@@ -37,7 +37,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: box.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: box.c,v 1.2 2000/12/09 12:27:11 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -92,132 +92,138 @@ CHARTYPE fillchar;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- BOXP boxp;
- short rc=RC_OK;
- unsigned short y=0,x=0;
- LENGTHTYPE offset=0;
- short save_mark_type=MARK_VIEW->mark_type;
+   BOXP boxp;
+   short rc=RC_OK;
+   unsigned short y=0,x=0;
+   LENGTHTYPE offset=0;
+   short save_mark_type=MARK_VIEW->mark_type;
+   bool same_view=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_operations");
-#endif
-/*---------------------------------------------------------------------*/
-/* This procedure is for copying, deleting, filling, moving and        */
-/* overlaying box blocks. Box blocks consist of BOX, WORD and COLUMN   */
-/* blocks.                                                             */
-/*---------------------------------------------------------------------*/
- post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
-/*---------------------------------------------------------------------*/
-/* If the command was issued on the command line then the destination  */
-/* line is the current line and the destination column is 0;           */
-/*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->current_window == WINDOW_COMMAND)
+   TRACE_FUNCTION("box.c:     box_operations");
+   /*
+    * This procedure is for copying, deleting, filling, moving and
+    * overlaying box blocks. Box blocks consist of BOX, WORD and COLUMN
+    * blocks.
+    */
+   post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
+   /*
+    * If the command was issued on the command line then the destination
+    * line is the current line and the destination column is 0;
+    */
+   if (CURRENT_VIEW->current_window == WINDOW_COMMAND)
    {
-    if (CURRENT_VIEW->current_line == 0L)
-       boxp.dst_start_line = 1L;
-    else
-       boxp.dst_start_line = CURRENT_VIEW->current_line;
-    boxp.dst_start_col = 0;
+      if (CURRENT_VIEW->current_line == 0L)
+         boxp.dst_start_line = 1L;
+      else
+         boxp.dst_start_line = CURRENT_VIEW->current_line;
+      boxp.dst_start_col = 0;
    }
- else
+   else
    {
-    if (CURRENT_VIEW->focus_line == 0L)
-       boxp.dst_start_line = 1L;
-    else
-       boxp.dst_start_line = CURRENT_VIEW->focus_line;
-    getyx(CURRENT_WINDOW,y,x);
-    boxp.dst_start_col = x + CURRENT_VIEW->verify_col-1;
+      if (CURRENT_VIEW->focus_line == 0L)
+         boxp.dst_start_line = 1L;
+      else
+         boxp.dst_start_line = CURRENT_VIEW->focus_line;
+      getyx(CURRENT_WINDOW,y,x);
+      boxp.dst_start_col = x + CURRENT_VIEW->verify_col-1;
    }
-/*---------------------------------------------------------------------*/
-/* Set up the source and destination views...                          */
-/*---------------------------------------------------------------------*/
- boxp.src_view = MARK_VIEW;
- boxp.dst_view = CURRENT_VIEW;
+   /*
+    * Set up the source and destination views...
+    */
+   boxp.src_view = MARK_VIEW;
+   boxp.dst_view = CURRENT_VIEW;
+   if ( MARK_VIEW == CURRENT_VIEW )
+      same_view = TRUE;
 
- boxp.mark_type = MARK_VIEW->mark_type;
+   boxp.mark_type = MARK_VIEW->mark_type;
 
- boxp.src_start_line = MARK_VIEW->mark_start_line;
- boxp.src_start_col = MARK_VIEW->mark_start_col-1;
+   boxp.src_start_line = MARK_VIEW->mark_start_line;
+   boxp.src_start_col = MARK_VIEW->mark_start_col-1;
 
- boxp.src_end_line = MARK_VIEW->mark_end_line;
- boxp.src_end_col = MARK_VIEW->mark_end_col-1;
+   boxp.src_end_line = MARK_VIEW->mark_end_line;
+   boxp.src_end_col = MARK_VIEW->mark_end_col-1;
 
- boxp.num_cols =  MARK_VIEW->mark_end_col - MARK_VIEW->mark_start_col + 1;
-/*---------------------------------------------------------------------*/
-/* If the block type is COLUMN, the number of lines to operate on is   */
-/* the number of lines in the source file and the destination start    */
-/* line is line 1. Reset these values set above.                       */
-/*---------------------------------------------------------------------*/
- if (MARK_VIEW->mark_type == M_COLUMN)
+   boxp.num_cols =  MARK_VIEW->mark_end_col - MARK_VIEW->mark_start_col + 1;
+   /*
+    * If the block type is COLUMN, the number of lines to operate on is
+    * the number of lines in the source file and the destination start
+    * line is line 1. Reset these values set above.
+    */
+   if (MARK_VIEW->mark_type == M_COLUMN)
    {
-    boxp.num_lines = MARK_VIEW->file_for_view->number_lines - boxp.src_start_line +1L;
-    boxp.dst_start_line = 1L;
+      boxp.num_lines = MARK_VIEW->file_for_view->number_lines - boxp.src_start_line +1L;
+      boxp.dst_start_line = 1L;
    }
- else
-    boxp.num_lines = MARK_VIEW->mark_end_line - boxp.src_start_line +1L;
-/*---------------------------------------------------------------------*/
-/* Find the current LINE pointer for both the source and destination   */
-/* lines.                                                              */
-/*---------------------------------------------------------------------*/
- boxp.curr_src = lll_find(MARK_FILE->first_line,MARK_FILE->last_line,boxp.src_start_line,MARK_FILE->number_lines);
- if (action != BOX_D)
-    boxp.curr_dst = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,boxp.dst_start_line,CURRENT_FILE->number_lines);
-/*---------------------------------------------------------------------*/
-/* Call the appropriate box function...                                */
-/*---------------------------------------------------------------------*/
- boxp.action = action;
- switch(action)
+   else
+      boxp.num_lines = MARK_VIEW->mark_end_line - boxp.src_start_line +1L;
+   /*
+    * Find the current LINE pointer for both the source and destination
+    * lines.
+    */
+   boxp.curr_src = lll_find(MARK_FILE->first_line,MARK_FILE->last_line,boxp.src_start_line,MARK_FILE->number_lines);
+   if (action != BOX_D)
+      boxp.curr_dst = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,boxp.dst_start_line,CURRENT_FILE->number_lines);
+   /*
+    * Call the appropriate box function...
+    */
+   boxp.action = action;
+   switch(action)
    {
-    case BOX_D:
-        rc = box_delete(&boxp);
-        break;
-    case BOX_M:
-        rc = box_move(&boxp,boverlay);
-        break;
-    case BOX_C:
-        rc = box_move(&boxp,boverlay);
-        break;
-    case BOX_F:
-        rc = box_fill(&boxp,fillchar);
-        break;
+      case BOX_D:
+         rc = box_delete(&boxp);
+         break;
+      case BOX_M:
+         rc = box_move(&boxp,boverlay);
+         break;
+      case BOX_C:
+         rc = box_move(&boxp,boverlay);
+         break;
+      case BOX_F:
+         rc = box_fill(&boxp,fillchar);
+         break;
    }
-/*---------------------------------------------------------------------*/
-/* Increment the alteration counts...                                  */
-/*---------------------------------------------------------------------*/
- increment_alt(CURRENT_FILE);
-/*---------------------------------------------------------------------*/
-/* Set the parameters in the MARK_VIEW to OFF;                         */
-/*---------------------------------------------------------------------*/
- MARK_VIEW->marked_line = MARK_VIEW->marked_col = FALSE;
- MARK_VIEW = (VIEW_DETAILS *)NULL;
-/*---------------------------------------------------------------------*/
-/* If we are not resetting the block, set up block markers...          */
-/*---------------------------------------------------------------------*/
- if (reset != SOURCE_BLOCK_RESET)
+   /*
+    * Increment the alteration counts...
+    */
+   increment_alt(CURRENT_FILE);
+   /*
+    * Set the parameters in the MARK_VIEW to OFF, and
+    * redraw the view if different from the current view
+    */
+   MARK_VIEW->marked_line = MARK_VIEW->marked_col = FALSE;
+   MARK_VIEW = (VIEW_DETAILS *)NULL;
+   if ( !same_view
+   &&   display_screens > 1)
    {
-    if (boxp.src_start_col < boxp.dst_start_col
-    && action == BOX_M)
-       offset = boxp.num_cols;
-    MARK_VIEW = CURRENT_VIEW;
-    MARK_VIEW->mark_start_line = boxp.dst_start_line;
-    MARK_VIEW->mark_end_line = boxp.dst_start_line+boxp.num_lines-1L;
-    MARK_VIEW->mark_start_col = boxp.dst_start_col+1-offset;
-    if (save_mark_type == M_STREAM
-    &&  boxp.num_lines != 1)
-       MARK_VIEW->mark_end_col = boxp.src_end_col+1;
-    else
-       MARK_VIEW->mark_end_col = boxp.dst_start_col+boxp.num_cols-offset;
-    MARK_VIEW->mark_type = save_mark_type;
-    MARK_VIEW->marked_line = MARK_VIEW->marked_col = TRUE;
-    wmove(CURRENT_WINDOW,y,x-offset);
+      build_screen(other_screen);
+      display_screen(other_screen);
    }
- pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
- build_screen(current_screen); 
- display_screen(current_screen); /* should only call this is the marked block is in view */
-#ifdef THE_TRACE
- trace_return();
-#endif
- return;
+   /*
+    * If we are not resetting the block, set up block markers...
+    */
+   if (reset != SOURCE_BLOCK_RESET)
+   {
+      if (boxp.src_start_col < boxp.dst_start_col
+      && action == BOX_M)
+         offset = boxp.num_cols;
+      MARK_VIEW = CURRENT_VIEW;
+      MARK_VIEW->mark_start_line = boxp.dst_start_line;
+      MARK_VIEW->mark_end_line = boxp.dst_start_line+boxp.num_lines-1L;
+      MARK_VIEW->mark_start_col = boxp.dst_start_col+1-offset;
+      if (save_mark_type == M_STREAM
+      &&  boxp.num_lines != 1)
+         MARK_VIEW->mark_end_col = boxp.src_end_col+1;
+      else
+         MARK_VIEW->mark_end_col = boxp.dst_start_col+boxp.num_cols-offset;
+      MARK_VIEW->mark_type = save_mark_type;
+      MARK_VIEW->marked_line = MARK_VIEW->marked_col = TRUE;
+      wmove(CURRENT_WINDOW,y,x-offset);
+   }
+   pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
+   build_screen(current_screen); 
+   display_screen(current_screen); /* should only call this is the marked block is in view */
+   TRACE_RETURN();
+   return;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -237,9 +243,7 @@ BOXP *prm;
  bool advance_line_ptr = TRUE;
  LINE *curr=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_delete");
-#endif
+ TRACE_FUNCTION("box.c:     box_delete");
  curr = prm->curr_src;
  for (i=0L;i<prm->num_lines;i++)
    {
@@ -324,9 +328,7 @@ BOXP *prm;
        if (curr->line == NULL)
          {
           display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY);
          }
        memcpy((DEFCHAR*)curr->line+curr->length,(DEFCHAR*)curr->next->line,curr->next->length);
@@ -341,9 +343,7 @@ BOXP *prm;
     curr = delete_LINE(MARK_FILE->first_line,MARK_FILE->last_line,curr->next,DIRECTION_FORWARD);
     MARK_FILE->number_lines--;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -361,9 +361,7 @@ bool boverlay;
  LINETYPE save_src_start_line=0L;
  LENGTHTYPE save_src_start_col=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_move");
-#endif
+ TRACE_FUNCTION("box.c:     box_move");
  save_src_start_col = prm->src_start_col;
  save_src_start_line = prm->src_start_line;
  save_src = prm->curr_src;
@@ -391,9 +389,7 @@ bool boverlay;
  &&  prm->action == BOX_M)
     box_delete(prm);
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -410,9 +406,7 @@ BOXP *prm;
  LINETYPE i=0L;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_copy_to_temp");
-#endif
+ TRACE_FUNCTION("box.c:     box_copy_to_temp");
  tmp = prm->curr_src;
  for (i=0L;i<prm->num_lines;i++)
  {
@@ -439,9 +433,7 @@ BOXP *prm;
            rec_len = mynum;
            if ((save_src = add_LINE(first_save,save_src,rec,rec_len,0,TRUE)) == (LINE *)NULL)
            {
-#ifdef THE_TRACE
-              trace_return();
-#endif
+              TRACE_RETURN();
               return(RC_OUT_OF_MEMORY);
            }
        }
@@ -451,9 +443,7 @@ BOXP *prm;
           rec_len = tmp->length;
           if ((save_src = add_LINE(first_save,save_src,rec+prm->src_start_col,prm->num_cols,0,TRUE)) == (LINE *)NULL)
           {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_OUT_OF_MEMORY);
           }
        }
@@ -464,9 +454,7 @@ BOXP *prm;
        if ((save_src = add_LINE(first_save,save_src,
             rec+prm->src_start_col,prm->num_cols,0,TRUE)) == (LINE *)NULL)
        {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY);
        }
 #endif
@@ -476,9 +464,7 @@ BOXP *prm;
     tmp = tmp->next;
  }
  prm->curr_src = first_save;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -497,9 +483,7 @@ bool boverlay;
  CHARTYPE chr=0;
  short rc=RC_OK,line_type=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_copy_from_temp");
-#endif
+ TRACE_FUNCTION("box.c:     box_copy_from_temp");
  dst_lineno = prm->dst_start_line;
  while(prm->curr_src)
  {
@@ -515,9 +499,7 @@ bool boverlay;
           if ((prm->curr_dst = add_LINE(CURRENT_FILE->first_line,prm->curr_dst->prev,
                                  (CHARTYPE *)"",0,0,TRUE)) == (LINE *)NULL)
           {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_OUT_OF_MEMORY);
           }
           CURRENT_FILE->number_lines++;
@@ -551,9 +533,7 @@ bool boverlay;
     dst_lineno++;
  }
  prm->num_lines = dst_lineno - prm->dst_start_line;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -573,9 +553,7 @@ bool boverlay;
  bool full_line=TRUE;
  LINE *curr=NULL,*last_line=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_copy_stream_from_temp");
-#endif
+ TRACE_FUNCTION("box.c:     box_copy_stream_from_temp");
  if (boverlay)
  {
     /*
@@ -599,9 +577,7 @@ bool boverlay;
              if ((prm->curr_dst = add_LINE(CURRENT_FILE->first_line,prm->curr_dst->prev,
                                     (CHARTYPE *)"",0,0,TRUE)) == (LINE *)NULL)
              {
-#ifdef THE_TRACE
-                trace_return();
-#endif
+                TRACE_RETURN();
                 return(RC_OUT_OF_MEMORY);
              }
              CURRENT_FILE->number_lines++;
@@ -670,9 +646,7 @@ bool boverlay;
           if ((prm->curr_dst = add_LINE(CURRENT_FILE->first_line,prm->curr_dst->prev,
                                     (CHARTYPE *)"",0,0,TRUE)) == (LINE *)NULL)
           {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_OUT_OF_MEMORY);
           }
           CURRENT_FILE->number_lines++;
@@ -733,9 +707,7 @@ bool boverlay;
           if ((curr = add_LINE(CURRENT_FILE->first_line,curr,
                                     prm->curr_src->line,prm->curr_src->length,0,TRUE)) == (LINE *)NULL)
           {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_OUT_OF_MEMORY);
           }
           prm->curr_src = prm->curr_src->next;   /* this should NEVER go past the end */
@@ -744,9 +716,7 @@ bool boverlay;
     }
     pre_process_line(prm->dst_view,dst_lineno,prm->curr_dst);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -763,9 +733,7 @@ CHARTYPE fillchar;
  LINETYPE i=0L;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("box.c:     box_fill");
-#endif
+ TRACE_FUNCTION("box.c:     box_fill");
  for (i=0L;i<prm->num_lines;i++)
     {
      if (processable_line(CURRENT_VIEW,prm->src_start_line+i,prm->curr_src) == LINE_LINE)
@@ -795,8 +763,6 @@ CHARTYPE fillchar;
  prm->dst_start_col = prm->src_start_col;
  prm->dst_start_line = prm->src_start_line;
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
