@@ -38,7 +38,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: colour.c,v 1.2 2000/12/09 21:17:27 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -51,7 +51,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  *             CTOFEOF    TABLINE  SHADOW   STATAREA
  *             DIVIDER    RESERVED NONDISP  HIGHLIGHT
  *             CHIGHLIGHT SLK      GAP      ALERT
- *             DIALOG
+ *             DIALOG     BOUNDMARK
  */
 
 #ifdef A_COLOR
@@ -62,7 +62,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_WHITE,COLOR_YELLOW,COLOR_RED,COLOR_BLUE,
                COLOR_RED,COLOR_WHITE,COLOR_MAGENTA,COLOR_WHITE,
                COLOR_YELLOW,COLOR_BLACK,COLOR_BLACK,COLOR_WHITE,
-               COLOR_BLACK};
+               COLOR_BLACK,COLOR_WHITE};
  static chtype the_back[ATTR_MAX] =
               {COLOR_BLUE,COLOR_BLUE,COLOR_WHITE,COLOR_WHITE,
                COLOR_CYAN,COLOR_WHITE,COLOR_WHITE,COLOR_CYAN,
@@ -70,7 +70,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_BLUE,COLOR_BLUE,COLOR_WHITE,COLOR_WHITE,
                COLOR_WHITE,COLOR_BLACK,COLOR_CYAN,COLOR_CYAN,
                COLOR_CYAN,COLOR_CYAN,COLOR_CYAN,COLOR_RED,
-               COLOR_WHITE};
+               COLOR_WHITE,COLOR_BLACK};
  static chtype the_mod[ATTR_MAX] =
               {A_NORMAL,A_BOLD,  A_NORMAL,A_NORMAL,
                A_NORMAL,A_NORMAL,A_NORMAL,A_NORMAL,
@@ -78,7 +78,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_BOLD,  A_NORMAL,A_NORMAL,
                A_NORMAL,A_NORMAL,A_BLINK, A_BOLD,
                A_BOLD,  A_BOLD,  A_NORMAL,A_NORMAL,
-               A_NORMAL};
+               A_NORMAL,A_BOLD};
  static chtype kedit_fore[ATTR_MAX] =
               {COLOR_CYAN,COLOR_YELLOW,COLOR_CYAN,COLOR_YELLOW,
                COLOR_YELLOW,COLOR_YELLOW,COLOR_YELLOW,COLOR_YELLOW,
@@ -86,7 +86,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_YELLOW,COLOR_YELLOW,COLOR_YELLOW,COLOR_YELLOW,
                COLOR_CYAN,COLOR_YELLOW,COLOR_MAGENTA,COLOR_WHITE,
                COLOR_YELLOW,COLOR_BLACK,COLOR_CYAN,COLOR_WHITE,
-               COLOR_BLACK};
+               COLOR_BLACK,COLOR_WHITE};
  static chtype kedit_back[ATTR_MAX] =
               {COLOR_BLUE,COLOR_BLUE,COLOR_WHITE,COLOR_WHITE,
                COLOR_BLUE,COLOR_BLUE,COLOR_BLUE,COLOR_BLUE,
@@ -94,7 +94,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_BLUE,COLOR_BLUE,COLOR_BLUE,COLOR_BLUE,
                COLOR_BLUE,COLOR_BLUE,COLOR_CYAN,COLOR_CYAN,
                COLOR_CYAN,COLOR_CYAN,COLOR_BLUE,COLOR_RED,
-               COLOR_WHITE};
+               COLOR_WHITE,COLOR_BLACK};
  static chtype kedit_mod[ATTR_MAX]  =
               {A_BOLD,  A_BOLD,  A_BOLD,  A_BOLD,
                A_BOLD,  A_BOLD,  A_BOLD,  A_BOLD,
@@ -102,7 +102,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_BOLD,  A_NORMAL,A_BOLD,
                A_BOLD,  A_BOLD,  A_BLINK, A_BOLD,
                A_BOLD,  A_BOLD,  A_BOLD,  A_NORMAL,
-               A_NORMAL};
+               A_NORMAL,A_BOLD};
  static chtype keditw_fore[ATTR_MAX] =
               {COLOR_BLACK,COLOR_BLUE,COLOR_WHITE,COLOR_YELLOW,
                COLOR_BLACK,COLOR_BLUE,COLOR_RED,COLOR_BLUE,
@@ -110,7 +110,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_BLUE,COLOR_BLUE,COLOR_BLUE,COLOR_WHITE,
                COLOR_BLUE,COLOR_BLUE,COLOR_RED,COLOR_BLACK,
                COLOR_GREEN,COLOR_BLACK,COLOR_BLACK,COLOR_WHITE,
-               COLOR_BLACK};
+               COLOR_BLACK,COLOR_WHITE};
  static chtype keditw_back[ATTR_MAX] =
               {COLOR_WHITE,COLOR_WHITE,COLOR_BLACK,COLOR_BLACK,
                COLOR_WHITE,COLOR_WHITE,COLOR_WHITE,COLOR_WHITE,
@@ -118,7 +118,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_WHITE,COLOR_WHITE,COLOR_WHITE,COLOR_CYAN,
                COLOR_WHITE,COLOR_WHITE,COLOR_WHITE,COLOR_YELLOW,
                COLOR_YELLOW,COLOR_CYAN,COLOR_WHITE,COLOR_RED,
-               COLOR_WHITE};
+               COLOR_WHITE,COLOR_WHITE};
  static chtype keditw_mod[ATTR_MAX]  =
               {A_NORMAL,A_NORMAL,A_BOLD,  A_NORMAL,
                A_NORMAL,A_NORMAL,A_BOLD,  A_NORMAL,
@@ -126,7 +126,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_NORMAL,A_NORMAL,A_NORMAL,A_BOLD,
                A_NORMAL,A_NORMAL,A_BLINK, A_BOLD,
                A_NORMAL,A_NORMAL,A_NORMAL,A_BOLD,
-               A_NORMAL};
+               A_NORMAL,A_NORMAL};
  static chtype xedit_fore[ATTR_MAX] =
               {COLOR_GREEN, COLOR_CYAN, COLOR_BLACK,COLOR_CYAN,
                COLOR_YELLOW,COLOR_CYAN, COLOR_RED,  COLOR_CYAN,
@@ -134,7 +134,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_GREEN, COLOR_GREEN,COLOR_GREEN,COLOR_CYAN,
                COLOR_GREEN, COLOR_GREEN,COLOR_MAGENTA,COLOR_WHITE,
                COLOR_YELLOW,COLOR_BLACK,COLOR_GREEN,COLOR_WHITE,
-               COLOR_BLACK};
+               COLOR_BLACK, COLOR_WHITE};
  static chtype xedit_back[ATTR_MAX] =
               {COLOR_BLACK,COLOR_BLACK,COLOR_GREEN,COLOR_GREEN,
                COLOR_BLACK,COLOR_BLACK,COLOR_BLACK,COLOR_BLACK,
@@ -142,7 +142,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                COLOR_BLACK,COLOR_BLACK,COLOR_BLACK,COLOR_BLACK,
                COLOR_BLACK,COLOR_BLACK,COLOR_CYAN,COLOR_CYAN,
                COLOR_CYAN,COLOR_GREEN,COLOR_BLACK,COLOR_RED,
-               COLOR_WHITE};
+               COLOR_WHITE<COLOR_BLACK};
  static chtype xedit_mod[ATTR_MAX]  =
               {A_NORMAL,A_NORMAL,A_NORMAL,A_BOLD,
                A_NORMAL,A_NORMAL,A_BOLD,  A_NORMAL,
@@ -150,20 +150,20 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_BOLD,  A_NORMAL,A_NORMAL,
                A_BOLD,  A_BOLD,  A_BLINK, A_BOLD,
                A_BOLD,  A_BOLD,  A_NORMAL,A_NORMAL,
-               A_NORMAL};
+               A_NORMAL,A_BOLD};
 #else
- static chtype the_fore[ATTR_MAX]   = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype the_back[ATTR_MAX]   = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype the_mod[ATTR_MAX]    = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype kedit_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype kedit_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype kedit_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype keditw_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype keditw_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype keditw_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype xedit_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype xedit_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
- static chtype xedit_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype the_fore[ATTR_MAX]   = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype the_back[ATTR_MAX]   = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype the_mod[ATTR_MAX]    = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype kedit_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype kedit_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype kedit_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype keditw_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype keditw_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype keditw_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype xedit_fore[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype xedit_back[ATTR_MAX] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+ static chtype xedit_mod[ATTR_MAX]  = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
 #endif
  static chtype the_mono[ATTR_MAX] =
               {A_NORMAL,A_BOLD,A_REVERSE,A_BOLD|A_REVERSE,
@@ -172,7 +172,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,A_BOLD,A_BOLD,A_REVERSE,
                A_BOLD,A_BOLD,A_BLINK|A_REVERSE,A_REVERSE,
                A_BOLD|A_REVERSE,A_BOLD|A_REVERSE,A_REVERSE,A_REVERSE,
-               A_NORMAL};
+               A_NORMAL,A_NORMAL};
  static chtype kedit_mono[ATTR_MAX] =
               {A_NORMAL,A_BOLD,  A_REVERSE,A_REVERSE|A_BOLD,
                A_NORMAL,A_NORMAL,A_BOLD,  A_BOLD,
@@ -180,7 +180,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_NORMAL,A_NORMAL,A_BOLD,
                A_NORMAL,A_NORMAL,A_BLINK|A_REVERSE,A_REVERSE,
                A_BOLD|A_REVERSE,A_BOLD|A_REVERSE,A_NORMAL,A_REVERSE,
-               A_NORMAL};
+               A_NORMAL,A_NORMAL};
  static chtype keditw_mono[ATTR_MAX] =
               {A_NORMAL,A_BOLD,  A_REVERSE,A_REVERSE|A_BOLD,
                A_NORMAL,A_NORMAL,A_BOLD,  A_BOLD,
@@ -188,7 +188,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_NORMAL,A_NORMAL,A_BOLD,
                A_NORMAL,A_NORMAL,A_BLINK|A_REVERSE,A_REVERSE,
                A_BOLD|A_REVERSE,A_BOLD|A_REVERSE,A_NORMAL,A_REVERSE,
-               A_NORMAL};
+               A_NORMAL,A_NORMAL};
  static chtype xedit_mono[ATTR_MAX] =
               {A_NORMAL,A_BOLD,  A_REVERSE,A_BOLD|A_REVERSE,
                A_NORMAL,A_BOLD,  A_BOLD,  A_BOLD,
@@ -196,7 +196,7 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
                A_BOLD,  A_BOLD,  A_NORMAL,A_BOLD,
                A_BOLD,  A_BOLD,  A_BLINK|A_REVERSE,A_REVERSE,
                A_BOLD|A_REVERSE,A_BOLD|A_REVERSE,A_NORMAL,A_REVERSE,
-               A_NORMAL};
+               A_NORMAL,A_NORMAL};
 
 /* A - comments */
 /* B - strings */
@@ -259,8 +259,8 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
   {COLOR_CYAN,    COLOR_BLUE , A_BOLD  , A_NORMAL}, /* T */
   {COLOR_RED,     COLOR_BLUE , A_BOLD  , A_NORMAL}, /* U */
   {COLOR_MAGENTA, COLOR_BLUE , A_NORMAL, A_NORMAL}, /* V */
-  {COLOR_BLACK,   COLOR_BLUE , A_NORMAL, A_NORMAL}, /* W */
-  {COLOR_BLACK,   COLOR_BLUE , A_NORMAL, A_NORMAL}, /* X */
+  {COLOR_YELLOW,  COLOR_BLUE , A_BOLD,   A_NORMAL}, /* W */
+  {COLOR_YELLOW,  COLOR_BLUE , A_NORMAL, A_NORMAL}, /* X */
   {COLOR_BLACK,   COLOR_BLUE , A_NORMAL, A_NORMAL}, /* Y */
   {COLOR_BLACK,   COLOR_BLUE , A_NORMAL, A_NORMAL}, /* Z */
   {COLOR_RED,     COLOR_BLUE , A_BOLD  , A_NORMAL}, /* 1 */
@@ -299,8 +299,8 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
   {COLOR_BLUE,    COLOR_BLACK, A_BOLD  , A_NORMAL}, /* T */
   {COLOR_RED,     COLOR_BLACK, A_BOLD  , A_NORMAL}, /* U */
   {COLOR_MAGENTA, COLOR_BLACK, A_NORMAL, A_NORMAL}, /* V */
-  {COLOR_BLACK,   COLOR_BLACK, A_NORMAL, A_NORMAL}, /* W */
-  {COLOR_BLACK,   COLOR_BLACK, A_NORMAL, A_NORMAL}, /* X */
+  {COLOR_YELLOW,  COLOR_BLACK, A_BOLD  , A_NORMAL}, /* W */
+  {COLOR_YELLOW,  COLOR_BLACK, A_NORMAL, A_NORMAL}, /* X */
   {COLOR_BLACK,   COLOR_BLACK, A_NORMAL, A_NORMAL}, /* Y */
   {COLOR_BLACK,   COLOR_BLACK, A_NORMAL, A_NORMAL}, /* Z */
   {COLOR_RED,     COLOR_BLACK, A_BOLD  , A_NORMAL}, /* 1 */
@@ -317,41 +317,41 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  static ECOLOURS kedit_ecolours[ECOLOUR_MAX] =
  {
   /* foreground   background   modifier  mono */
-  {COLOR_GREEN,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* A */
-  {COLOR_CYAN,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* B */
-  {COLOR_RED,     COLOR_WHITE, A_NORMAL, A_NORMAL}, /* C */
-  {COLOR_BLUE,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* D */
-  {COLOR_RED,     COLOR_WHITE, A_NORMAL, A_NORMAL}, /* E */
-  {COLOR_RED,     COLOR_WHITE, A_NORMAL, A_NORMAL}, /* F */
-  {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* G */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* H */
-  {COLOR_GREEN,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* I */
-  {COLOR_BLUE,    COLOR_WHITE, A_BOLD  , A_NORMAL}, /* J */
-  {COLOR_RED,     COLOR_WHITE, A_NORMAL, A_NORMAL}, /* K */
-  {COLOR_GREEN,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* L */
-  {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* M */
-  {COLOR_CYAN,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* N */
-  {COLOR_MAGENTA, COLOR_WHITE, A_NORMAL, A_NORMAL}, /* O */
-  {COLOR_WHITE,   COLOR_WHITE, A_BOLD,   A_NORMAL}, /* P */
-  {COLOR_BLUE,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* Q */
-  {COLOR_MAGENTA, COLOR_WHITE, A_BOLD  , A_NORMAL}, /* R */
-  {COLOR_MAGENTA, COLOR_WHITE, A_BOLD  , A_NORMAL}, /* S */
-  {COLOR_BLUE,    COLOR_WHITE, A_BOLD  , A_NORMAL}, /* T */
-  {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* U */
-  {COLOR_MAGENTA, COLOR_WHITE, A_NORMAL, A_NORMAL}, /* V */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* W */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* X */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* Y */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* Z */
-  {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* 1 */
-  {COLOR_BLUE,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 2 */
-  {COLOR_RED,     COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 3 */
-  {COLOR_MAGENTA, COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 4 */
-  {COLOR_GREEN,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 5 */
-  {COLOR_CYAN,    COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 6 */
-  {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* 7 */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* 8 */
-  {COLOR_BLUE,    COLOR_WHITE, A_BOLD ,  A_NORMAL}, /* 9 */
+  {COLOR_GREEN,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* A */
+  {COLOR_CYAN,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* B */
+  {COLOR_RED,     COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* C */
+  {COLOR_BLUE,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* D */
+  {COLOR_RED,     COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* E */
+  {COLOR_RED,     COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* F */
+  {COLOR_RED,     COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* G */
+  {COLOR_BLACK,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* H */
+  {COLOR_GREEN,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* I */
+  {COLOR_BLUE,    COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* J */
+  {COLOR_RED,     COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* K */
+  {COLOR_GREEN,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* L */
+  {COLOR_RED,     COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* M */
+  {COLOR_CYAN,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* N */
+  {COLOR_MAGENTA, COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* O */
+  {COLOR_WHITE,   COLOR_BLUE,  A_BOLD,   A_NORMAL}, /* P */
+  {COLOR_BLUE,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* Q */
+  {COLOR_MAGENTA, COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* R */
+  {COLOR_MAGENTA, COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* S */
+  {COLOR_BLUE,    COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* T */
+  {COLOR_RED,     COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* U */
+  {COLOR_MAGENTA, COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* V */
+  {COLOR_YELLOW,  COLOR_BLUE,  A_BOLD,   A_NORMAL}, /* W */
+  {COLOR_YELLOW,  COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* X */
+  {COLOR_BLACK,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* Y */
+  {COLOR_BLACK,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* Z */
+  {COLOR_RED,     COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* 1 */
+  {COLOR_BLUE,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 2 */
+  {COLOR_RED,     COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 3 */
+  {COLOR_MAGENTA, COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 4 */
+  {COLOR_GREEN,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 5 */
+  {COLOR_CYAN,    COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 6 */
+  {COLOR_RED,     COLOR_BLUE,  A_BOLD  , A_NORMAL}, /* 7 */
+  {COLOR_BLACK,   COLOR_BLUE,  A_NORMAL, A_NORMAL}, /* 8 */
+  {COLOR_BLUE,    COLOR_BLUE,  A_BOLD ,  A_NORMAL}, /* 9 */
  };
 
  static ECOLOURS keditw_ecolours[ECOLOUR_MAX] =
@@ -379,8 +379,8 @@ static char RCSid[] = "$Id: colour.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
   {COLOR_BLUE,    COLOR_WHITE, A_BOLD  , A_NORMAL}, /* T */
   {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* U */
   {COLOR_MAGENTA, COLOR_WHITE, A_NORMAL, A_NORMAL}, /* V */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* W */
-  {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* X */
+  {COLOR_YELLOW,  COLOR_WHITE, A_BOLD,   A_NORMAL}, /* W */
+  {COLOR_YELLOW,  COLOR_WHITE, A_NORMAL, A_NORMAL}, /* X */
   {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* Y */
   {COLOR_BLACK,   COLOR_WHITE, A_NORMAL, A_NORMAL}, /* Z */
   {COLOR_RED,     COLOR_WHITE, A_BOLD  , A_NORMAL}, /* 1 */
@@ -463,9 +463,7 @@ bool *any_colours;
  bool spare_pos=FALSE;
  int offset=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("colour.c:  parse_colours");
-#endif
+ TRACE_FUNCTION("colour.c:  parse_colours");
 /*---------------------------------------------------------------------*/
 /* Get a copy of the passed string and wreck it rather than the passed */
 /* string.                                                             */
@@ -473,9 +471,7 @@ bool *any_colours;
  if ((string = (CHARTYPE *)my_strdup(attrib)) == NULL)
    {
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OUT_OF_MEMORY);
    }
  oldp = string;
@@ -493,9 +489,7 @@ bool *any_colours;
              {
               display_error(61,(CHARTYPE *)p,FALSE);
               (*the_free)(string);
-#ifdef THE_TRACE
-              trace_return();
-#endif
+              TRACE_RETURN();
               return(RC_INVALID_OPERAND);
              }
            if (valid_attribs[i].attrib_modifier)
@@ -517,9 +511,7 @@ bool *any_colours;
                         {
                          display_error(61,(CHARTYPE *)p,FALSE);
                          (*the_free)(string);
-#ifdef THE_TRACE
-                         trace_return();
-#endif
+                         TRACE_RETURN();
                          return(RC_INVALID_OPERAND);
                         }
                       if (valid_attribs[i].actual_attrib != 8)
@@ -536,9 +528,7 @@ bool *any_colours;
                         {
                          display_error(61,(CHARTYPE *)p,FALSE);
                          (*the_free)(string);
-#ifdef THE_TRACE
-                         trace_return();
-#endif
+                         TRACE_RETURN();
                          return(RC_INVALID_OPERAND);
                         }
                       if (valid_attribs[i].actual_attrib != 8)
@@ -557,9 +547,7 @@ bool *any_colours;
                         }
                       display_error(1,(CHARTYPE *)p,FALSE);
                       (*the_free)(string);
-#ifdef THE_TRACE
-                      trace_return();
-#endif
+                      TRACE_RETURN();
                       return(RC_INVALID_OPERAND);
                       break;
                 }
@@ -585,9 +573,7 @@ bool *any_colours;
             }
           display_error(1,(CHARTYPE *)p,FALSE);
           (*the_free)(string);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
          }
       }
@@ -602,9 +588,7 @@ bool *any_colours;
  pattr->mono = mono;
  *any_colours = any_found;
  (*the_free)(string);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 
@@ -625,17 +609,13 @@ COLOUR_ATTR *attr;
 /*--------------------------- local data ------------------------------*/
  chtype color=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("colour.c:  set_colour");
-#endif
+ TRACE_FUNCTION("colour.c:  set_colour");
  color = attr->mono;
 #ifdef A_COLOR
  if (colour_support)
     color = (attr->pair) ? COLOR_PAIR(attr->pair) | attr->mod : attr->mod;
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(color);
 }
 #endif
@@ -650,27 +630,20 @@ COLOUR_ATTR *attr,*ecolour;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- chtype bg,fg,mod,pair;
+   chtype bg,fg,mod,pair;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("colour.c:  merge_curline_colour");
-#endif
+   TRACE_FUNCTION("colour.c:  merge_curline_colour");
 #ifdef A_COLOR
    bg = BACKFROMPAIR(attr->pair);
    fg = FOREFROMPAIR(ecolour->pair);
    mod = attr->mod | ecolour->mod;
    pair = ATTR2PAIR(fg,bg);
+   fg = (COLOR_PAIR(pair) | mod);
 #else
-   mod = attr->mod | ecolour->mod;
-#endif
-#ifdef THE_TRACE
-   trace_return();
-#endif
-#ifdef A_COLOR
-   return (COLOR_PAIR(pair) | mod);
-#else
-   return (mod);
+   fg = attr->mod | ecolour->mod;
 #endif
+   TRACE_RETURN();
+   return fg;
 }
 
 /***********************************************************************/
@@ -689,9 +662,7 @@ int colour_num;
 /*--------------------------- local data ------------------------------*/
    register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("colour.c:  set_up_default_colours");
-#endif
+   TRACE_FUNCTION("colour.c:  set_up_default_colours");
 /*---------------------------------------------------------------------*/
 /* Set up default colours.                                             */
 /*---------------------------------------------------------------------*/
@@ -766,9 +737,7 @@ int colour_num;
          }
          break;
    }
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return;
 }
 /***********************************************************************/
@@ -785,9 +754,7 @@ FILE_DETAILS *fd;
 /*--------------------------- local data ------------------------------*/
    register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("colour.c:  set_up_default_ecolours");
-#endif
+   TRACE_FUNCTION("colour.c:  set_up_default_ecolours");
 /*---------------------------------------------------------------------*/
 /* Set up default colours.                                             */
 /*---------------------------------------------------------------------*/
@@ -826,9 +793,7 @@ FILE_DETAILS *fd;
          }
          break;
    }
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return;
 }
 /***********************************************************************/
@@ -856,9 +821,7 @@ COLOUR_ATTR *attr;
  bool colour_only=FALSE;
  chtype match_value=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("colour.c:  get_colour_strings");
-#endif
+ TRACE_FUNCTION("colour.c:  get_colour_strings");
 
  start_with = GET_MOD;
 #ifdef A_COLOR
@@ -872,9 +835,7 @@ COLOUR_ATTR *attr;
  if (attr_string == (CHARTYPE *)NULL)
    {
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(NULL);
    }
  strcpy((DEFCHAR *)attr_string,"");
@@ -920,8 +881,6 @@ COLOUR_ATTR *attr;
          }
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(attr_string);
 }
