@@ -38,7 +38,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: comm2.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: comm2.c,v 1.2 2000/12/09 21:26:55 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -98,110 +98,98 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
 #define DEF_PARAMS  2
 #define DEF_MOUSE_PARAMS  4
- CHARTYPE *word[DEF_MOUSE_PARAMS+1];
- CHARTYPE strip[DEF_MOUSE_PARAMS];
- CHARTYPE *ptr=NULL;
- unsigned short num_params=0;
- int key_value=0;
- short rc=RC_OK;
+   CHARTYPE *word[DEF_MOUSE_PARAMS+1];
+   CHARTYPE strip[DEF_MOUSE_PARAMS];
+   CHARTYPE *ptr=NULL;
+   unsigned short num_params=0;
+   int key_value=0;
+   short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Define");
-#endif
- strip[0] = STRIP_BOTH;
- strip[1] = STRIP_LEADING;
- num_params = param_split(params,word,DEF_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
- if (num_params == 0)
+   TRACE_FUNCTION("comm2.c:   Define");
+   strip[0] = STRIP_BOTH;
+   strip[1] = STRIP_LEADING;
+   num_params = param_split(params,word,DEF_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
+   if (num_params == 0)
    {
-    display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_OPERAND);
+      display_error(3,(CHARTYPE *)"",FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
 /* The first parameter is the key name mnemonic , the next is one or   */
 /* more commands and/or parameters.                                    */
 /* First check the mnemonic for decimal string value. ie begins with \ */
 /*---------------------------------------------------------------------*/
- if (word[0][0] == '\\')
+   if (word[0][0] == '\\')
    {
-    if ((key_value = atoi((DEFCHAR *)word[0]+1)) == 0)
-       rc = RC_INVALID_OPERAND;
+       if ((key_value = atoi((DEFCHAR *)word[0]+1)) == 0)
+          rc = RC_INVALID_OPERAND;
    }
- else
+   else
    {
-    if ((key_value = find_key_value(word[0])) == (-1))
-       rc = RC_INVALID_OPERAND;
+       if ((key_value = find_key_value(word[0])) == (-1))
+          rc = RC_INVALID_OPERAND;
    }
- if (rc == RC_OK)
+   if (rc == RC_OK)
    {
 /*---------------------------------------------------------------------*/
 /* Determine if the first word of the supplied command is REXX (either */
 /* case)...                                                            */
 /*---------------------------------------------------------------------*/
-    if (memcmpi(word[1],(CHARTYPE *)"REXX ",5) == 0)
+      if ( strlen( (DEFCHAR *)word[1] ) > 5
+      &&   memcmpi( word[1], (CHARTYPE *)"REXX ", 5 ) == 0 )
       {
-       ptr = word[1];
-       rc = add_define(&first_define,&last_define,key_value,ptr+5,TRUE);
+         ptr = word[1];
+         rc = add_define(&first_define,&last_define,key_value,ptr+5,TRUE,FALSE,0);
       }
-    else
-       rc = add_define(&first_define,&last_define,key_value,word[1],FALSE);
+      else
+         rc = add_define(&first_define,&last_define,key_value,word[1],FALSE,FALSE,0);
     /*
      * Return after processing a KEY definition...
      */
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(rc);
+       TRACE_RETURN();
+       return(rc);
    }
 /*---------------------------------------------------------------------*/
 /* To get here, either it is an invalid KEY definition, or it is a     */
 /* MOUSE key definition waiting to be validated.                       */
 /*---------------------------------------------------------------------*/
- strip[0] = STRIP_BOTH;
- strip[1] = STRIP_BOTH;
- strip[2] = STRIP_BOTH;
- strip[3] = STRIP_NONE;
- num_params = param_split(params,word,DEF_MOUSE_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
- if (num_params < 3)
+   strip[0] = STRIP_BOTH;
+   strip[1] = STRIP_BOTH;
+   strip[2] = STRIP_BOTH;
+   strip[3] = STRIP_NONE;
+   num_params = param_split(params,word,DEF_MOUSE_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
+   if (num_params < 3)
    {
-    display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_OPERAND);
+      display_error(3,(CHARTYPE *)"",FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_OPERAND);
    }
- if (!equal((CHARTYPE *)"in",word[1],2))
+   if (!equal((CHARTYPE *)"in",word[1],2))
    {
-    display_error(1,word[1],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_OPERAND);
+      display_error(1,word[1],FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_OPERAND);
    }
- if ((key_value = find_mouse_key_value(word[0],word[2])) == (-1))
+   if ((key_value = find_mouse_key_value(word[0],word[2])) == (-1))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_OPERAND);
+      TRACE_RETURN();
+      return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
 /* Determine if the first word of the supplied command is REXX (either */
 /* case)...                                                            */
 /*---------------------------------------------------------------------*/
- if (memcmpi(word[3],(CHARTYPE *)"REXX ",5) == 0)
+   if ( strlen( (DEFCHAR *)word[1] ) > 5
+   &&   memcmpi( word[3], (CHARTYPE *)"REXX ", 5) == 0 )
    {
-    ptr = word[3];
-    rc = add_define(&first_mouse_define,&last_mouse_define,key_value,ptr+5,TRUE);
+      ptr = word[3];
+      rc = add_define(&first_mouse_define,&last_mouse_define,key_value,ptr+5,TRUE,FALSE,0);
    }
- else
-    rc = add_define(&first_mouse_define,&last_mouse_define,key_value,word[3],FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   else
+      rc = add_define(&first_mouse_define,&last_mouse_define,key_value,word[3],FALSE,FALSE,0);
+   TRACE_RETURN();
+   return(rc);
 }
 /*man-start*********************************************************************
 COMMAND
@@ -244,9 +232,7 @@ CHARTYPE *params;
  short target_type=TARGET_NORMAL|TARGET_ALL|TARGET_BLOCK_CURRENT;
  bool lines_based_on_scope=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   DeleteLine");
-#endif
+ TRACE_FUNCTION("comm2.c:   DeleteLine");
 /*---------------------------------------------------------------------*/
 /* If no parameter is supplied, 1 is assumed.                          */
 /*---------------------------------------------------------------------*/
@@ -260,9 +246,7 @@ CHARTYPE *params;
  if ((rc = validate_target(args,&target,target_type,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
    {
     free_target(&target);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
@@ -278,9 +262,7 @@ CHARTYPE *params;
       {
        free_target(&target);
        box_operations(BOX_D,SOURCE_BLOCK_RESET,FALSE,' ');
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OK);
       }
     start_line = MARK_VIEW->mark_start_line;
@@ -321,9 +303,7 @@ CHARTYPE *params;
     if (CURRENT_BOF || CURRENT_TOF)
        rc = RC_TOF_EOF_REACHED;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -404,13 +384,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
    short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("comm2.c:   Dialog");
-#endif
+   TRACE_FUNCTION("comm2.c:   Dialog");
    rc = prepare_dialog( params, FALSE, "DIALOG" );
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
  return(rc);
 }
 
@@ -455,9 +431,7 @@ CHARTYPE *params;
  unsigned short num_params=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Directory");
-#endif
+ TRACE_FUNCTION("comm2.c:   Directory");
 /*---------------------------------------------------------------------*/
 /* Validate the parameters that have been supplied. The one and only   */
 /* parameter should be the directory to display.                       */
@@ -467,9 +441,7 @@ CHARTYPE *params;
  if (num_params > 1)
    {
     display_error(1,(CHARTYPE *)word[1],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -478,9 +450,7 @@ CHARTYPE *params;
  if ((rc = splitpath(strrmdup(strtrans(word[0],OSLASH,ISLASH),ISLASH,TRUE))) != RC_OK)
    {
     display_error(10,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  if ((rc = read_directory()) != RC_OK)
@@ -489,9 +459,7 @@ CHARTYPE *params;
        display_error(10,(CHARTYPE *)word[0],FALSE);
     else
        display_error(9,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 #if 0
@@ -508,9 +476,7 @@ CHARTYPE *params;
 #endif
  Xedit(temp_cmd);
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -644,9 +610,7 @@ CHARTYPE *params;
  short target_type=TARGET_NORMAL|TARGET_BLOCK_CURRENT|TARGET_ALL;
  bool lines_based_on_scope=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Duplicate");
-#endif
+ TRACE_FUNCTION("comm2.c:   Duplicate");
  strip[0]=STRIP_BOTH;
  strip[1]=STRIP_LEADING;
  num_params = param_split(params,word,DUP_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
@@ -669,9 +633,7 @@ CHARTYPE *params;
  if (!valid_integer(word[0]))
    {
     display_error(4,word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
  num_occ = atoi((DEFCHAR *)word[0]);
@@ -682,9 +644,7 @@ CHARTYPE *params;
  if ((rc = validate_target(word[1],&target,target_type,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
    {
     free_target(&target);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
@@ -699,9 +659,7 @@ CHARTYPE *params;
          if (MARK_VIEW->mark_type == M_BOX)
            {
             display_error(48,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-            trace_return();
-#endif
+            TRACE_RETURN();
             return(RC_INVALID_ENVIRON);
            }
          command_source = SOURCE_BLOCK;
@@ -730,9 +688,7 @@ CHARTYPE *params;
                             CURRENT_VIEW,CURRENT_VIEW,lines_based_on_scope,
                             &lines_affected);
  free_target(&target);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 
@@ -828,18 +784,14 @@ CHARTYPE *params;
  short rc=RC_OK;
  bool editv_file = FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   THEEditv");
-#endif
+ TRACE_FUNCTION("comm2.c:   THEEditv");
  strip[0] = STRIP_BOTH;
  strip[1] = STRIP_LEADING;
  num_params = param_split(params,word,EDITV_PARAMS,WORD_DELIMS,TEMP_PARAM,strip,FALSE);
  if (num_params == 0)
    {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -898,9 +850,7 @@ CHARTYPE *params;
  else
    {
     display_error(1,word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -910,9 +860,7 @@ CHARTYPE *params;
  &&  num_params == 1)
    {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -924,16 +872,12 @@ CHARTYPE *params;
     if (!in_macro)
       {
        display_error(53,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_ENVIRON);
       }
    }
  rc = execute_editv(editv_type,editv_file,word[1]);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 
@@ -968,13 +912,9 @@ CHARTYPE *params;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Emsg");
-#endif
+ TRACE_FUNCTION("comm2.c:   Emsg");
  display_error(0,params,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -982,7 +922,7 @@ COMMAND
      enter - execute a command
 
 SYNTAX
-     enter
+     enter [CUA]
 
 DESCRIPTION
      The ENTER command executes the command currently displayed on the
@@ -997,6 +937,9 @@ DESCRIPTION
      This command can only be used by assigning it to a function key
      with the <DEFINE> command.
 
+     With the optional 'CUA' argument, when in the <FILEAREA>, the enter
+     command acts like the <SPLIT> command.
+
      This command will be removed in a future version.
 
 COMPATIBILITY
@@ -1004,7 +947,7 @@ COMPATIBILITY
      KEDIT: N/A
 
 SEE ALSO
-     <SOS EXECUTE>
+     <SOS EXECUTE>, <ENTER>
 
 STATUS
      Complete.
@@ -1018,49 +961,68 @@ CHARTYPE *params;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- unsigned short x=0,y=0;
- short rc=RC_OK;
+   unsigned short x=0,y=0;
+   short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Enter");
-#endif
- switch(CURRENT_VIEW->current_window)
+   TRACE_FUNCTION("comm2.c:   Enter");
+   switch(CURRENT_VIEW->current_window)
    {
-    case WINDOW_COMMAND:
+      case WINDOW_COMMAND:
          rc = Sos_execute((CHARTYPE *)"");
          break;
-    case WINDOW_PREFIX:
+      case WINDOW_PREFIX:
          post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
          if (CURRENT_FILE->first_ppc == NULL)/* no pending prefix cmds */
-           {
+         {
             THEcursor_down(TRUE);
             rc = Sos_firstcol((CHARTYPE *)"");
-           }
+         }
          else
             Sos_doprefix((CHARTYPE *)"");
          break;
-    case WINDOW_FILEAREA:
-/*---------------------------------------------------------------------*/
-/* If in readonly mode, ignore new line addition...                    */
-/*---------------------------------------------------------------------*/
+      case WINDOW_FILEAREA:
+      /*
+       * If in readonly mode, ignore new line addition...
+       */
          if (!ISREADONLY(CURRENT_FILE))
-           {
-            if (CURRENT_VIEW->inputmode == INPUTMODE_LINE)
-              {
-               post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
-               insert_new_line((CHARTYPE *)"",0,1,get_true_line(FALSE),FALSE,FALSE,TRUE,CURRENT_VIEW->display_low,TRUE,TRUE);
-               break;
-              }
-           }
+         {
+            if ( equal((CHARTYPE *)"cua", params, 3 ) )
+            {
+               /*
+                * Split the line at the cursor position
+                * move the cursor to the first character of the FILEAREA
+                */
+               if ( CURRENT_VIEW->newline_aligned )
+               {
+                  rc = execute_split_join(SPLTJOIN_SPLIT,TRUE,TRUE);
+                  rc = Sos_firstchar((CHARTYPE *)"");
+               }
+               else
+               {
+                  rc = execute_split_join(SPLTJOIN_SPLIT,FALSE,TRUE);
+                  rc = Sos_firstcol((CHARTYPE *)"");
+               }
+               THEcursor_down(TRUE);
+               TRACE_RETURN();
+               return(rc);
+            }
+            else
+            {
+               if (CURRENT_VIEW->inputmode == INPUTMODE_LINE)
+               {
+                  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
+                  insert_new_line((CHARTYPE *)"",0,1,get_true_line(FALSE),FALSE,FALSE,TRUE,CURRENT_VIEW->display_low,TRUE,TRUE);
+                  break;
+               }
+            }
+         }
          THEcursor_down(TRUE);
          getyx(CURRENT_WINDOW,y,x);
          wmove(CURRENT_WINDOW,y,0);
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
 /*man-start*********************************************************************
 COMMAND
@@ -1095,13 +1057,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Expand");
-#endif
+ TRACE_FUNCTION("comm2.c:   Expand");
  rc = execute_expand_compress(params,TRUE,TRUE,TRUE,TRUE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1145,16 +1103,12 @@ CHARTYPE *params;
    bool invalid_item=FALSE;
    CHARTYPE item_type=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("comm2.c:   Extract");
-#endif
+   TRACE_FUNCTION("comm2.c:   Extract");
    if (!in_macro
    ||  !rexx_support)
    {
       display_error(53,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-      trace_return();
-#endif
+      TRACE_RETURN();
       return(RC_INVALID_ENVIRON);
    }
 /*---------------------------------------------------------------------*/
@@ -1177,9 +1131,7 @@ CHARTYPE *params;
    if (invalid_item)
    {
       display_error(1,params,FALSE);
-#ifdef THE_TRACE
-      trace_return();
-#endif
+      TRACE_RETURN();
       return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -1224,9 +1176,7 @@ CHARTYPE *params;
       ||  !(item_type & QUERY_EXTRACT))
        {
           display_error(1,params,FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
        }
 /*---------------------------------------------------------------------*/
@@ -1238,9 +1188,7 @@ CHARTYPE *params;
 /*---------------------------------------------------------------------*/
       if (num_values == EXTRACT_ARG_ERROR)
       {
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(RC_INVALID_OPERAND);
       }
 /*---------------------------------------------------------------------*/
@@ -1255,9 +1203,7 @@ CHARTYPE *params;
       params += arglen+1;
    }
 
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return(rc);
 }
 
@@ -1298,15 +1244,11 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Ffile");
-#endif
+ TRACE_FUNCTION("comm2.c:   Ffile");
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
  if ((rc = save_file(CURRENT_FILE,params,TRUE,CURRENT_FILE->number_lines,1L,NULL,FALSE,0,max_line_length,TRUE,FALSE,FALSE)) != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
@@ -1315,9 +1257,7 @@ CHARTYPE *params;
  if (CURRENT_FILE->autosave > 0)
     rc = remove_aus_file(CURRENT_FILE);
  free_view_memory(TRUE,TRUE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1357,9 +1297,7 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   File");
-#endif
+ TRACE_FUNCTION("comm2.c:   File");
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
 /*---------------------------------------------------------------------*/
 /* If we are filing the current file with the same name AND the number */
@@ -1374,9 +1312,7 @@ CHARTYPE *params;
    {
     if ((rc = save_file(CURRENT_FILE,params,FALSE,CURRENT_FILE->number_lines,1L,NULL,FALSE,0,max_line_length,TRUE,FALSE,FALSE)) != RC_OK)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(rc);
       }
 /*---------------------------------------------------------------------*/
@@ -1386,9 +1322,7 @@ CHARTYPE *params;
        rc = remove_aus_file(CURRENT_FILE);
     free_view_memory(TRUE,TRUE);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1421,70 +1355,76 @@ CHARTYPE *params;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- CHARTYPE chr=0;
- short len_params=0;
- short y=0,x=0;
+   int key=0;
+   short len_params=0;
+   short y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Fillbox");
-#endif
- post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
+   TRACE_FUNCTION("comm2.c:   Fillbox");
+   post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
 /*---------------------------------------------------------------------*/
 /* Validate the marked block.                                          */
 /*---------------------------------------------------------------------*/
- if (marked_block(TRUE) != RC_OK)
+   if (marked_block(TRUE) != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_ENVIRON);
+      TRACE_RETURN();
+      return(RC_INVALID_ENVIRON);
    }
 /*---------------------------------------------------------------------*/
 /* Check if hex on in effect and translate hex char if required...     */
 /*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->hex)
+   if (CURRENT_VIEW->hex)
    {
-    if ((len_params = convert_hex_strings(params)) == (-1))
+      if ((len_params = convert_hex_strings(params)) == (-1))
       {
-       display_error(32,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
-       return(RC_INVALID_OPERAND);
+         display_error(32,params,FALSE);
+         TRACE_RETURN();
+         return(RC_INVALID_OPERAND);
       }
    }
- else
-   len_params = strlen((DEFCHAR *)params);
+   else
+      len_params = strlen((DEFCHAR *)params);
 /*---------------------------------------------------------------------*/
 /* Whew, now do something...                                           */
 /*---------------------------------------------------------------------*/
- if (len_params > 1)
+   if (len_params > 1)
    {
-    display_error(1,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_OPERAND);
+      display_error(1,params,FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_OPERAND);
    }
- if (len_params == 0)
-    chr = ' ';
- else
-    chr = *(params);
- if (CURRENT_VIEW->current_window != WINDOW_COMMAND
- && len_params != 1) 
+   if (len_params == 0)
+      key = (int)' ';
+   else
+      key = (int)*(params);
+   if (CURRENT_VIEW->current_window != WINDOW_COMMAND
+   && len_params != 1) 
    {
-    getyx(CURRENT_WINDOW,y,x);
-    display_prompt((CHARTYPE *)"Enter fill character...");
-    wmove(CURRENT_WINDOW_FILEAREA,y,x);
-    wrefresh(CURRENT_WINDOW_FILEAREA);
-    chr = (CHARTYPE)my_getch(stdscr);
-    clear_msgline(-1);
-   }
- box_operations(BOX_F,SOURCE_BLOCK,TRUE,chr);
-#ifdef THE_TRACE
- trace_return();
+      getyx(CURRENT_WINDOW,y,x);
+      display_prompt((CHARTYPE *)"Enter fill character...");
+      wmove(CURRENT_WINDOW_FILEAREA,y,x);
+      wrefresh(CURRENT_WINDOW_FILEAREA);
+      while(1)
+      {
+         key = my_getch(stdscr);
+#if defined(XCURSES) && PDC_BUILD >= 2501
+         if ( key == ERR )
+         {
+            /*
+             * Send the X11 process a display_cursor message
+             * This blinks the cursor.
+             */
+            PDC_curs_set(-1);
+            continue;
+         }
 #endif
- return(RC_OK);
+         if ( !is_modifier_key( key ) )
+            break;
+      }
+      clear_msgline(-1);
+   }
+   box_operations(BOX_F,SOURCE_BLOCK,TRUE,(CHARTYPE)key);
+   TRACE_RETURN();
+   return(RC_OK);
 }
 /*man-start*********************************************************************
 COMMAND
@@ -1523,13 +1463,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Find");
-#endif
+ TRACE_FUNCTION("comm2.c:   Find");
  rc = execute_find_command(params,TARGET_FIND);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1569,13 +1505,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Findup");
-#endif
+ TRACE_FUNCTION("comm2.c:   Findup");
  rc = execute_find_command(params,TARGET_FINDUP);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1624,9 +1556,7 @@ CHARTYPE *params;
  LINETYPE num_pages=0L;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Forward");
-#endif
+ TRACE_FUNCTION("comm2.c:   Forward");
 /*---------------------------------------------------------------------*/
 /* Validate parameters...                                              */
 /*---------------------------------------------------------------------*/
@@ -1640,9 +1570,7 @@ CHARTYPE *params;
  if (num_params != 1)
     {
      display_error(1,(CHARTYPE *)word[1],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
      return(RC_INVALID_OPERAND);
     }
 /*---------------------------------------------------------------------*/
@@ -1651,9 +1579,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)word[0],"*") == 0)
    {
     rc = Bottom((CHARTYPE *)"");
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
@@ -1662,9 +1588,7 @@ CHARTYPE *params;
  if (!valid_integer(word[0]))
    {
     display_error(1,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -1677,9 +1601,7 @@ CHARTYPE *params;
  if (num_pages < 0L)
    {
     display_error(5,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -1690,18 +1612,14 @@ CHARTYPE *params;
  || CURRENT_BOF)
    {
     rc = Top((CHARTYPE *)"");
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
 /* Scroll the screen num_pages...                                      */
 /*---------------------------------------------------------------------*/
  rc = scroll_page(DIRECTION_FORWARD,num_pages,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1785,9 +1703,7 @@ CHARTYPE *params;
  LINETYPE fromline=1L,numlines=0L;
  bool clip=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Get");
-#endif
+ TRACE_FUNCTION("comm2.c:   Get");
 /*---------------------------------------------------------------------*/
 /* Validate the parameters that have been supplied.                    */
 /*---------------------------------------------------------------------*/
@@ -1798,9 +1714,7 @@ CHARTYPE *params;
  if (num_params > 3)
  {
     display_error(2,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
  }
  if (num_params == 0)
@@ -1816,9 +1730,7 @@ CHARTYPE *params;
        if ((rc = splitpath(strrmdup(strtrans(word[0],OSLASH,ISLASH),ISLASH,TRUE))) != RC_OK)
        {
           display_error(10,word[0],FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(rc);
        }
        strcpy((DEFCHAR *)temp_cmd,(DEFCHAR *)sp_path);
@@ -1830,18 +1742,14 @@ CHARTYPE *params;
           if (!valid_positive_integer(word[1]))
           {
              display_error(4,word[1],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_OPERAND);
           }
           fromline = atol((DEFCHAR *)word[1]);
           if (fromline == 0L)
           {
              display_error(4,word[1],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_OPERAND);
           }
        }
@@ -1854,9 +1762,7 @@ CHARTYPE *params;
              if (!valid_positive_integer(word[2]))
              {
                 display_error(4,word[2],FALSE);
-#ifdef THE_TRACE
-                trace_return();
-#endif
+                TRACE_RETURN();
                 return(RC_INVALID_OPERAND);
              }
              else
@@ -1873,18 +1779,14 @@ CHARTYPE *params;
    if (!file_readable(filename))
    {
       display_error(8,filename,FALSE);
-#ifdef THE_TRACE
-      trace_return();
-#endif
+      TRACE_RETURN();
       return(RC_ACCESS_DENIED);
    }
 
    if ((fp = fopen((DEFCHAR *)filename,"r")) == NULL)
    {
       display_error(9,params,FALSE);
-#ifdef THE_TRACE
-      trace_return();
-#endif
+      TRACE_RETURN();
       return(RC_ACCESS_DENIED);
    }
  }
@@ -1911,9 +1813,7 @@ CHARTYPE *params;
     pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
     if (!clip)
        fclose(fp);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_ACCESS_DENIED);
  }
 
@@ -1934,9 +1834,7 @@ CHARTYPE *params;
 
  build_screen(current_screen); 
  display_screen(current_screen);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -1970,18 +1868,14 @@ CHARTYPE *params;
  static bool first=TRUE;
  char *envptr=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Help");
-#endif
+ TRACE_FUNCTION("comm2.c:   Help");
 /*---------------------------------------------------------------------*/
 /* No arguments are allowed; error if any are present.                 */
 /*---------------------------------------------------------------------*/
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -2002,15 +1896,11 @@ CHARTYPE *params;
  if (!file_exists(the_help_file))
    {
     display_error(23,(CHARTYPE *)the_help_file,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_FILE_NOT_FOUND);
    }
  Xedit(the_help_file);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -2054,9 +1944,7 @@ CHARTYPE *params;
  bool save_in_macro=in_macro;
  bool mouse_details_present=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Hit");
-#endif
+ TRACE_FUNCTION("comm2.c:   Hit");
 /*---------------------------------------------------------------------*/
 /* Prase the parameters into multiple words. If only one word then it  */
 /* must be a key.  If 3 words its a mouse key, otherwise asn error.    */
@@ -2073,9 +1961,7 @@ CHARTYPE *params;
        if (key == (-1))
        {
           display_error(13,params,FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
        }
        break;
@@ -2083,16 +1969,12 @@ CHARTYPE *params;
        if (!equal((CHARTYPE *)"in",word[1],2))
        {
           display_error(1,word[1],FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
        }
        if ((key = find_mouse_key_value(word[0],word[2])) == (-1))
        {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
        }
        mouse_details_present = TRUE;
@@ -2109,9 +1991,7 @@ CHARTYPE *params;
  if (number_of_files == 0)
     rc = RC_INVALID_ENVIRON;
  /* how to exit ???? */
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -2152,18 +2032,14 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  LINETYPE len_params=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Input");
-#endif
+ TRACE_FUNCTION("comm2.c:   Input");
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
  if (CURRENT_VIEW->hex)
    {
     if ((len_params = (LINETYPE)convert_hex_strings(params)) == (-1))
       {
        display_error(32,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
    }
@@ -2175,9 +2051,7 @@ CHARTYPE *params;
     len_params = (LINETYPE)max_line_length;
    }
  insert_new_line(params,(unsigned short)len_params,1L,get_true_line(TRUE),TRUE,TRUE,TRUE,CURRENT_VIEW->display_low,TRUE,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -2229,9 +2103,7 @@ CHARTYPE *params;
  bool aligned=FALSE;
  bool cursorarg=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Join");
-#endif
+ TRACE_FUNCTION("comm2.c:   Join");
 /*---------------------------------------------------------------------*/
 /* Split parameters up...                                              */
 /*---------------------------------------------------------------------*/
@@ -2261,9 +2133,7 @@ CHARTYPE *params;
           else
             {
              display_error(1,(CHARTYPE *)word[1],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_ENVIRON);
             }
          }
@@ -2285,17 +2155,13 @@ CHARTYPE *params;
           else
             {
              display_error(1,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_ENVIRON);
             }
          }
       }
    }
  rc = execute_split_join(SPLTJOIN_JOIN,aligned,cursorarg);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
