@@ -38,7 +38,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: comm3.c,v 1.3 1999/07/31 05:49:13 mark Exp mark $";
+static char RCSid[] = "$Id: comm3.c,v 1.2 2000/12/09 21:30:40 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -114,9 +114,7 @@ CHARTYPE *params;
  short rc=RC_OK;
  LINETYPE shift_val=1L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Left");
-#endif
+ TRACE_FUNCTION("comm3.c:   Left");
 /*---------------------------------------------------------------------*/
 /* Validate only parameter, HALF or positive integer. 1 if no argument.*/
 /*---------------------------------------------------------------------*/
@@ -138,9 +136,7 @@ CHARTYPE *params;
  if (shift_val == 1)                               /* invalid argument */
    {
     display_error(1,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -155,9 +151,7 @@ CHARTYPE *params;
 #endif
  build_screen(current_screen);
  display_screen(current_screen);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -194,9 +188,7 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Locate");
-#endif
+ TRACE_FUNCTION("comm3.c:   Locate");
 /*---------------------------------------------------------------------*/
 /* If no parameter is specified, use the last_target. If that doesn't  */
 /* exist, error.                                                       */
@@ -206,21 +198,15 @@ CHARTYPE *params;
     if (blank_field(last_target))
       {
        display_error(39,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     rc = command_line(last_target,COMMAND_ONLY_FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  rc = command_line(params,COMMAND_ONLY_FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -256,13 +242,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Lowercase");
-#endif
+ TRACE_FUNCTION("comm3.c:   Lowercase");
  rc = execute_change_case(params,CASE_LOWER);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -307,9 +289,7 @@ DESCRIPTION
 
      With the optional '?' parameter, interactive tracing of the Rexx
      macro is possible, but this does not set interactive tracing on;
-     you still must do that with "THE_TRACE ?".
 
-COMPATIBILITY
      XEDIT: Compatible.
      KEDIT: Compatible.
 
@@ -328,13 +308,9 @@ CHARTYPE *params;
  short rc=RC_OK;
  short macrorc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Macro");
-#endif
+ TRACE_FUNCTION("comm3.c:   Macro");
  rc = execute_macro(params,TRUE,&macrorc);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((rc==RC_SYSTEM_ERROR)?rc:macrorc);
 }
 /*man-start*********************************************************************
@@ -405,9 +381,7 @@ CHARTYPE *params;
  LENGTHTYPE cont_len=0;
  int num[5];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Mark");
-#endif
+ TRACE_FUNCTION("comm3.c:   Mark");
  /*
   * Do this rather than define numparams[6] = {0,3,5,5,3,3} so that
   * non-ansi compilers won't barf.
@@ -464,9 +438,7 @@ CHARTYPE *params;
  else 
  {
     display_error(1,(CHARTYPE *)word[0],FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
  }
 /*---------------------------------------------------------------------*/
@@ -481,9 +453,7 @@ CHARTYPE *params;
     if (TOF(true_line) || BOF(true_line))
       {
        display_error(38,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_ENVIRON);
       }
 /*---------------------------------------------------------------------*/
@@ -497,9 +467,7 @@ CHARTYPE *params;
        if (CURRENT_SCREEN.sl[y].line_type != LINE_LINE)
          {
           display_error(38,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_ENVIRON);
          }
       }
@@ -634,17 +602,13 @@ CHARTYPE *params;
     if (num_params < numparms[mark_type])
     {
        display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
     }
     if (num_params > numparms[mark_type])
     {
        display_error(2,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
     }
 /*---------------------------------------------------------------------*/
@@ -658,26 +622,20 @@ CHARTYPE *params;
           if (num[i] > nummax[mark_type][i])
           {
              display_error(6,word[i],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_OPERAND);
           }
           if (num[i] == 0)
           {
              display_error(5,word[i],FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_OPERAND);
           }
        }
        else
        {
           display_error(1,word[i],FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
        }
     }
@@ -786,9 +744,7 @@ CHARTYPE *params;
     build_screen(current_screen); 
     display_screen(current_screen);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -823,14 +779,10 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Modify");
-#endif
+ TRACE_FUNCTION("comm3.c:   Modify");
  if ((rc = execute_modify_command(params)) == RC_OK)
     Cmsg(temp_cmd);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -883,26 +835,20 @@ CHARTYPE *params;
  LINETYPE start_line=0L,end_line=0L,num_lines=0L,dest_line=0L,lines_affected=0L;
  VIEW_DETAILS *old_mark_view=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   THEMove");
-#endif
+ TRACE_FUNCTION("comm3.c:   THEMove");
 /*---------------------------------------------------------------------*/
 /* This command invalid if source file is readonly...                  */
 /*---------------------------------------------------------------------*/
  if (!MARK_VIEW)
  {
     display_error(44,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
  }
  if (ISREADONLY(MARK_FILE))
  {
     display_error(56,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
  }
  strip[0]=STRIP_BOTH;
@@ -911,17 +857,13 @@ CHARTYPE *params;
  if (num_params == 0)
  {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
  }
  if (num_params > 2)
  {
     display_error(2,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
  }
 /*---------------------------------------------------------------------*/
@@ -937,9 +879,7 @@ CHARTYPE *params;
  if (reset_block == SOURCE_UNKNOWN)
  {
     display_error(1,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
  }
 /*---------------------------------------------------------------------*/
@@ -947,9 +887,7 @@ CHARTYPE *params;
 /*---------------------------------------------------------------------*/
  if (marked_block(FALSE) != RC_OK)
  {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
  }
 /*---------------------------------------------------------------------*/
@@ -971,9 +909,7 @@ CHARTYPE *params;
           &&  (x + CURRENT_VIEW->verify_col <= MARK_VIEW->mark_end_col))
           {
              display_error(50,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_INVALID_ENVIRON);
           }
           break;
@@ -990,9 +926,7 @@ CHARTYPE *params;
  ||  MARK_VIEW->mark_type == M_COLUMN)
  {
     box_operations(BOX_M,reset_block,FALSE,' ');/* don't reset and don't overlay */
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
  }
 /*---------------------------------------------------------------------*/
@@ -1042,9 +976,7 @@ CHARTYPE *params;
                             end_line,start_line,1,old_mark_view,old_mark_view,FALSE,
                             &lines_affected);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1080,13 +1012,9 @@ CHARTYPE *params;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Msg");
-#endif
+ TRACE_FUNCTION("comm3.c:   Msg");
  display_error(0,params,TRUE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -1126,9 +1054,7 @@ CHARTYPE *params;
  short rc=RC_OK;
  LINETYPE num_lines=0L,true_line=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   THENext");
-#endif
+ TRACE_FUNCTION("comm3.c:   THENext");
  params = MyStrip(params,STRIP_BOTH,' ');
  if (strcmp("",(DEFCHAR *)params) == 0)
     params = (CHARTYPE *)"1";
@@ -1140,25 +1066,19 @@ CHARTYPE *params;
     if (!valid_integer(params))
       {
        display_error(4,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     num_lines = atol((DEFCHAR *)params);
     if (num_lines < 0L)
       {
        display_error(5,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
    }
  rc = advance_current_or_focus_line(num_lines);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1194,23 +1114,17 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Nextwindow");
-#endif
+ TRACE_FUNCTION("comm3.c:   Nextwindow");
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
  if (display_screens == 1)
    {
     rc = Xedit((CHARTYPE *)"");
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
@@ -1257,9 +1171,7 @@ CHARTYPE *params;
    }
  display_screen(current_screen);
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -1299,13 +1211,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Nfind");
-#endif
+ TRACE_FUNCTION("comm2.c:   Nfind");
  rc = execute_find_command(params,TARGET_NFIND);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1345,13 +1253,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm2.c:   Nfindup");
-#endif
+ TRACE_FUNCTION("comm2.c:   Nfindup");
  rc = execute_find_command(params,TARGET_NFINDUP);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1407,15 +1311,11 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Nomsg");
-#endif
+ TRACE_FUNCTION("comm3.c:   Nomsg");
  in_nomsg = TRUE;
  rc = command_line(params,COMMAND_ONLY_FALSE);
  in_nomsg = FALSE;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1449,23 +1349,17 @@ CHARTYPE *params;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Nop");
-#endif
+ TRACE_FUNCTION("comm3.c:   Nop");
 /*---------------------------------------------------------------------*/
 /* No arguments are allowed; error if any are present.                 */
 /*---------------------------------------------------------------------*/
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -1500,17 +1394,13 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Os");
-#endif
+ TRACE_FUNCTION("comm3.c:   Os");
 /*---------------------------------------------------------------------*/
 /* Execute the supplied parameters as OS commands. Run with output     */
 /* displayed and pause before redrawing the windows.                   */
 /*---------------------------------------------------------------------*/
  rc = execute_os_command(params,FALSE,TRUE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1546,9 +1436,7 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Osnowait");
-#endif
+ TRACE_FUNCTION("comm3.c:   Osnowait");
 /*---------------------------------------------------------------------*/
 /* Execute the supplied parameters as OS commands. Run with output     */
 /* displayed but no pause before redrawing the windows.                */
@@ -1556,15 +1444,11 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") == 0)          /* no params....error */
    {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
  rc = execute_os_command(params,FALSE,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1599,9 +1483,7 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Osquiet");
-#endif
+ TRACE_FUNCTION("comm3.c:   Osquiet");
 /*---------------------------------------------------------------------*/
 /* Execute the supplied parameters as OS commands. Run with no output  */
 /* displayed and no pause before redrawing the windows.                */
@@ -1609,15 +1491,11 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") == 0)          /* no params....error */
    {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
  rc = execute_os_command(params,TRUE,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1664,9 +1542,7 @@ CHARTYPE *params;
 #endif
  int fd=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Osredir");
-#endif
+ TRACE_FUNCTION("comm3.c:   Osredir");
 /*---------------------------------------------------------------------*/
 /* Execute the supplied parameters as OS commands. Run with no output  */
 /* displayed and no pause before redrawing the windows.                */
@@ -1677,17 +1553,13 @@ CHARTYPE *params;
  if (num_params == 0)
     {
      display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-     trace_return();
-#endif
+     TRACE_RETURN();
      return(RC_INVALID_OPERAND);
     }
  if (num_params > 2)
     {
      display_error(2,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-     trace_return();
-#endif
+     TRACE_RETURN();
      return(RC_INVALID_OPERAND);
     }
  save_stdout = dup(fileno(stdout));
@@ -1701,9 +1573,7 @@ CHARTYPE *params;
  if (fd == (-1))
     {
      display_error(8,word[0],FALSE);
-#ifdef THE_TRACE
-     trace_return();
-#endif
+     TRACE_RETURN();
      return(RC_INVALID_OPERAND);
     }
 #ifdef UNIX
@@ -1720,12 +1590,11 @@ CHARTYPE *params;
  dup2(save_stderr,fileno(stderr));
 #ifdef UNIX
  dup2(save_stdin,fileno(stdin)); 
+ close(save_stdin);
 #endif
  close(save_stdout);
  close(save_stderr);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1762,130 +1631,116 @@ CHARTYPE *params;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- unsigned short y=0,x=0;
- LINETYPE true_line=0L,start_line=0L,end_line=0L,num_lines=0L,dest_line=0L,lines_affected=0L;
- VIEW_DETAILS *old_mark_view=NULL;
- short rc=RC_OK;
- LINE *curr=NULL;
- LINETYPE save_current_line=CURRENT_VIEW->current_line;
+   unsigned short y=0,x=0;
+   LINETYPE true_line=0L,start_line=0L,end_line=0L,num_lines=0L,dest_line=0L,lines_affected=0L;
+   VIEW_DETAILS *old_mark_view=NULL;
+   short rc=RC_OK;
+   LINE *curr=NULL;
+   LINETYPE save_current_line=CURRENT_VIEW->current_line;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm3.c:   Overlaybox");
-#endif
-/*---------------------------------------------------------------------*/
-/* Ensure there are no parameters.                                     */
-/*---------------------------------------------------------------------*/
- if (strcmp((DEFCHAR *)params,"") != 0)
+   TRACE_FUNCTION("comm3.c:   Overlaybox");
+   /*
+    * Ensure there are no parameters.
+    */
+   if (strcmp((DEFCHAR *)params,"") != 0)
    {
-    display_error(1,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+      display_error(1,params,FALSE);
+      TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
-/*---------------------------------------------------------------------*/
-/* Validate marked block, can be in any view.                          */
-/*---------------------------------------------------------------------*/
- if (marked_block(FALSE) != RC_OK)
+   /*
+    * Validate marked block, can be in any view.
+    */
+   if (marked_block(FALSE) != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_ENVIRON);
+      TRACE_RETURN();
+      return(RC_INVALID_ENVIRON);
    }
-/*---------------------------------------------------------------------*/
-/* Don't allow for multi-line STREAM blocks.                           */
-/*---------------------------------------------------------------------*/
- if (MARK_VIEW->mark_type == M_STREAM
- &&  MARK_VIEW->mark_start_line != MARK_VIEW->mark_end_line)
+   /*
+    * Don't allow for multi-line STREAM blocks.
+    */
+   if (MARK_VIEW->mark_type == M_STREAM
+   &&  MARK_VIEW->mark_start_line != MARK_VIEW->mark_end_line)
    {
-    display_error(62,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_ENVIRON);
+      display_error(62,(CHARTYPE *)"",FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_ENVIRON);
    }
-/*---------------------------------------------------------------------*/
-/* If the command is executed from the filearea, the focus line must be*/
-/* in scope...                                                         */
-/*---------------------------------------------------------------------*/
- if (curses_started)
+   /*
+    * If the command is executed from the filearea, the focus line must be
+    * in scope...
+    */
+   if (curses_started)
    {
-    if (CURRENT_VIEW->current_window != WINDOW_COMMAND)
+      if (CURRENT_VIEW->current_window != WINDOW_COMMAND)
       {
-       getyx(CURRENT_WINDOW,y,x);
-       if (!IN_SCOPE(CURRENT_VIEW,CURRENT_SCREEN.sl[y].current)
-       && !CURRENT_VIEW->scope_all)
+         getyx(CURRENT_WINDOW,y,x);
+         if (!IN_SCOPE(CURRENT_VIEW,CURRENT_SCREEN.sl[y].current)
+         && !CURRENT_VIEW->scope_all)
          {
-          display_error(87,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
-          return(RC_INVALID_ENVIRON);
+            display_error(87,(CHARTYPE *)"",FALSE);
+            TRACE_RETURN();
+            return(RC_INVALID_ENVIRON);
          }
       }
    }
-/*---------------------------------------------------------------------*/
-/* If block is a box, call its function.                               */
-/*---------------------------------------------------------------------*/
- if (MARK_VIEW->mark_type != M_LINE)
+   /*
+    * If block is a box, call its function.
+    */
+   if (MARK_VIEW->mark_type != M_LINE)
    {
-    box_operations(BOX_C,SOURCE_BLOCK,TRUE,' ');  /* no reset, overlay */
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      box_operations(BOX_C,SOURCE_BLOCK,TRUE,' ');  /* no reset, overlay */
+      TRACE_RETURN();
+      return(RC_OK);
    }
-/*---------------------------------------------------------------------*/
-/* Determine the target line. If on the command line, target is current*/
-/* line, else target line is focus line.                               */
-/*---------------------------------------------------------------------*/
- true_line = get_true_line(TRUE);
+   /*
+    * Determine the target line. If on the command line, target is current
+    * line, else target line is focus line.
+    */
+   true_line = get_true_line(TRUE);
 
- post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
- start_line = MARK_VIEW->mark_start_line;
- end_line = MARK_VIEW->mark_end_line;
- num_lines = end_line - start_line + 1L;
- dest_line = true_line-1L;
- old_mark_view = MARK_VIEW;
+   post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
+   start_line = MARK_VIEW->mark_start_line;
+   end_line = MARK_VIEW->mark_end_line;
+   num_lines = end_line - start_line + 1L;
+   dest_line = true_line-1L;
+   old_mark_view = MARK_VIEW;
 
- rc = rearrange_line_blocks(COMMAND_OVERLAY_COPY,SOURCE_BLOCK,start_line,
+   rc = rearrange_line_blocks(COMMAND_OVERLAY_COPY,SOURCE_BLOCK,start_line,
                             end_line,dest_line,1,MARK_VIEW,CURRENT_VIEW,FALSE,
                             &lines_affected);
- if (rc == RC_OK
- &&  lines_affected != 0)
+   if (rc == RC_OK
+   &&  lines_affected != 0)
    {
-    start_line = end_line = true_line + lines_affected;
-    curr = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,start_line,CURRENT_FILE->number_lines);
-    while(1)
+      start_line = end_line = true_line + lines_affected;
+      curr = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,start_line,CURRENT_FILE->number_lines);
+      for ( ; ; )
       {
-       if (CURRENT_VIEW->scope_all
-       ||  IN_SCOPE(CURRENT_VIEW,curr))
-          lines_affected--;
-       curr = curr->next;
-       if (curr == NULL
-       ||  lines_affected == 0L
-       ||  end_line == CURRENT_FILE->number_lines)
-          break;
-       end_line++;
+         if (CURRENT_VIEW->scope_all
+         ||  IN_SCOPE(CURRENT_VIEW,curr))
+            lines_affected--;
+         curr = curr->next;
+         if (curr == NULL
+         ||  lines_affected == 0L
+         ||  end_line == CURRENT_FILE->number_lines)
+            break;
+         end_line++;
       }
-    dest_line = true_line;
-    post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
-    rc = rearrange_line_blocks(COMMAND_OVERLAY_DELETE,SOURCE_BLOCK,start_line,
+      dest_line = true_line;
+      post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
+      rc = rearrange_line_blocks(COMMAND_OVERLAY_DELETE,SOURCE_BLOCK,start_line,
                             end_line,dest_line,1,CURRENT_VIEW,CURRENT_VIEW,FALSE,
                             &lines_affected);
-    if (old_mark_view != MARK_VIEW)
-       old_mark_view->marked_line = old_mark_view->marked_col = FALSE;
+      if (old_mark_view != MARK_VIEW)
+         old_mark_view->marked_line = old_mark_view->marked_col = FALSE;
    }
- CURRENT_VIEW->current_line = save_current_line;
- build_screen(current_screen);
- display_screen(current_screen);
- if (curses_started
- && CURRENT_VIEW->current_window != WINDOW_COMMAND)
-   wmove(CURRENT_WINDOW,y,x);
+   CURRENT_VIEW->current_line = save_current_line;
+   build_screen(current_screen);
+   display_screen(current_screen);
+   if (curses_started
+   && CURRENT_VIEW->current_window != WINDOW_COMMAND)
+      wmove(CURRENT_WINDOW,y,x);
 
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
