@@ -38,11 +38,63 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: comm5.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: comm5.c,v 1.2 2000/12/09 22:24:55 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
 
+#ifdef HAVE_PROTO
+static bool ispf_special_lines_entry( short line_type, int ch, CHARTYPE real_key )
+#else
+static bool ispf_special_lines_entry( line_type, ch, real_key )
+short line_type;
+int ch;
+CHARTYPE real_key;
+#endif
+{
+   bool need_to_build_screen=FALSE;
+   /*
+    * In ISPF mode, we need to allow certain characters to be
+    * typed on the TABS line, and the BNDS line
+    * Characters allowed are:
+    * Char     TABS       BNDS
+    *   <       -          Y
+    *   >       -          Y
+    *           Y          Y
+    * etc... TBD
+    *
+    */
+   switch(line_type)
+   {
+      case LINE_BOUNDS:
+         switch( real_key )
+         {
+            case ' ':
+               /*
+                * If the existing character is < or >, then reset that
+                * particular edge of the BNDS
+                */
+               if ( ch == '<' || ch == '>' )
+               {
+                  need_to_build_screen = TRUE;
+               }
+               break;
+            case '<':
+               need_to_build_screen = TRUE;
+               break;
+            case '>':
+               need_to_build_screen = TRUE;
+               break;
+         }
+         break;
+      case LINE_TABLINE:
+         break;
+      default:
+         break;
+   }
+   return need_to_build_screen;
+}
+
 /*#define DEBUG 1*/
 /*man-start*********************************************************************
 COMMAND
@@ -81,18 +133,14 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Tabpre");
-#endif
+ TRACE_FUNCTION("comm5.c:   Tabpre");
 /*---------------------------------------------------------------------*/
 /* No arguments are allowed; error if any are present.                 */
 /*---------------------------------------------------------------------*/
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -101,18 +149,14 @@ CHARTYPE *params;
  if (CURRENT_VIEW->current_window == WINDOW_COMMAND
  ||  !CURRENT_VIEW->prefix)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
  if (CURRENT_VIEW->current_window == WINDOW_FILEAREA)
     rc = Sos_prefix((CHARTYPE *)"");
  else
     rc = Sos_leftedge((CHARTYPE *)"");
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -173,16 +217,12 @@ CHARTYPE *params;
  bool save_scope=FALSE;
  LINETYPE num_lines=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm1.c:   Tag");
-#endif
+ TRACE_FUNCTION("comm1.c:   Tag");
  if (strlen((DEFCHAR *)params) == 0)
  {
     if (CURRENT_FILE->number_lines == 0L)
     {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(rc);
     }
     post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
@@ -196,17 +236,13 @@ CHARTYPE *params;
     }
     build_screen(current_screen); 
     display_screen(current_screen);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
  }
  if (CURRENT_FILE->number_lines == 0L)
  {
     display_error(17,params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_TARGET_NOT_FOUND);
  }
 /*---------------------------------------------------------------------*/
@@ -217,9 +253,7 @@ CHARTYPE *params;
  if (rc != RC_OK)
  {
     free_target(&target);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
  }
 /*---------------------------------------------------------------------*/
@@ -283,9 +317,7 @@ CHARTYPE *params;
        rc = status;
  }
  free_target(&target);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -317,86 +349,93 @@ CHARTYPE *params;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- register short i=0;
- CHARTYPE real_key=0;
- chtype chtype_key=0;
- LENGTHTYPE x=0;
- unsigned short y=0;
- short len_params=0;
- short rc=RC_OK;
+   register short i=0;
+   CHARTYPE real_key=0;
+   chtype chtype_key=0;
+   LENGTHTYPE x=0;
+   unsigned short y=0;
+   short len_params=0;
+   short rc=RC_OK;
+#if defined(HAVE_BROKEN_COLORS)
+   int junky,newx;
+#endif
 #if defined(USE_EXTCURSES)
- ATTR attr=0;
+   ATTR attr=0;
 #else
- chtype attr=0;
+   chtype attr=0;
 #endif
- bool need_to_build_screen=FALSE;
- bool save_in_macro=in_macro;
+   bool need_to_build_screen=FALSE;
+   bool save_in_macro=in_macro;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Text");
-#endif
+   TRACE_FUNCTION("comm5.c:   Text");
 /*---------------------------------------------------------------------*/
 /* If running in read-only mode, do not allow any text to be entered   */
 /* in the main window.                                                 */
 /*---------------------------------------------------------------------*/
- if (ISREADONLY(CURRENT_FILE)
- && CURRENT_VIEW->current_window == WINDOW_FILEAREA)
+   if (ISREADONLY(CURRENT_FILE)
+   && CURRENT_VIEW->current_window == WINDOW_FILEAREA)
    {
-    display_error(56,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_INVALID_ENVIRON);
+      display_error(56,(CHARTYPE *)"",FALSE);
+      TRACE_RETURN();
+      return(RC_INVALID_ENVIRON);
    }
 /*---------------------------------------------------------------------*/
 /* If HEX mode is on, convert the hex string...                        */
 /*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->hex)
+   if (CURRENT_VIEW->hex)
    {
-    if ((len_params = convert_hex_strings(params)) == (-1))
+      if ((len_params = convert_hex_strings(params)) == (-1))
       {
-       display_error(32,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
-       return(RC_INVALID_OPERAND);
+         display_error(32,params,FALSE);
+         TRACE_RETURN();
+         return(RC_INVALID_OPERAND);
       }
    }
- else
-   len_params = strlen((DEFCHAR *)params);
- for (i=0;i<len_params;i++)
+   else
+      len_params = strlen((DEFCHAR *)params);
+   for (i=0;i<len_params;i++)
    {
-    real_key = case_translate((CHARTYPE)*(params+i));
-    chtype_key = (chtype)(real_key & A_CHARTEXT);
-    getyx(CURRENT_WINDOW,y,x);
+      real_key = case_translate((CHARTYPE)*(params+i));
+      chtype_key = (chtype)(real_key & A_CHARTEXT);
+      getyx(CURRENT_WINDOW,y,x);
 #if defined(USE_EXTCURSES)
-    attr = CURRENT_WINDOW->_a[y][x];
-    wattrset(CURRENT_WINDOW,attr);
-    attr = 0;
+      attr = CURRENT_WINDOW->_a[y][x];
+      wattrset(CURRENT_WINDOW,attr);
+      attr = 0;
 #else
-    attr = winch(CURRENT_WINDOW) & A_ATTRIBUTES;
+      attr = winch(CURRENT_WINDOW) & A_ATTRIBUTES;
 #endif
-    switch(CURRENT_VIEW->current_window)
+      switch(CURRENT_VIEW->current_window)
       {
-       case WINDOW_FILEAREA:
+         case WINDOW_FILEAREA:
             if (CURRENT_SCREEN.sl[y].line_type != LINE_LINE)
+            {
+               if ( compatible_feel == COMPAT_ISPF 
+               && ( CURRENT_SCREEN.sl[y].line_type == LINE_BOUNDS
+                 || CURRENT_SCREEN.sl[y].line_type == LINE_TABLINE ) )
+               {
+                  need_to_build_screen = ispf_special_lines_entry( CURRENT_SCREEN.sl[y].line_type,
+                                                                   winch(CURRENT_WINDOW) & A_CHARTEXT,
+                                                                   real_key );
+               }
                break;
+            }
             if ((LENGTHTYPE)(x+CURRENT_VIEW->verify_start) > (LENGTHTYPE)(CURRENT_VIEW->verify_end))
                break;
             if (INSERTMODEx)
-              {
+            {
                rec = meminschr(rec,real_key,CURRENT_VIEW->verify_col-1+x,
                                max_line_length,rec_len);
                put_char(CURRENT_WINDOW,chtype_key|attr,INSCHAR);
-              }
+            }
             else
-              {
+            {
                rec[CURRENT_VIEW->verify_col-1+x] = real_key;
                if (x == CURRENT_SCREEN.cols[WINDOW_FILEAREA]-1)
                   put_char(CURRENT_WINDOW,chtype_key|attr,INSCHAR);
                else
                   put_char(CURRENT_WINDOW,chtype_key|attr,ADDCHAR);
-              }
+            }
             rc = memrevne(rec,' ',max_line_length);
             if (rc == (-1))
                rec_len = 0;
@@ -410,23 +449,36 @@ CHARTYPE *params;
             &&  rec_len > CURRENT_VIEW->margin_right)
                execute_wrap_word(x+CURRENT_VIEW->verify_col);
             else    
-               {
+            {
                /* this is done here so that the show_page() in */
                /* THEcursor_right() is executed AFTER we get the   */
                /* new length of rec_len.                       */
 #if defined(USE_EXTCURSES)
                if (x == CURRENT_SCREEN.cols[WINDOW_FILEAREA]-1)
-                 {
+               {
                   wmove(CURRENT_WINDOW,y,x);
      /*           wrefresh(CURRENT_WINDOW); */
                   THEcursor_right(TRUE,FALSE);
-                 }
+               }
 #else
                if (INSERTMODEx
                || x == CURRENT_SCREEN.cols[WINDOW_FILEAREA]-1)
+               {
                   THEcursor_right(TRUE,FALSE);
-#endif
+# if defined(HAVE_BROKEN_COLORS)
+                  /*
+                   * AIX curses is broken. It moves the cursor down one
+                   * line, probably as a result of put_char() above. We
+                   * fix this by getting the new cursor position after
+                   * scrolling the screen horizontally, and then position
+                   * the cursor with the OLD y value, and the NEW x value;
+                   */
+                  getyx(CURRENT_WINDOW,junky,newx);
+                  wmove(CURRENT_WINDOW,y,newx);
+# endif
                }
+#endif
+            }
 /*---------------------------------------------------------------------*/
 /* If HEXSHOW is on and we are on the current line, build screen...    */
 /*---------------------------------------------------------------------*/
@@ -434,9 +486,9 @@ CHARTYPE *params;
             &&  CURRENT_VIEW->focus_line == CURRENT_VIEW->current_line)
                need_to_build_screen = TRUE;
             break;
-       case WINDOW_COMMAND:
+         case WINDOW_COMMAND:
             if (INSERTMODEx)
-              {
+            {
                cmd_rec = (CHARTYPE *)meminschr((CHARTYPE *)cmd_rec,
                                real_key,x,
                                COLS,cmd_rec_len);
@@ -447,15 +499,15 @@ CHARTYPE *params;
 #ifndef OLD_CMD
                cmd_rec_len++;
 #endif
-              }
+            }
             else
-              {
+            {
                cmd_rec[x] = real_key;
                put_char(CURRENT_WINDOW,chtype_key,ADDCHAR);
 #ifndef OLD_CMD
                cmd_rec_len = max(x+1,cmd_rec_len);
 #endif
-              }
+            }
 #ifdef OLD_CMD
             rc = memrevne(cmd_rec,' ',COLS);
             if (rc == (-1))
@@ -469,28 +521,28 @@ CHARTYPE *params;
              */
             clear_command = FALSE;
             break;
-       case WINDOW_PREFIX:
+         case WINDOW_PREFIX:
             prefix_changed = TRUE;
             if (pre_rec_len == 0)
-              {
+            {
                x = 0;
                wmove(CURRENT_WINDOW,y,x);
                my_wclrtoeol(CURRENT_WINDOW);
                wrefresh(CURRENT_WINDOW);
-              }
+            }
             if (INSERTMODEx)
-              {
+            {
                if (pre_rec_len == (CURRENT_VIEW->prefix_width-CURRENT_VIEW->prefix_gap))
                   break;
                pre_rec = (CHARTYPE *)meminschr((CHARTYPE *)pre_rec,
                                real_key,x,CURRENT_VIEW->prefix_width-CURRENT_VIEW->prefix_gap,pre_rec_len);
                put_char(CURRENT_WINDOW,chtype_key,INSCHAR);
-              }
+            }
             else
-              {
+            {
                pre_rec[x] = real_key;
                put_char(CURRENT_WINDOW,chtype_key,ADDCHAR);
-              }
+            }
             wmove(CURRENT_WINDOW,y,min(x+1,CURRENT_VIEW->prefix_width-CURRENT_VIEW->prefix_gap-1));
             rc = memrevne(pre_rec,' ',CURRENT_VIEW->prefix_width);
             if (rc == (-1))
@@ -500,47 +552,45 @@ CHARTYPE *params;
             break;
       }
    }
- if (in_macro)
-    need_to_build_screen = TRUE;
+   if (in_macro)
+      need_to_build_screen = TRUE;
 /*---------------------------------------------------------------------*/
 /* Set in_macro to FALSE to allow for the refreshing of the screen.    */
 /*---------------------------------------------------------------------*/
- in_macro = FALSE;
+   in_macro = FALSE;
 /*---------------------------------------------------------------------*/
 /* If text is being inserted on a line which is in the marked block,   */
 /* build and redisplay the window.                                     */
 /*---------------------------------------------------------------------*/
- if (CURRENT_VIEW == MARK_VIEW
- &&  CURRENT_VIEW->current_window == WINDOW_FILEAREA
- &&  INSERTMODEx
- &&  CURRENT_VIEW->focus_line >= MARK_VIEW->mark_start_line
- &&  CURRENT_VIEW->focus_line <= MARK_VIEW->mark_end_line)
-    need_to_build_screen = TRUE;
+   if (CURRENT_VIEW == MARK_VIEW
+   &&  CURRENT_VIEW->current_window == WINDOW_FILEAREA
+   &&  INSERTMODEx
+   &&  CURRENT_VIEW->focus_line >= MARK_VIEW->mark_start_line
+   &&  CURRENT_VIEW->focus_line <= MARK_VIEW->mark_end_line)
+      need_to_build_screen = TRUE;
 /*---------------------------------------------------------------------*/
 /* If the current file has colouring on and not using the NULL parser, */
 /* build and redisplay the window.                                     */
 /*---------------------------------------------------------------------*/
- if (CURRENT_FILE->colouring
- &&  CURRENT_FILE->parser
- &&  CURRENT_VIEW->current_window == WINDOW_FILEAREA)
-    need_to_build_screen = TRUE;
+   if (CURRENT_FILE->colouring
+   &&  CURRENT_FILE->parser
+   &&  CURRENT_VIEW->current_window == WINDOW_FILEAREA)
+      need_to_build_screen = TRUE;
 /*---------------------------------------------------------------------*/
 /* If we have determined we need to rebuild the screen, do it now.     */
 /*---------------------------------------------------------------------*/
- if (need_to_build_screen
- &&  !in_readv)
- {
-    build_screen(current_screen);
-    display_screen(current_screen);
- }
+   if (need_to_build_screen
+   &&  !in_readv)
+   {
+      build_screen(current_screen);
+      display_screen(current_screen);
+   }
 /*---------------------------------------------------------------------*/
 /* Set in_macro back to its original value...                          */
 /*---------------------------------------------------------------------*/
- in_macro = save_in_macro;
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(RC_OK);
+   in_macro = save_in_macro;
+   TRACE_RETURN();
+   return(RC_OK);
 }
 /*man-start*********************************************************************
 COMMAND
@@ -605,18 +655,14 @@ CHARTYPE *params;
  bool lines_based_on_scope=TRUE;
  bool adjust_alt=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Toascii");
-#endif
+ TRACE_FUNCTION("comm5.c:   Toascii");
  if (strcmp("",(DEFCHAR *)params) == 0)
     params = (CHARTYPE *)"+1";
  initialise_target(&target);
  if ((rc = validate_target(params,&target,target_type,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
    {
     free_target(&target);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
@@ -725,9 +771,7 @@ CHARTYPE *params;
 /*---------------------------------------------------------------------*/
  pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
  resolve_current_and_focus_lines(CURRENT_VIEW,true_line,num_file_lines,direction,TRUE,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 
@@ -766,18 +810,14 @@ CHARTYPE *params;
  short rc=RC_TOF_EOF_REACHED;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Top");
-#endif
+ TRACE_FUNCTION("comm5.c:   Top");
 /*---------------------------------------------------------------------*/
 /* No arguments are allowed; error if any are present.                 */
 /*---------------------------------------------------------------------*/
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
  CURRENT_VIEW->current_line = 0L;
@@ -800,9 +840,7 @@ CHARTYPE *params;
     else
        wmove(CURRENT_WINDOW,y,x);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -842,9 +880,7 @@ CHARTYPE *params;
  short rc=RC_OK;
  LINETYPE num_lines=0L,true_line=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Up");
-#endif
+ TRACE_FUNCTION("comm5.c:   Up");
  params = MyStrip(params,STRIP_BOTH,' ');
  if (strcmp("",(DEFCHAR *)params) == 0)
     params = (CHARTYPE *)"1";
@@ -856,25 +892,19 @@ CHARTYPE *params;
     if (!valid_integer(params))
       {
        display_error(4,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     num_lines = atol((DEFCHAR *)params);
     if (num_lines < 0L)
       {
        display_error(5,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
    }
  rc = advance_current_or_focus_line(-num_lines);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -910,13 +940,9 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Uppercase");
-#endif
+ TRACE_FUNCTION("comm5.c:   Uppercase");
  rc = execute_change_case(params,CASE_UPPER);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -955,16 +981,12 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Xedit");
-#endif
+ TRACE_FUNCTION("comm5.c:   Xedit");
 /*---------------------------------------------------------------------*/
 /* Parse any parameters...future work.                                 */
 /*---------------------------------------------------------------------*/
  rc = EditFile(params,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
@@ -1017,9 +1039,7 @@ CHARTYPE *params;
  int param_len=0;
  short direction=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Retrieve");
-#endif
+ TRACE_FUNCTION("comm5.c:   Retrieve");
 /*
  *---------------------------------------------------------------------
  * No parameters, get the last command...
@@ -1038,9 +1058,7 @@ CHARTYPE *params;
     if ((save_params = (CHARTYPE *)my_strdup(params)) == NULL)
       {
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY);
       }
     /*
@@ -1067,9 +1085,7 @@ CHARTYPE *params;
     if (strzne(save_params,(CHARTYPE)'?') != (-1))
       {
        display_error(1,params,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     current_command = get_next_command(direction,strlen((DEFCHAR *)save_params)+1);
@@ -1080,9 +1096,7 @@ CHARTYPE *params;
  my_wclrtoeol(CURRENT_WINDOW_COMMAND);
  if (current_command != (CHARTYPE *)NULL)
     Cmsg(current_command);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /*man-start*********************************************************************
@@ -1114,24 +1128,18 @@ CHARTYPE *params;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("comm5.c:   Reexecute");
-#endif
+ TRACE_FUNCTION("comm5.c:   Reexecute");
  if (strcmp((DEFCHAR *)params,""))
     {
      display_error(1,params,FALSE);
-#ifdef THE_TRACE
-     trace_return();
-#endif
+     TRACE_RETURN();
      return(RC_INVALID_OPERAND);
     }
 /*---------------------------------------------------------------------*/
 /* Retrieve the last command and execute it.                           */
 /*---------------------------------------------------------------------*/
  rc = command_line(last_command_for_reexecute,COMMAND_ONLY_FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man-start*********************************************************************
