@@ -34,7 +34,7 @@
  */
 
 /*
-$Id: command.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
+$Id: command.h,v 1.2 2000/12/09 22:37:42 mark Exp $
 */
 
 struct commands
@@ -102,6 +102,7 @@ COMMAND command[] =
  {(CHARTYPE *)"backup",      4,  (-1),            Backup,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"beep",        4,  (-1),            BeepSound,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"bottom",      1,  (-1),            Bottom,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
+ {(CHARTYPE *)"boundmark",   9,  (-1),            Boundmark,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"cancel",      3,  (-1),            Cancel,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"cappend",     2,  (-1),            Cappend,          TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"case",        4,  (-1),            Case,             TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
@@ -185,6 +186,7 @@ COMMAND command[] =
  {(CHARTYPE *)"editv",       5,  (-1),            THEEditv,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"emsg",        4,  (-1),            Emsg,             TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"eolout",      4,  (-1),            Eolout,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"equivchar",   6,  (-1),            Equivchar,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"etmode",      6,  (-1),            Etmode,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"expand",      3,  (-1),            Expand,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"extract",     3,  (-1),            Extract,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
@@ -219,6 +221,7 @@ COMMAND command[] =
 #endif
  {(CHARTYPE *)"fullfname",   6,  (-1),            Fullfname,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"get",         3,  (-1),            Get,              TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
+ {(CHARTYPE *)"header",      4,  (-1),            THEHeader,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"help",        4,  KEY_F1,          Help,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
 #else
@@ -236,6 +239,7 @@ COMMAND command[] =
  {(CHARTYPE *)"impcmscp",    3,  (-1),            Impos,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"input",       1,  (-1),            Input,            TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"inputmode",   6,  (-1),            Inputmode,        TRUE, TRUE, FALSE,FALSE,FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"interface",   3,  (-1),            THEInterface,     TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"insertmode",  7,  KEY_INS,         Insertmode,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)"toggle"},  /* commset1.c */
  {(CHARTYPE *)"locate",      1,  KEY_S_F1,        Locate,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
@@ -330,6 +334,7 @@ COMMAND command[] =
 #endif
  {(CHARTYPE *)"readv",       5,  (-1),            Readv,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"readonly",    8,  (-1),            THEReadonly,      TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
+ {(CHARTYPE *)"redit",       5,  (-1),            Redit,            FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"redraw",      6,  KEY_C_r,         Redraw,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"refresh",     7,  (-1),            THERefresh,       FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"repeat",      4,  (-1),            Repeat,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
@@ -390,6 +395,8 @@ COMMAND command[] =
  {(CHARTYPE *)"blockstart",  6,  (-1),            Sos_blockstart,   FALSE,FALSE,TRUE, TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
  {(CHARTYPE *)"blockend",    6,  (-1),            Sos_blockend,     FALSE,FALSE,TRUE, TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
  {(CHARTYPE *)"cursoradj",   7,  KEY_C_a,         Sos_cursoradj,    FALSE,FALSE,TRUE, FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
+ {(CHARTYPE *)"cuadelback",  8,  (-1),            Sos_cuadelback,   FALSE,FALSE,TRUE, TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
+ {(CHARTYPE *)"cuadelchar",  7,  (-1),            Sos_cuadelchar,   FALSE,FALSE,TRUE, TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"addline",     3,  KEY_F4,          Sos_addline,      FALSE,FALSE,TRUE, FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
  {(CHARTYPE *)"delback",     5,  KEY_BKSP,        Sos_delback,      FALSE,FALSE,TRUE, TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* commsos.c */
