@@ -38,7 +38,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: cursor.c,v 1.3 1999/07/06 04:07:58 mark Exp mark $";
+static char RCSid[] = "$Id: cursor.c,v 1.2 2000/12/09 23:49:15 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -55,17 +55,13 @@ short col;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_cmdline");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_cmdline");
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -73,9 +69,7 @@ short col;
 /*---------------------------------------------------------------------*/
  if (CURRENT_WINDOW_COMMAND == (WINDOW *)NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  if (CURRENT_VIEW->current_window != WINDOW_COMMAND)
@@ -86,9 +80,7 @@ short col;
    }
  wmove(CURRENT_WINDOW,0,col-1);
  CURRENT_VIEW->cmdline_col = col-1;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -103,17 +95,13 @@ short THEcursor_column()
  short rc=RC_OK;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_column");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_column");
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
  switch(CURRENT_VIEW->current_window)
@@ -128,43 +116,45 @@ short THEcursor_column()
          break;
    }
  rc = execute_move_cursor(CURRENT_VIEW->current_column-1);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short THEcursor_down(bool escreen)
+short THEcursor_down(short escreen)
 #else
 short THEcursor_down(escreen)
-bool escreen;
+short escreen;
 #endif
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- short rc=RC_OK;
+   short rc=RC_OK;
+   short x,y;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_down");
-#endif
+   TRACE_FUNCTION("cursor.c:  THEcursor_down");
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
- if (in_readv)
+   if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      TRACE_RETURN();
+      return(RC_OK);
    }
- switch(CURRENT_VIEW->current_window)
+   switch(CURRENT_VIEW->current_window)
    {
-    case WINDOW_PREFIX:
-    case WINDOW_FILEAREA:
+      case WINDOW_PREFIX:
+      case WINDOW_FILEAREA:
          rc = scroll_line(DIRECTION_FORWARD,1L,FALSE,escreen);
+         if ( rc == RC_OK 
+         &&   escreen == CURSOR_CUA )
+         {
+            getyx(CURRENT_WINDOW_FILEAREA,y,x);
+            if ( x + CURRENT_VIEW->verify_col > min(rec_len,CURRENT_VIEW->verify_end) )
+               rc = execute_move_cursor(rec_len);
+         }
          break;
-    case WINDOW_COMMAND:
+      case WINDOW_COMMAND:
 /*---------------------------------------------------------------------*/
 /* Cycle forward  through the command list or tab to first line.       */
 /*---------------------------------------------------------------------*/
@@ -173,14 +163,12 @@ bool escreen;
          else
             rc = Retrieve((CHARTYPE *)"+");
          break;
-    default:
+      default:
          display_error(2,(CHARTYPE *)"",FALSE);
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -196,17 +184,13 @@ LENGTHTYPE col;
  short rc=RC_OK;
  unsigned short y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_file");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_file");
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -215,9 +199,7 @@ LENGTHTYPE col;
  if (!line_in_view(current_screen,line))
    {
     display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -230,18 +212,14 @@ LENGTHTYPE col;
     if (!column_in_view(current_screen,col-1))
       {
        display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     x = (LENGTHTYPE)((LINETYPE)col - (LINETYPE)CURRENT_VIEW->verify_col + 1);
    }
  y = get_row_for_focus_line(current_screen,line,CURRENT_VIEW->current_line);
  rc = THEcursor_move(FALSE,y+1,x);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -258,18 +236,14 @@ bool save;
  unsigned short x=0,y=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_home");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_home");
 /*---------------------------------------------------------------------*/
 /* If CMDLINE is OFF or in READV CMDLINE, return without doing anything*/
 /*---------------------------------------------------------------------*/
  if (CURRENT_WINDOW_COMMAND == (WINDOW *)NULL
  ||  in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  last_win = CURRENT_VIEW->previous_window;
@@ -306,166 +280,193 @@ bool save;
     wmove(CURRENT_WINDOW,y,x);
    }
  build_screen(current_screen);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short THEcursor_left(bool escreen,bool kedit_defaults)
+short THEcursor_left(short escreen,bool kedit_defaults)
 #else
 short THEcursor_left(escreen,kedit_defaults)
-bool escreen,kedit_defaults;
+short escreen;
+bool kedit_defaults;
 #endif
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- unsigned short x=0,y=0;
- short rc=RC_OK;
+   unsigned short x=0,y=0;
+   short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_left");
-#endif
-/*---------------------------------------------------------------------*/
-/* The following should be a temporary fix for KEDIT compatability...  */
-/*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->prefix
- &&  kedit_defaults)
-    escreen = FALSE;
- getyx(CURRENT_WINDOW,y,x);
-/*---------------------------------------------------------------------*/
-/* For all windows, if we are not at left column, move 1 pos to left.  */
-/*---------------------------------------------------------------------*/
- if (x > 0)
+   /*
+    * If escreen is CURSOR_ESCREEN or CURSOR_CUA, then scrolling of the 
+    * window will be done if possible.
+    */
+   TRACE_FUNCTION("cursor.c:  THEcursor_left");
+   /*
+    * The following should be a temporary fix for KEDIT compatability...
+    */
+   if (CURRENT_VIEW->prefix
+   &&  kedit_defaults)
+      escreen = CURSOR_SCREEN;
+
+   getyx(CURRENT_WINDOW,y,x);
+   /*
+    * For all windows, if we are not at left column, move 1 pos to left. 
+    */
+   if (x > 0)
    {
-    wmove(CURRENT_WINDOW,y,x-1);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      wmove(CURRENT_WINDOW,y,x-1);
+      TRACE_RETURN();
+      return(RC_OK);
    }
-/*---------------------------------------------------------------------*/
-/* For all windows, determine if CMDARROWSTABLRx is set for tabbing or */
-/* scrolling and act accordingly.                                      */
-/*---------------------------------------------------------------------*/
- switch(CURRENT_VIEW->current_window)
+   /*
+    * We are at the left edge of the FILEAREA!
+    * For all windows, determine if CMDARROWSTABLRx is set for tabbing or
+    * scrolling and act accordingly.
+    */
+   switch(CURRENT_VIEW->current_window)
    {
-    case WINDOW_FILEAREA:
-         if (!escreen)
-           {
+      case WINDOW_FILEAREA:
+         /*
+          * For CUA interface, at the left column of the file, move the cursor
+          * to the last character of the previous line; that line
+          * which is in scope
+          */
+         if ( escreen == CURSOR_CUA
+         &&   CURRENT_VIEW->verify_col == 1 )
+         {
+            rc = scroll_line(DIRECTION_BACKWARD,1L,FALSE,escreen);
+            rc = Sos_endchar( (CHARTYPE *)"" );
+            break;
+         }
+         if ( escreen == CURSOR_SCREEN )
+         {
+            /*
+             * Move the cursor into the prefix area, to the right-most
+             * column, then move the cursor to the last column of the
+             * window, either PREFIX (if ON) or FILEAREA
+             */
             if (CURRENT_VIEW->prefix)
                rc = Sos_prefix((CHARTYPE *)"");
             rc = Sos_lastcol((CHARTYPE *)"");
-           }
+         }
          else
-           {
+         {
             if (CURRENT_VIEW->verify_col != 1
             &&  CURRENT_VIEW->autoscroll != 0)
-              {
-               int curr_col=x+CURRENT_VIEW->verify_col-1;
-               int num_cols = (CURRENT_VIEW->autoscroll == (-1)) ? CURRENT_SCREEN.cols[WINDOW_FILEAREA]/2 : CURRENT_VIEW->autoscroll;
+            {
+               LENGTHTYPE curr_col = x+CURRENT_VIEW->verify_col-1;
+               LENGTHTYPE num_cols = (CURRENT_VIEW->autoscroll == (-1)) ? CURRENT_SCREEN.cols[WINDOW_FILEAREA]/2 : CURRENT_VIEW->autoscroll;
 
                num_cols = min(num_cols,CURRENT_SCREEN.cols[WINDOW_FILEAREA]);
-               CURRENT_VIEW->verify_col = max(1,CURRENT_VIEW->verify_col-num_cols);
+               if ( num_cols >= CURRENT_VIEW->verify_col )
+                  CURRENT_VIEW->verify_col = 1;
+               else
+                  CURRENT_VIEW->verify_col = CURRENT_VIEW->verify_col-num_cols;
                build_screen(current_screen);
                display_screen(current_screen);
                wmove(CURRENT_WINDOW,y,curr_col-CURRENT_VIEW->verify_col);
-              }
+            }
             else
-              {
+            {
                if (compatible_feel == COMPAT_KEDIT
                ||  compatible_feel == COMPAT_KEDITW)
-                 {
+               {
                   if (CURRENT_VIEW->prefix)
                      if ((CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_LEFT)
                         rc = Sos_prefix((CHARTYPE *)"");
                   rc = Sos_lastcol((CHARTYPE *)"");
-                 }
-              }
-           }
+               }
+            }
+         }
          break;
-    case WINDOW_PREFIX:
-    case WINDOW_COMMAND:
-         if ((escreen
+      case WINDOW_PREFIX:
+      case WINDOW_COMMAND:
+         if ((escreen == CURSOR_ESCREEN
          &&  (CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_RIGHT)
-         ||  !escreen)
+         ||  escreen == CURSOR_SCREEN)
              rc = Sos_rightedge((CHARTYPE *)"");
          break;
-    default:
+      default:
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short THEcursor_right(bool escreen,bool kedit_defaults)
+short THEcursor_right(short escreen,bool kedit_defaults)
 #else
 short THEcursor_right(escreen,kedit_defaults)
-bool escreen,kedit_defaults;
+short escreen;
+bool kedit_defaults;
 #endif
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- unsigned short x=0,y=0,tempx=0;
- short right_column=0;
- short rc=RC_OK;
+   unsigned short x=0,y=0,tempx=0;
+   short right_column=0;
+   short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_right");
-#endif
-/*---------------------------------------------------------------------*/
-/* The following should be a temporary fix for KEDIT compatability...  */
-/*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->prefix
- &&  kedit_defaults)
-    escreen = FALSE;
- getyx(CURRENT_WINDOW,y,x);
-/*---------------------------------------------------------------------*/
-/* Check for going past end of line - max_line_length                  */
-/*---------------------------------------------------------------------*/
- if (CURRENT_VIEW->verify_col+x+1 > max_line_length)
+   TRACE_FUNCTION("cursor.c:  THEcursor_right");
+   /*
+    * The following should be a temporary fix for KEDIT compatability... 
+    */
+   if (CURRENT_VIEW->prefix
+   &&  kedit_defaults)
+      escreen = CURSOR_SCREEN;
+   getyx(CURRENT_WINDOW,y,x);
+   /*
+    * Check for going past end of line - max_line_length   
+    */
+   if (CURRENT_VIEW->verify_col+x+1 > max_line_length)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      TRACE_RETURN();
+      return(RC_OK);
    }
- right_column = getmaxx(CURRENT_WINDOW)-1;
-/*---------------------------------------------------------------------*/
-/* For all windows, if we are not at right column, move 1 pos to right.*/
-/*---------------------------------------------------------------------*/
- if (x < right_column)
+   right_column = getmaxx(CURRENT_WINDOW)-1;
+   /*
+    * For CUA interface, if after the right-most character of the line,
+    * move the cursor to the first column of the next line; that line
+    * which is in scope
+    */
+   if ( escreen == CURSOR_CUA
+   &&   x + CURRENT_VIEW->verify_col > min(rec_len,CURRENT_VIEW->verify_end) )
    {
-    wmove(CURRENT_WINDOW,y,x+1);
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      rc = scroll_line(DIRECTION_FORWARD,1L,FALSE,escreen);
+      rc = Sos_firstcol( (CHARTYPE *)"" );
+      TRACE_RETURN();
+      return(rc);
    }
-/*---------------------------------------------------------------------*/
-/* For all windows, determine if CMDARROWSTABLRx is set for tabbing or */
-/* scrolling and act accordingly.                                      */
-/*---------------------------------------------------------------------*/
- switch(CURRENT_VIEW->current_window)
+   /*
+    * For all windows, if we are not at right column, move 1 pos to right.
+    */
+   if (x < right_column)
    {
-    case WINDOW_FILEAREA:
-         if (!escreen)
-           {
+      wmove(CURRENT_WINDOW,y,x+1);
+      TRACE_RETURN();
+      return(RC_OK);
+   }
+   /*
+    * For all windows, determine if CMDARROWSTABLRx is set for tabbing or 
+    * scrolling and act accordingly.
+    */
+   switch(CURRENT_VIEW->current_window)
+   {
+      case WINDOW_FILEAREA:
+         if (escreen == CURSOR_SCREEN)
+         {
             if (CURRENT_VIEW->prefix)
                rc = Sos_prefix((CHARTYPE *)"");
             else
                wmove(CURRENT_WINDOW,y,0); /* this should move down a line too */
-           }
+         }
          else
-           {
+         {
             tempx = getmaxx(CURRENT_WINDOW);
             if (x == tempx-1
             &&  CURRENT_VIEW->autoscroll != 0)
-              {
+            {
                int curr_col=x+CURRENT_VIEW->verify_col-1;
                int num_cols = (CURRENT_VIEW->autoscroll == (-1)) ? CURRENT_SCREEN.cols[WINDOW_FILEAREA]/2 : CURRENT_VIEW->autoscroll;
 
@@ -474,81 +475,83 @@ bool escreen,kedit_defaults;
                build_screen(current_screen);
                display_screen(current_screen);
                wmove(CURRENT_WINDOW,y,curr_col-CURRENT_VIEW->verify_col+2);
-              }
-           }
+            }
+         }
          break;
-    case WINDOW_PREFIX:
-    case WINDOW_COMMAND:
-         if (!escreen)
+      case WINDOW_PREFIX:
+      case WINDOW_COMMAND:
+         if ( escreen == CURSOR_SCREEN )
             rc = Sos_leftedge((CHARTYPE *)"");
          else 
+         {
             if ((CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_LEFT)
                Tabpre((CHARTYPE *)"");
+         }
          break;
-    default:
+      default:
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short THEcursor_up(bool escreen)
+short THEcursor_up(short escreen)
 #else
 short THEcursor_up(escreen)
-bool escreen;
+short escreen;
 #endif
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- short rc=RC_OK;
- CHARTYPE *current_command=NULL;
+   short rc=RC_OK;
+   short x,y;
+   CHARTYPE *current_command=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_up");
-#endif
+   TRACE_FUNCTION("cursor.c:  THEcursor_up");
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
- if (in_readv)
+   if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(RC_OK);
+      TRACE_RETURN();
+      return(RC_OK);
    }
- switch(CURRENT_VIEW->current_window)
+   switch(CURRENT_VIEW->current_window)
    {
-    case WINDOW_FILEAREA:
-    case WINDOW_PREFIX:
+      case WINDOW_FILEAREA:
+      case WINDOW_PREFIX:
          rc = scroll_line(DIRECTION_BACKWARD,1L,FALSE,escreen);
+         if ( rc == RC_OK 
+         &&   escreen == CURSOR_CUA )
+         {
+            getyx(CURRENT_WINDOW_FILEAREA,y,x);
+            if ( x + CURRENT_VIEW->verify_col > min(rec_len,CURRENT_VIEW->verify_end) )
+               rc = execute_move_cursor(rec_len);
+         }
          break;
-    case WINDOW_COMMAND:
+      case WINDOW_COMMAND:
 /*---------------------------------------------------------------------*/
 /* Cycle backward through the command list or tab to last line.        */
 /*---------------------------------------------------------------------*/
          if (CMDARROWSTABCMDx)
             rc = Sos_bottomedge((CHARTYPE *)"");
          else
-           {
+         {
             current_command = get_next_command(DIRECTION_FORWARD,1);
             wmove(CURRENT_WINDOW_COMMAND,0,0);
             my_wclrtoeol(CURRENT_WINDOW_COMMAND);
             if (current_command != (CHARTYPE *)NULL)
                Cmsg(current_command);
-           }
+         }
          break;
-    default:
+      default:
          display_error(2,(CHARTYPE *)"",FALSE);
          rc = RC_INVALID_OPERAND;
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(rc);
+   TRACE_RETURN();
+   return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -567,25 +570,19 @@ short row,col;
  unsigned short max_row=0,min_row=0,max_col=0;
  short idx=(-1);
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_move");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_move");
  getyx(CURRENT_WINDOW_FILEAREA,y,x);
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
  if (!escreen)
    {
     if (find_last_focus_line(&max_row) != RC_OK)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(rc);
       }
     if (find_first_focus_line(&min_row) != RC_OK)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(rc);
       }
     if (row == 0)
@@ -605,9 +602,7 @@ short row,col;
              else
                {
                 display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                trace_return();
-#endif
+                TRACE_RETURN();
                 return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
                }
             }
@@ -659,9 +654,7 @@ short row,col;
     ||  col > max_col)
       {
        display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
       }
 /*---------------------------------------------------------------------*/
@@ -689,9 +682,7 @@ short row,col;
             if (!CURRENT_SCREEN.sl[row].main_enterable)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-               trace_return();
-#endif
+               TRACE_RETURN();
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
               }
             rc = Sos_current((CHARTYPE *)"");
@@ -704,9 +695,7 @@ short row,col;
             if (!CURRENT_SCREEN.sl[row].prefix_enterable)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-               trace_return();
-#endif
+               TRACE_RETURN();
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
               }
 #if 0
@@ -714,18 +703,14 @@ short row,col;
             &&  col >= CURRENT_VIEW->prefix_width-CURRENT_VIEW->prefix_gap)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-               trace_return();
-#endif
+               TRACE_RETURN();
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
               }
             if ((CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_RIGHT
             &&  col < CURRENT_VIEW->prefix_gap)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-               trace_return();
-#endif
+               TRACE_RETURN();
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
               }
 #endif
@@ -740,16 +725,12 @@ short row,col;
             break;
        default:
             display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-            trace_return();
-#endif
+            TRACE_RETURN();
             return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
             break;
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -775,9 +756,7 @@ short THEcursor_mouse()
 #endif
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  THEcursor_mouse");
-#endif
+ TRACE_FUNCTION("cursor.c:  THEcursor_mouse");
 
 #if defined(PDCURSES_MOUSE_ENABLED) || defined(NCURSES_MOUSE_VERSION)
 /*---------------------------------------------------------------------*/
@@ -785,9 +764,7 @@ short THEcursor_mouse()
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -796,9 +773,7 @@ short THEcursor_mouse()
  which_window_is_mouse_in(&scrn,&w);
  if (w == (-1)) /* shouldn't happen! */
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
    }
 /*---------------------------------------------------------------------*/
@@ -814,9 +789,7 @@ short THEcursor_mouse()
  rc = THEcursor_move(TRUE,MOUSE_Y,MOUSE_X);
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -831,9 +804,7 @@ long where_now()
  long rc=0L;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  where_now");
-#endif
+ TRACE_FUNCTION("cursor.c:  where_now");
  getyx(CURRENT_WINDOW,y,x);
  switch(CURRENT_VIEW->current_window)
    {
@@ -863,9 +834,7 @@ long where_now()
        rc |= WHERE_SCREEN_LAST;
    }
  rc |= (long)y;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -879,9 +848,7 @@ long what_current_now()
 /*--------------------------- local data ------------------------------*/
  long rc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  what_current_now");
-#endif
+ TRACE_FUNCTION("cursor.c:  what_current_now");
  if (CURRENT_WINDOW_PREFIX != NULL)
    {
     if ((CURRENT_VIEW->prefix & PREFIX_LOCATION_MASK) == PREFIX_LEFT)
@@ -894,9 +861,7 @@ long what_current_now()
  else
     if (CURRENT_VIEW->cmd_line == 'T')
        rc |= WHERE_WINDOW_CMDLINE_TOP;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -910,14 +875,10 @@ long what_other_now()
 /*--------------------------- local data ------------------------------*/
  long rc=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  what_other_now");
-#endif
+ TRACE_FUNCTION("cursor.c:  what_other_now");
 if (display_screens == 1)
   {
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return(rc);
   }
  if (OTHER_SCREEN.win[WINDOW_PREFIX] != NULL)
@@ -932,9 +893,7 @@ if (display_screens == 1)
  else
     if (OTHER_SCREEN.screen_view->cmd_line == 'T')
        rc |= WHERE_WINDOW_CMDLINE_TOP;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1310,9 +1269,7 @@ long where;
  long where_screen=0L;
  CHARTYPE scrn=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  enterable_field");
-#endif
+ TRACE_FUNCTION("cursor.c:  enterable_field");
  where_screen = where & WHERE_SCREEN_MASK;
  row = (ROWTYPE)(where & WHERE_ROW_MASK);
  scrn = (where_screen == WHERE_SCREEN_LAST) ? 1 : 0;
@@ -1331,9 +1288,7 @@ long where;
     case WHERE_WINDOW_CMDLINE_BOTTOM:
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1351,9 +1306,7 @@ long save_where,where;
  long save_where_window=0L,where_window=0L;
  ROWTYPE where_row=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  go_to_new_field");
-#endif
+ TRACE_FUNCTION("cursor.c:  go_to_new_field");
  save_where_screen = save_where & WHERE_SCREEN_MASK;
  where_screen = where & WHERE_SCREEN_MASK;
  save_where_window = save_where & WHERE_WINDOW_MASK;
@@ -1421,9 +1374,7 @@ long save_where,where;
       }
    }
  wmove(CURRENT_WINDOW,where_row,0);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1439,9 +1390,7 @@ LINETYPE *screen_line,*screen_column,*file_line,*file_column;
  unsigned short y=0,x=0;
  unsigned short begy=0,begx=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  get_cursor_position");
-#endif
+ TRACE_FUNCTION("cursor.c:  get_cursor_position");
  if (curses_started)
    {
     getyx(CURRENT_WINDOW,y,x);
@@ -1465,9 +1414,7 @@ LINETYPE *screen_line,*screen_column,*file_line,*file_column;
          *file_line = *file_column = (-1L);
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1483,11 +1430,9 @@ LINETYPE num_lines;
  unsigned short y=0,x=0;
  LINE *curr=NULL;
  LINETYPE actual_lines=num_lines;
- short direction=DIRECTION_FORWARD;
+ short direction=DIRECTION_FORWARD,rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  advance_focus_line");
-#endif
+ TRACE_FUNCTION("cursor.c:  advance_focus_line");
  if (num_lines < 0L)
    {
     actual_lines = -num_lines;
@@ -1520,13 +1465,10 @@ LINETYPE num_lines;
                                CURRENT_VIEW->current_row);
     wmove(CURRENT_WINDOW,y,x);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
  if (FOCUS_TOF || FOCUS_BOF)
-    return(RC_TOF_EOF_REACHED);
- else
-    return(RC_OK);
+    rc = RC_TOF_EOF_REACHED;
+ TRACE_RETURN();
+ return rc;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -1541,11 +1483,9 @@ LINETYPE num_lines;
  LINE *curr=NULL;
  LINETYPE actual_lines=num_lines;
  short direction=DIRECTION_FORWARD;
- short y=0,x=0;
+ short y=0,x=0,rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  advance_current_line");
-#endif
+ TRACE_FUNCTION("cursor.c:  advance_current_line");
  if (num_lines < 0L)
    {
     actual_lines = -num_lines;
@@ -1585,13 +1525,10 @@ LINETYPE num_lines;
  pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
  build_screen(current_screen);
  display_screen(current_screen);
-#ifdef THE_TRACE
- trace_return();
-#endif
  if (CURRENT_TOF || CURRENT_BOF)
-    return(RC_TOF_EOF_REACHED);
- else
-    return(RC_OK);
+    rc = RC_TOF_EOF_REACHED;
+ TRACE_RETURN();
+ return rc;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -1605,17 +1542,13 @@ LINETYPE num_lines;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  advance_current_or_focus_line");
-#endif
+ TRACE_FUNCTION("cursor.c:  advance_current_or_focus_line");
  if (CURRENT_VIEW->current_window == WINDOW_COMMAND
  ||  compatible_feel == COMPAT_XEDIT)
     rc = advance_current_line(num_lines);
  else
     rc = advance_focus_line(num_lines);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /*man***************************************************************************
@@ -1671,9 +1604,7 @@ bool sos;
  short y=0,x=0;
  short save_compatible_feel=compatible_feel;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("cursor.c:  resolve_current_and_focus_lines");
-#endif
+ TRACE_FUNCTION("cursor.c:  resolve_current_and_focus_lines");
 /*---------------------------------------------------------------------*/
 /* If no lines to move, don't do anything...                           */
 /*---------------------------------------------------------------------*/
@@ -1681,9 +1612,7 @@ bool sos;
    {
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -1699,9 +1628,7 @@ bool sos;
    {
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -1713,9 +1640,7 @@ bool sos;
     view->current_line = true_line+num_lines-(LINETYPE)direction;
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -1761,8 +1686,6 @@ bool sos;
          display_screen(current_screen);
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
