@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $";
+static char RCSid[] = "$Id: default.c,v 1.2 2000/12/09 23:57:29 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -60,6 +60,8 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
  bool REPROFILEx;
  CHARTYPE TABI_ONx;
  CHARTYPE TABI_Nx;
+ CHARTYPE EQUIVCHARx;                         /* equivalence character */
+ CHARTYPE EQUIVCHARstr[2];        /* equivalence character as a string */
  ROWTYPE STATUSLINEx='B';
  bool TYPEAHEADx;
  bool scroll_cursor_stay;   /* determine how page scrolling is handled */
@@ -77,6 +79,7 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
  CHARTYPE ctlchar_escape=0;
  COLOUR_ATTR ctlchar_attr[MAX_CTLCHARS];  /* colour attributes for ctlchar */
  CHARTYPE ctlchar_char[MAX_CTLCHARS];      /* escape chars for ctlchar */
+ CHARTYPE INTERFACEx=INTERFACE_CLASSIC;       /* behavioural interface */
 /*--------------------------- default parsers -------------------------*/
    typedef struct
    {
@@ -106,7 +109,8 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
             "abs\nformat\nmax\nmin\nsign\ntrunc\naddress\narg\ncondition\ndigits\nerrortext\nform\n"                        \
             "fuzz\nsourceline\ntrace\nb2x\nbitand\nbitor\nbitxor\nc2d\nc2x\nd2c\nd2x\nx2b\nx2c\nx2d\n"                      \
             "charin\ncharout\nchars\nlinein\nlineout\nlines\nqualify\nstream\ndate\nqueued\nrandom\n"                       \
-            "symbol\ntime\nvalue\n"
+            "symbol\ntime\nvalue\nrxfuncdrop\nrxfuncerrmsg\nrxfuncadd\nrxfuncquery\nrxqueue\n"                              \
+            ":postcompare\nclass [-\\/\\+\\=\\*\\<\\>|%&,] alt w\n"
       },
       { (CHARTYPE *)"*C.TLD",
         (CHARTYPE *)"C",
@@ -114,13 +118,14 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
             ":string\nsingle backslash\ndouble backslash\n:comment\npaired /* */ nonest\nline // any\n"                     \
             ":label\ndelimiter : column 1\n:match\n( )\n{ }\n#ifdef,#if,#ifndef #endif #else,#elif,#elseif\n"               \
             ":keyword\n#define\n#elif\n#else\n#endif\n#error\n#if\n#ifdef\n#ifndef\n#include\n#line\n#pragma\n#undef\n"     \
-            "auto\nbool\nbreak\ncase\nchar\nconst\ncontinue\ndefault\ndelete\ndo\ndouble\nelse\nenum\nextern\nfloat\n"      \
-            "for\ngoto\nif\nint\nlong\nnew\nregister\nreturn\nshort\nsigned\nsizeof\nstatic\nstruct\nswitch\n"              \
-            "typedef\nunion\nunsigned\nvoid\nvolatile\nwhile\nclass\nprivate\npublic\n"
+            "auto\nbool\nbreak\ncase\nchar\nconst\ncontinue\ndefault\ndefined alt f\ndelete\ndo\ndouble\nelse\nenum\n"      \
+            "extern\nfloat\nfor\ngoto\nif\nint\nlong\nnew\nregister\nreturn\nshort\nsigned\nsizeof\nstatic\nstruct\n"       \
+            "switch\ntypedef\nunion\nunsigned\nvoid\nvolatile\nwhile\nclass\nprivate\npublic\n"                             \
+            ":postcompare\nclass [-\\/\\+\\=\\*\\<\\>|%&!,] alt x\n"
       },
       { (CHARTYPE *)"*SH.TLD",
         (CHARTYPE *)"SH",
-        (CHARTYPE *)"* SH\n:case\nrespect\n"       \
+        (CHARTYPE *)"* SH\n:case\nrespect\n:number\nc\n"       \
             ":string\nsingle backslash\ndouble backslash\n:identifier\n[a-zA-Z_] [a-zA-Z0-9_]\n"                            \
             ":comment\nline # any\n:header\nline #! column 1\n"                                                                                        \
             ":keyword\nif\nfi\nelif\nfor\nuntil\ncase\nesac\nwhile\nthen\nelse\ntest alt 4\nshift alt 4\ndo\ndone\nin\n"          \
@@ -135,13 +140,26 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
       },
       { (CHARTYPE *)"*HTML.TLD",
         (CHARTYPE *)"HTML",
-        (CHARTYPE *)"* HTML" \
+        (CHARTYPE *)"* HTML\n" \
             ":case\nignore\n" \
             ":identifier\n[a-zA-Z] [a-zA-Z0-9]\n" \
             ":string\ndouble\n" \
-            ":comment\npaired <! --> nonest\n" \
+            ":comment\npaired <! > nonest\n" \
             ":markup\ntag < >\nreference & ;\n"
       },
+      { (CHARTYPE *)"*DIR.TLD",
+        (CHARTYPE *)"DIR",
+        (CHARTYPE *)"* DIR\n" \
+            ":column\nexclude 1 38\n" \
+            ":postcompare\nstring -> alt 1\n" \
+            "class .*\\.o$ alt A\n" \
+            "class .*\\.c$ alt B\n" \
+            "class .*\\.h$ alt C\n" \
+            "class .*\\.zip$ alt D\n" \
+            "class .*\\.Z$ alt D\n"   \
+            "class .*\\.gz$ alt D\n"  \
+            "class .*\\.tgz$ alt D\n"
+      },
       {
         NULL, NULL
       }
@@ -149,6 +167,7 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
   
    PARSER_MAPPING default_parser_mapping[] =
    {
+
       /*
        * The following describes this table for those interested in
        * updating it manually.
@@ -173,6 +192,7 @@ static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $"
       { NULL,NULL,(CHARTYPE*)"TLD",  (CHARTYPE*)"*.tld"  , NULL  ,0, NULL },
       { NULL,NULL,(CHARTYPE*)"HTML", (CHARTYPE*)"*.htm"  , NULL  ,0, NULL },
       { NULL,NULL,(CHARTYPE*)"HTML", (CHARTYPE*)"*.html" , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"DIR",  (CHARTYPE*)"DIR.DIR", NULL  ,0, NULL },
       { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"rexx"  ,4, NULL },
       { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"regina",6, NULL },
       { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"rxx"   ,3, NULL },
@@ -194,9 +214,7 @@ void set_global_defaults()
 /*--------------------------- local data ------------------------------*/
  int i;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_global_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_global_defaults");
 /*---------------------------------------------------------------------*/
 /* Set defaults for all environments first...                          */
 /*---------------------------------------------------------------------*/
@@ -206,6 +224,9 @@ void set_global_defaults()
  INSERTMODEx = FALSE;
  CLEARERRORKEYx = -1;
  LINEND_VALUEx = '#';
+ EQUIVCHARx = '=';
+ EQUIVCHARstr[0] = '=';
+ EQUIVCHARstr[1] = '\0';
  REPROFILEx = FALSE;
  TABI_ONx = FALSE;
  TABI_Nx = 8;
@@ -220,7 +241,7 @@ void set_global_defaults()
     EOLx = EOLOUT_NONE;
  else
    {
-#ifdef UNIX
+#if defined(UNIX) || defined(AMIGA)
     EOLx = EOLOUT_LF;
 #endif
 #if defined(DOS) || defined(OS2) || defined(WIN32)
@@ -248,9 +269,7 @@ void set_global_defaults()
 /*---------------------------------------------------------------------*/
  set_global_look_defaults();
  set_global_feel_defaults();
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -263,9 +282,7 @@ void set_global_look_defaults()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_global_look_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_global_look_defaults");
  switch(compatible_look)
    {
     case COMPAT_THE:
@@ -293,10 +310,16 @@ void set_global_look_defaults()
          PREFIXx = PREFIX_ON|PREFIX_LEFT;
          prefix_gap = 1;
          break;
+    case COMPAT_ISPF:
+         CLEARSCREENx = TRUE;
+         CLOCKx = FALSE;
+         HEXDISPLAYx = FALSE;
+         NONDISPx = '"';
+         PREFIXx = PREFIX_ON|PREFIX_LEFT;
+         prefix_gap = 1;
+         break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -309,9 +332,7 @@ void set_global_feel_defaults()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_global_feel_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_global_feel_defaults");
  switch(compatible_feel)
    {
     case COMPAT_THE:
@@ -327,10 +348,12 @@ void set_global_feel_defaults()
          CMDARROWSTABCMDx = TRUE;
          LINEND_STATUSx = TRUE;
          break;
+    case COMPAT_ISPF:
+         CMDARROWSTABCMDx = TRUE;
+         LINEND_STATUSx = TRUE;
+         break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -344,9 +367,7 @@ FILE_DETAILS *filep;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_file_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_file_defaults");
 /*---------------------------------------------------------------------*/
 /* Set defaults for all environments first...                          */
 /*---------------------------------------------------------------------*/
@@ -375,6 +396,10 @@ FILE_DETAILS *filep;
          filep->colouring = TRUE;
          filep->backup = BACKUP_OFF;
          break;
+    case COMPAT_ISPF:
+         filep->colouring = TRUE;
+         filep->backup = BACKUP_OFF;
+         break;
     case COMPAT_KEDITW:
          filep->colouring = TRUE;
          filep->backup = BACKUP_OFF;
@@ -384,9 +409,7 @@ FILE_DETAILS *filep;
          filep->backup = BACKUP_OFF;
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -402,9 +425,7 @@ VIEW_DETAILS *viewp;
  register int i=0;
  short tabinc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_view_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_view_defaults");
 /*---------------------------------------------------------------------*/
 /* Set defaults for all environments first...                          */
 /*---------------------------------------------------------------------*/
@@ -456,8 +477,11 @@ VIEW_DETAILS *viewp;
  viewp->wordwrap = FALSE;
  viewp->wrap = FALSE;
  viewp->zone_start = 1;
+ viewp->synonym = TRUE;
  viewp->zone_end = max_line_length;
  viewp->autoscroll = (-1);  /* scroll half */
+ viewp->boundmark = BOUNDMARK_OFF; /* normal default is BOUNDMARK_ZONE */
+ viewp->syntax_headers = HEADER_ALL; /* ALL headers applied */
 
  if (viewp->cmd_line == 'O')
    {
@@ -496,6 +520,18 @@ VIEW_DETAILS *viewp;
          viewp->msgline_off = 2;
          viewp->msgline_rows = 2;
          break;
+    case COMPAT_ISPF:
+         viewp->number = FALSE;
+         viewp->prefix = PREFIX_ON|PREFIX_LEFT;
+         viewp->prefix_width = 7;
+         viewp->prefix_gap = 1;
+         viewp->scale_on = TRUE;
+         viewp->tab_off = (-3);
+         viewp->msgline_base = POSITION_TOP;
+         viewp->msgline_off = 2;
+         viewp->msgline_rows = 2;
+         viewp->cmd_line = 'T';
+         break;
     case COMPAT_KEDITW:
     case COMPAT_KEDIT:
          viewp->number = FALSE;
@@ -532,6 +568,20 @@ VIEW_DETAILS *viewp;
          viewp->imp_os = FALSE;
 #else
          viewp->imp_os = TRUE;
+#endif
+         viewp->linend_status = TRUE;
+         viewp->linend_value = '#';
+         viewp->stay = FALSE;
+         viewp->tab_off = (-3);
+         tabinc = 3;
+         break;
+    case COMPAT_ISPF:
+         viewp->case_enter = CASE_UPPER;
+         viewp->imp_macro = TRUE;
+#if defined(USE_XCURSES)
+         viewp->imp_os = FALSE;
+#else
+         viewp->imp_os = TRUE;
 #endif
          viewp->linend_status = TRUE;
          viewp->linend_value = '#';
@@ -553,9 +603,7 @@ VIEW_DETAILS *viewp;
    }
  for (i=0;i<MAX_NUMTABS;i++)
      viewp->tabs[i] = 1 + (i*tabinc);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -573,9 +621,7 @@ CHARTYPE *prf_file,*prf_arg;
  bool save_in_macro=in_macro;
  short macrorc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: get_profile");
-#endif
+ TRACE_FUNCTION("default.c: get_profile");
 /*---------------------------------------------------------------------*/
 /* To get here, we either have a specified a valid profile name or we  */
 /* haven't specified a profile file at all.                            */
@@ -616,9 +662,7 @@ CHARTYPE *prf_file,*prf_arg;
        display_error(52,(CHARTYPE *)"",FALSE);
    }
  in_macro = save_in_macro;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
 /* return(rc);*/
  return(RC_OK);
 }
@@ -633,18 +677,14 @@ short defaults_for_first_file()
 /*--------------------------- local data ------------------------------*/
  register int i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: defaults_for_first_file");
-#endif
+ TRACE_FUNCTION("default.c: defaults_for_first_file");
 /*---------------------------------------------------------------------*/
 /* Add to view linked list.                                            */
 /*---------------------------------------------------------------------*/
  if ((CURRENT_VIEW = vll_add(vd_first,vd_current,sizeof(VIEW_DETAILS)))
                    == (VIEW_DETAILS *)NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OUT_OF_MEMORY);
    }
  if (vd_first == (VIEW_DETAILS *)NULL)
@@ -688,9 +728,7 @@ short defaults_for_first_file()
     CURRENT_VIEW->previous_window =       WINDOW_FILEAREA;
    }
  CURRENT_VIEW->preserved_view_details = (PRESERVED_VIEW_DETAILS *)NULL;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -705,15 +743,11 @@ VIEW_DETAILS *base_view;
 /*--------------------------- local data ------------------------------*/
  register int i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: defaults_for_other_files");
-#endif
+ TRACE_FUNCTION("default.c: defaults_for_other_files");
  if ((CURRENT_VIEW = vll_add(vd_first,vd_current,sizeof(VIEW_DETAILS)))
                    == (VIEW_DETAILS *)NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OUT_OF_MEMORY);
    }
  if (CURRENT_VIEW->next == (VIEW_DETAILS *)NULL)
@@ -744,6 +778,8 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->zone_start =      base_view->zone_start;
     CURRENT_VIEW->zone_end =        base_view->zone_end;
     CURRENT_VIEW->autoscroll =      base_view->autoscroll;
+    CURRENT_VIEW->boundmark =       base_view->boundmark;
+    CURRENT_VIEW->syntax_headers =  base_view->syntax_headers;
     
     for (i=0;i<VIEW_WINDOWS;i++)
       {
@@ -889,9 +925,7 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->previous_window =       WINDOW_FILEAREA;
    }
  CURRENT_VIEW->preserved_view_details = (PRESERVED_VIEW_DETAILS *)NULL;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -907,9 +941,7 @@ FILE_DETAILS *fd;
  RESERVED *curr=NULL;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: default_file_attributes");
-#endif
+ TRACE_FUNCTION("default.c: default_file_attributes");
 
  set_file_defaults(CURRENT_FILE);
 
@@ -955,9 +987,7 @@ FILE_DETAILS *fd;
        }
     }
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -977,9 +1007,7 @@ void set_screen_defaults()
  short my_prefix_width=0,my_prefix_gap=0;
  bool my_arrow=TRUE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_screen_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_screen_defaults");
 /*---------------------------------------------------------------------*/
 /* Set values that affect the placement of each screen depending on    */
 /* the position of the status line...                                  */
@@ -1187,9 +1215,7 @@ void set_screen_defaults()
        exit(1);
     }
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1202,9 +1228,7 @@ void set_defaults()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_defaults");
 /*---------------------------------------------------------------------*/
 /* Set up screen default sizes.                                        */
 /*---------------------------------------------------------------------*/
@@ -1223,9 +1247,7 @@ void set_defaults()
  memset(cmd_rec,' ',max_line_length);
  cmd_rec_len = 0;
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1240,9 +1262,7 @@ int prey,prex;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_THE_key_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_THE_key_defaults");
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for THE           */
 /* compatibility mode.                                                 */
@@ -1274,9 +1294,7 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB");
  Define((CHARTYPE *)"ENTER");
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1291,9 +1309,7 @@ int prey,prex;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_XEDIT_key_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_XEDIT_key_defaults");
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for XEDIT         */
 /* compatibility mode.                                                 */
@@ -1324,9 +1340,53 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB sos tabfieldb");
  Define((CHARTYPE *)"TAB sos tabfieldf");
 #endif
-#ifdef THE_TRACE
- trace_return();
+ TRACE_RETURN();
+ return(rc);
+}
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short set_ISPF_key_defaults(int prey,int prex)
+#else
+short set_ISPF_key_defaults(prey,prex)
+int prey,prex;
 #endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ short rc=RC_OK;
+/*--------------------------- processing ------------------------------*/
+ TRACE_FUNCTION("default.c: set_XEDIT_key_defaults");
+/*---------------------------------------------------------------------*/
+/* This function is for resetting all default values for XEDIT         */
+/* compatibility mode.                                                 */
+/*---------------------------------------------------------------------*/
+ Define((CHARTYPE *)"F2 sos lineadd");
+ Define((CHARTYPE *)"F3 quit");
+ Define((CHARTYPE *)"F4 sos tabf");
+ Define((CHARTYPE *)"F6 ?");
+ Define((CHARTYPE *)"F7 up");
+ Define((CHARTYPE *)"F8 down");
+ Define((CHARTYPE *)"F9 =");
+ Define((CHARTYPE *)"F11 spltjoin");
+ Define((CHARTYPE *)"CURD cursor screen down");
+ Define((CHARTYPE *)"CURL cursor screen left");
+ Define((CHARTYPE *)"CURR cursor screen right");
+ Define((CHARTYPE *)"CURU cursor screen up");
+#if defined(UNIX) && !defined(USE_EXTCURSES) && !defined(USE_XCURSES)
+ Define((CHARTYPE *)"C-M sos doprefix execute");
+# if defined(KEY_BTAB)
+ Define((CHARTYPE *)"S-TAB sos tabfieldb");
+# endif
+# if defined(KEY_TAB)
+ Define((CHARTYPE *)"KEY_TAB sos tabfieldf");
+# endif
+ Define((CHARTYPE *)"C-I sos tabfieldf");
+#else
+ Define((CHARTYPE *)"ENTER sos doprefix execute");
+ Define((CHARTYPE *)"S-TAB sos tabfieldb");
+ Define((CHARTYPE *)"TAB sos tabfieldf");
+#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1341,9 +1401,7 @@ int prey,prex;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: set_KEDIT_key_defaults");
-#endif
+ TRACE_FUNCTION("default.c: set_KEDIT_key_defaults");
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for KEDIT         */
 /* compatibility mode.                                                 */
@@ -1377,9 +1435,7 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB");
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1396,9 +1452,7 @@ short construct_default_parsers()
    int i;
    CHARTYPE tmp[20];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("default.c: construct_default_parsers");
-#endif
+   TRACE_FUNCTION("default.c: construct_default_parsers");
 /*---------------------------------------------------------------------*/
    for (i=0;;i++)
    {
@@ -1422,9 +1476,7 @@ short construct_default_parsers()
       }
    }
 
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return(rc);
 }
 /***********************************************************************/
@@ -1439,18 +1491,14 @@ short destroy_all_parsers()
  short rc=RC_OK;
  PARSER_DETAILS *curr=first_parser;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: destroy_all_parsers");
-#endif
+ TRACE_FUNCTION("default.c: destroy_all_parsers");
  while( curr->next != NULL )
  {
     destroy_parser(curr);
     curr = curr->next;
  }
  first_parser = last_parser = parserll_free(first_parser);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1467,9 +1515,7 @@ short construct_default_parser_mapping()
  PARSER_DETAILS *currp;
  int i;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: construct_default_parser_mapping");
-#endif
+ TRACE_FUNCTION("default.c: construct_default_parser_mapping");
 /*---------------------------------------------------------------------*/
  for (i=0;;i++)
  {
@@ -1484,6 +1530,7 @@ short construct_default_parser_mapping()
        if (curr->filemask == NULL)
        {
           display_error(30,(CHARTYPE *)"",FALSE);
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY);
        }
        strcpy((DEFCHAR *)curr->filemask,(DEFCHAR *)default_parser_mapping[i].filemask);
@@ -1494,6 +1541,7 @@ short construct_default_parser_mapping()
        if (curr->magic_number == NULL)
        {
           display_error(30,(CHARTYPE *)"",FALSE);
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY);
        }
        strcpy((DEFCHAR *)curr->magic_number,(DEFCHAR *)default_parser_mapping[i].magic_number);
@@ -1521,9 +1569,7 @@ short construct_default_parser_mapping()
       MyRexxRegisterFunctionExe(tmp);
    }
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1540,9 +1586,7 @@ CHARTYPE *tldname;
  int i;
  CHARTYPE *contents=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("default.c: find_default_parser");
-#endif
+ TRACE_FUNCTION("default.c: find_default_parser");
 /*---------------------------------------------------------------------*/
  tldname = NULL;
  for (i=0;;i++)
@@ -1556,8 +1600,6 @@ CHARTYPE *tldname;
        break;
     }
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(contents);
 }
