@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: directry.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: directry.c,v 1.2 2000/12/09 23:58:22 mark Exp $";
 
 #if defined(__OS2__) && !defined(__EMX__)
 #   define INCL_DOS
@@ -94,7 +94,7 @@ CHARTYPE *path, *file;
  return(filebuf);
 }
 /*********************************************************************/
-#if defined(UNIX) || defined(EMX)
+#if defined(UNIX) || defined(EMX) || (defined(AMIGA) && defined(GCC))
 #ifdef HAVE_PROTO
 short getfiles(CHARTYPE *path,CHARTYPE *files,struct dirfile **dpfirst,
                                     struct dirfile **dplast)
@@ -580,7 +580,7 @@ int facl;
 #endif
 /*********************************************************************/
 {
-#ifdef UNIX
+#if defined(UNIX) || defined(AMIGA)
  ATTR_TYPE ftype=(attrs & S_IFMT);
 
  str_attr[11] = '\0';
@@ -644,7 +644,7 @@ ATTR_TYPE attrs;
 #endif
 /*********************************************************************/
 {
-#ifdef UNIX
+#if defined(UNIX) || defined(AMIGA)
  ATTR_TYPE ftype=(attrs & S_IFMT);
 
  if (ftype == S_IFDIR)
