@@ -34,7 +34,7 @@
  */
 
 /*
-$Id: directry.h,v 1.1 1999/06/25 06:11:56 mark Exp mark $
+$Id: directry.h,v 1.2 2000/12/09 23:59:47 mark Exp $
 */
 
 #if defined(DOS) && defined(TC)
@@ -348,6 +348,48 @@ $Id: directry.h,v 1.1 1999/06/25 06:11:56 mark Exp mark $
 # define YY_MASK(a) ((a->tm_year)+1900)
 #endif
 
+#if defined(AMIGA) && defined(GCC)
+# if defined(HAVE_DIRENT_H)
+#   include <dirent.h>
+# endif
+# if defined(HAVE_SYS_STAT_H)
+#   include <sys/stat.h>
+# endif
+# if defined(HAVE_SYS_MODE_H)
+#   include <sys/mode.h>
+# endif
+# if defined(HAVE_TIME_H)
+#  include <time.h>
+# endif
+
+# define F_RO 0
+# define F_HI 0
+# define F_SY 0
+# define F_DI 0
+# define F_AR 0
+
+# define ATTR_TYPE mode_t
+# define SIZE_TYPE long
+# define TIME_TYPE time_t
+# define DATE_TYPE CHARTYPE
+# define D_TYPE    struct tm *
+# define T_TYPE    struct tm *
+# define DONE_TYPE short
+
+# define HOUR_MASK (time->tm_hour)
+# define MINU_MASK (time->tm_min)
+# define DAYS_MASK (date->tm_mday)
+# define MONT_MASK (mon[date->tm_mon])
+# define YEAR_MASK (date->tm_year)
+
+# define HH_MASK(a) (a->tm_hour)
+# define MI_MASK(a) (a->tm_min)
+# define SS_MASK(a) (a->tm_sec)
+# define DD_MASK(a) (a->tm_mday)
+# define MM_MASK(a) (a->tm_mon)
+# define YY_MASK(a) ((a->tm_year)+1900)
+#endif
+
 struct dirfile {
 	CHARTYPE	*fname;		/* file name */
 	CHARTYPE	*lname;		/* link name */
