@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: error.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: error.c,v 1.2 2000/12/10 00:18:52 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -289,9 +289,7 @@ static CHARTYPE *error_message[] =
 };
  int new_last_message_length = 0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("error.c:   display_error");
-#endif
+ TRACE_FUNCTION("error.c:   display_error");
 /*---------------------------------------------------------------------*/
 /* Always save message text, even if MSGMODE is OFF...                 */
 /* If no error number, display text only...                            */
@@ -302,7 +300,10 @@ static CHARTYPE *error_message[] =
     last_message_length = new_last_message_length;
     last_message = (CHARTYPE *)(*the_malloc)(last_message_length*sizeof(CHARTYPE));
     if (last_message == NULL)
+    {
+          TRACE_RETURN();
        return;
+    }
    }
  else
    {
@@ -311,7 +312,10 @@ static CHARTYPE *error_message[] =
        last_message_length = new_last_message_length;
        last_message = (CHARTYPE *)(*the_realloc)(last_message,last_message_length*sizeof(CHARTYPE));
        if (last_message == NULL)
+        {
+          TRACE_RETURN();
           return;
+        }
       }
    }
  if (err_num == 0)
@@ -326,9 +330,7 @@ static CHARTYPE *error_message[] =
    {
     if (!CURRENT_VIEW->msgmode_status)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return;
       }
    }
@@ -338,9 +340,7 @@ static CHARTYPE *error_message[] =
 /*---------------------------------------------------------------------*/
  if (in_nomsg)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 
@@ -360,6 +360,7 @@ static CHARTYPE *error_message[] =
     }
     error_on_screen = TRUE;
     Operator("%s%s",hdr,last_message);
+    TRACE_RETURN();
     return;
  }
  }
@@ -377,9 +378,7 @@ static CHARTYPE *error_message[] =
     }
     error_on_screen = TRUE;
     fprintf(stderr,"%s\n",last_message);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
  }
 #endif
@@ -389,11 +388,13 @@ static CHARTYPE *error_message[] =
  last_error = lll_add(first_error,last_error,sizeof(LINE));
  if (last_error == NULL)
    {
+    TRACE_RETURN();
     return;
    }
  last_error->line = (CHARTYPE *)(*the_malloc)((strlen((DEFCHAR *)last_message)+1)*sizeof(CHARTYPE));
  if (last_error->line == NULL)
    {
+    TRACE_RETURN();
     return;
    }
  strcpy((DEFCHAR *)last_error->line,(DEFCHAR *)last_message);
@@ -420,9 +421,7 @@ static CHARTYPE *error_message[] =
 #endif
  if (first_screen_display)
     wrefresh(error_window);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -440,9 +439,7 @@ ROWTYPE rows;
  int start_row=0;
  COLOUR_ATTR attr;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("error.c:   open_msgline");
-#endif
+ TRACE_FUNCTION("error.c:   open_msgline");
  if (CURRENT_VIEW == NULL
  ||  CURRENT_FILE == NULL)
     set_up_default_colours((FILE_DETAILS *)NULL,&attr,ATTR_MSGLINE);
@@ -455,9 +452,7 @@ ROWTYPE rows;
     delwin(error_window);
  error_window = newwin(rows,CURRENT_SCREEN.screen_cols,CURRENT_SCREEN.screen_start_row+start_row,CURRENT_SCREEN.screen_start_col);
  wattrset(error_window,set_colour(&attr));
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -471,9 +466,7 @@ int key;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("error.c:   clear_msgline");
-#endif
+ TRACE_FUNCTION("error.c:   clear_msgline");
  /*
   * Only clear the message line if the supplied key matches that set
   * by SET CLEARERRORKEY.  -1 indicates any key can clear
@@ -494,9 +487,7 @@ int key;
     redraw_screen(current_screen);
     doupdate();
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -510,18 +501,14 @@ CHARTYPE *prompt;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("error.c:   display_prompt");
-#endif
+ TRACE_FUNCTION("error.c:   display_prompt");
  open_msgline(CURRENT_VIEW->msgline_base,CURRENT_VIEW->msgline_off,1);
  wmove(error_window,0,0);
  my_wclrtoeol(error_window);
  put_string(error_window,0,0,prompt,strlen((DEFCHAR *)prompt));
  wrefresh(error_window);
  error_on_screen = TRUE;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -539,9 +526,7 @@ void expose_msgline()
  short msgline_off=2;
  ROWTYPE msgline_rows=5;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("error.c:   expose_msgline");
-#endif
+ TRACE_FUNCTION("error.c:   expose_msgline");
 /*---------------------------------------------------------------------*/
 /* If msgmode is off, don't display any errors.                        */
 /*---------------------------------------------------------------------*/
@@ -549,9 +534,7 @@ void expose_msgline()
    {
     if (!CURRENT_VIEW->msgmode_status)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return;
       }
     msgline_rows = CURRENT_VIEW->msgline_rows;
@@ -585,8 +568,20 @@ void expose_msgline()
    }
  wnoutrefresh(error_window);
  error_on_screen = TRUE;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ if ( errors_to_display == msgline_rows
+ &&   errors_displayed % errors_to_display == 1
+ &&   curr_error != NULL )
+ {
+    wmove(error_window,msgline_rows-1,0);
+    my_wclrtoeol(error_window);
+    if (CURRENT_VIEW == NULL
+    ||  CURRENT_FILE == NULL)
+       mvwaddstr(error_window,msgline_rows-1,0,(DEFCHAR *)"Press any key to continue...");
+    else
+       put_string(error_window,msgline_rows-1,0,"Press any key to continue...",28);
+    wrefresh(error_window);
+    my_getch(stdscr);
+ }
+ TRACE_RETURN();
  return;
 }
