@@ -34,7 +34,7 @@
  */
 
 /*
-$Id: key.h,v 1.1 1999/06/25 06:11:56 mark Exp mark $
+$Id: key.h,v 1.2 2000/12/10 00:29:20 mark Exp $
 */
 
 #if defined(USE_EXTCURSES)
@@ -409,22 +409,22 @@ KEYS key_table[] =
   {(CHARTYPE *)"S-DEL",KEY_S_DEL,SHIFT_SHIFT},
 # endif
 # ifdef KEY_SHIFT_L
-  {(CHARTYPE *)"SHIFT-L",KEY_SHIFT_L,0},
+  {(CHARTYPE *)"SHIFT-L",KEY_SHIFT_L,SHIFT_MODIFIER_ONLY},
 # endif
 # ifdef KEY_SHIFT_R
-  {(CHARTYPE *)"SHIFT-R",KEY_SHIFT_R,0},
+  {(CHARTYPE *)"SHIFT-R",KEY_SHIFT_R,SHIFT_MODIFIER_ONLY},
 # endif
 # ifdef KEY_CONTROL_L
-  {(CHARTYPE *)"CONTROL-L",KEY_CONTROL_L,0},
+  {(CHARTYPE *)"CONTROL-L",KEY_CONTROL_L,SHIFT_MODIFIER_ONLY},
 # endif
 # ifdef KEY_CONTROL_R
-  {(CHARTYPE *)"CONTROL-R",KEY_CONTROL_R,0},
+  {(CHARTYPE *)"CONTROL-R",KEY_CONTROL_R,SHIFT_MODIFIER_ONLY},
 # endif
 # ifdef KEY_ALT_L
-  {(CHARTYPE *)"ALT-L",KEY_ALT_L,0},
+  {(CHARTYPE *)"ALT-L",KEY_ALT_L,SHIFT_MODIFIER_ONLY},
 # endif
 # ifdef KEY_ALT_R
-  {(CHARTYPE *)"ALT-R",KEY_ALT_R,0},
+  {(CHARTYPE *)"ALT-R",KEY_ALT_R,SHIFT_MODIFIER_ONLY},
 # endif
 #else
   {(CHARTYPE *)"CURD"     ,KEY_DOWN ,0},
