@@ -40,7 +40,7 @@
  * Copyright (C) 1992-1994  Anders Christensen <anders@pvv.unit.no>
  */
 
-static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: memory.c,v 1.2 2000/12/10 04:23:23 mark Exp $";
 
 /*
  * The routines in this file try to minimize the the number of calls
@@ -84,9 +84,7 @@ static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  *
  * If you don't #define FLISTS, then malloc() and free() should be
  * used instead. That might be very slow on some machines, since rexx
- * tend to use lots of small size memory. If you #define THE_TRACEMEM,
  * memory is traced, which also tend to be slow, since there is a lot
- * of overhead in allocation and deallocation. Also note that in the
  * current implementation you can use malloc()/free() in parallel with
  * the routines defined here.
  *
@@ -97,9 +95,7 @@ static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  * this metod (typical less than 100 for medium sized programs). But
  * this is of course dependent on how the program uses memory. 
  *
- * The tracing part of this file, (#ifdef THE_TRACEMEM) is an optional
  * extention for debugging purposes. Whenever memory is allocated,
- * mymalloc() allocates 16 bytes more than needed. These bytes are
  * used like this:
  *
  *   0       4       8      12       16 bytes
@@ -115,9 +111,7 @@ static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  * there to fill the space, and can be used for more useful purposed
  * if needed.
  *
- * An additional option to THE_TRACEMEM is filling allocated and deallocated
  * memory with bitpatterns. If the PATTERN_MEMORY cpp-variable is set,
- * all allocated memory is initated to NOT_USED, and deallocated memory 
  * is set BEEN_USED before deallocation.
  * 
  * Garbage-collection is not implemented, but listleaked will list out
@@ -129,9 +123,7 @@ static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  * be traced and then garbage collected, or it should have a sort 
  * of transaction oriented memory management (yuk!).
  *
- * NOTE that #define'ing THE_TRACEMEM requires that your machine follows
  *      this:  sizeof(int) = sizeof(char*) = 32 bits. It might work
- *      for other machines to (having larger word size), but I don't
  *      guarantee it. 
  *
  */
@@ -188,7 +180,7 @@ void the_free_flists( void )
  * it will just forward the request to malloc()/free(). Note that 
  * this value should be less than or equal to CHUNK_SIZE.
  */
-#define MAX_INTERNAL_SIZE (2048)
+#define MAX_INTERNAL_SIZE (4096)
 
 /* 
  * MEMINFO_HASHSIZE is the size of the 'hashtable' used to find the size
@@ -236,7 +228,9 @@ void the_free_flists( void )
  * into consideration that all these sizes should be aligned according
  * to the size of ints and pointers, so don't make them too small.
  */
-static int sizes[] = {    8,   12,   16,   24,   32,   48,   64,   96, 
+#define NUMBER_SIZES 19
+static const int sizes[NUMBER_SIZES] = 
+                     {    8,   12,   16,   24,   32,   48,   64,   96, 
                         128,  192 , 256,  384,  512,  768, 1024, 1536, 
                        2048, 3072, 4096 } ;
 
@@ -246,7 +240,7 @@ static int sizes[] = {    8,   12,   16,   24,   32,   48,   64,   96,
  * of free memory chunks of size 8, flist[1] to memory of size 12 etc.
  * The size of this array is the same as the size of 'sizes'.
  */
-static char *theflists[sizeof(sizes)/sizeof(int)] = { NULL } ;
+static char *theflists[NUMBER_SIZES] = { NULL } ;
 
 /*
  * The type meminfo holds the info about the connection between the 
@@ -294,6 +288,26 @@ static short hash[ CHUNK_SIZE/4 + 1 ] ;
 static meminfo *first_chunk=NULL;
 static meminfo *curr_chunk=NULL;
 
+# ifdef THE_DEBUG_MEMORY2
+static int show_a_free_list(int bin, char *str)
+{
+   char *ptr;
+   int j=0;
+
+   if ( theflists[bin] == NULL )
+   {
+      if (str)
+         fprintf(stderr,"%sbin[%d] Free List unallocated Maximum %d Size: %d\n",str,bin,(CHUNK_SIZE / sizes[bin]), sizes[bin]);
+   }
+   else
+   {
+      for (j=1,ptr=theflists[bin]; *(char**)ptr!=NULL && j<5000; ptr=*(char **)ptr,j++ );
+      if (str)
+         fprintf(stderr,"%sbin[%d] Number in Free List %d Maximum %d Size: %d\n",str,bin,j,(CHUNK_SIZE / sizes[bin]), sizes[bin]);
+   }
+   return j;
+}
+#endif
 /*
  * This function stores in a singly linked list all chunks of memory
  * that are allocated with malloc(). This is so that they can all be
@@ -421,7 +435,7 @@ void init_memory_table()
 
    if (sizeof(int)>4 || sizeof(int*)>4)
       hash[3] = 2 ;
-   memset( theflists, 0, ( sizeof(sizes) / sizeof(int) ) * sizeof(char *) );
+   memset( theflists, 0, NUMBER_SIZES * sizeof(char *) );
 
 }
 
@@ -519,6 +533,9 @@ int size;
    register int bin ;     /* bin no in array of freelists */
    register char *vptr ;  /* holds the result */
    register void *result ; 
+#ifdef THE_DEBUG_MEMORY2
+   int before, after;
+#endif
 
    /*
     * If memory is too big, let malloc() handle the problem. 
@@ -526,7 +543,11 @@ int size;
    if (size>MAX_INTERNAL_SIZE) 
    {
       if ((result=malloc( size )))
+      {
+         if (register_mem( result ))
+            return(NULL);
          return result ;
+      }
       else
           return NULL;
    }
@@ -548,7 +569,7 @@ int size;
        * 'incremented' later, so it must be set to the value which now
        * is to be allocated. 
        */
-      vptr = malloc( CHUNK_SIZE + sizes[bin]) ;
+      vptr = malloc( CHUNK_SIZE ) ;
       if (!vptr)
           return(NULL);
       theflists[bin] = vptr ;
@@ -577,6 +598,10 @@ int size;
          *(char**)ptr = ptr + sizes[bin] ;
   
       *((char**)(ptr-sizes[bin])) = NULL ;
+
+#ifdef THE_DEBUG_MEMORY2
+      show_a_free_list( bin, "get_a_block(): empty freelist for ");
+#endif
    }
 
    /*
@@ -584,7 +609,15 @@ int size;
     * freelist instead of the one we just allocated, and return to 
     * caller.
     */
+#ifdef THE_DEBUG_MEMORY2
+   before = show_a_free_list( bin, NULL);
+#endif
    theflists[bin] = (*((char**)(vptr))) ;
+#ifdef THE_DEBUG_MEMORY2
+   after = show_a_free_list( bin, NULL );
+   if ( before - 1 != after )
+      fprintf(stderr,"****** get_a_block() for bin [%d] failed. Before %d After %d\n",bin,before,after);
+#endif
    return (vptr) ;
 }
 
@@ -609,6 +642,9 @@ void *ptr;
 {
    char *cptr ;      /* pseudonym for 'ptr' */
    meminfo *mptr ;   /* caches the right element in hashtable */
+#ifdef THE_DEBUG_MEMORY2
+   int before, after;
+#endif
 
    /*
     * initialize a few values, 'cptr' is easy, while 'mptr' is the
@@ -640,8 +676,16 @@ void *ptr;
       /* 
        * Link it into the first place of the freelist.
        */
+#ifdef THE_DEBUG_MEMORY2
+      before = show_a_free_list( mptr->size, NULL );
+#endif
       *((char**)cptr) = theflists[mptr->size] ;
       theflists[mptr->size] = cptr ;
+#ifdef THE_DEBUG_MEMORY2
+      after = show_a_free_list( mptr->size, NULL );
+      if ( before + 1 != after )
+         fprintf(stderr,"****** give_a_block() for bin [%d] failed. Before %d After %d\n",mptr->size,before,after);
+#endif
    }
    else
       free( ptr ) ; 
@@ -740,10 +784,10 @@ void the_free_flists()
    while( ptr )
    {
       next = ptr->next;
-      free( ptr->start );
       free( ptr );
       ptr = next;
    }
+   first_chunk = curr_chunk = NULL;
    return;
 }
 #endif /* __BOUNDS_CHECKING_ON */
