@@ -38,7 +38,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: mouse.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: mouse.c,v 1.2 2000/12/10 00:36:43 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -118,9 +118,7 @@ int *button,*button_action,*button_modifier;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:  get_mouse_info");
-#endif
+ TRACE_FUNCTION("mouse.c:  get_mouse_info");
  request_mouse_pos();
  /*
   * Save the current mouse position
@@ -139,9 +137,7 @@ int *button,*button_action,*button_modifier;
              *button = 3;
           else
             {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return(RC_OK);
             }
     if (BUTTON_STATUS(*button) & BUTTON_SHIFT)
@@ -164,9 +160,7 @@ int *button,*button_action,*button_modifier;
     *button = *button_action = *button_modifier = 0;
     rc = RC_INVALID_OPERAND;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 #endif
@@ -182,17 +176,13 @@ int *y,*x;
 /***********************************************************************/
 {
  int begy,begx,maxy,maxx;
-#ifdef THE_TRACE
- trace_function("mouse.c:  wmouse_position");
-#endif
+ TRACE_FUNCTION("mouse.c:  wmouse_position");
  /* if the current mouse position is outside the provided window, put  */
  /* -1 in x and y                                                      */
  if (win == (WINDOW *)NULL)
  {
    *y = *x = (-1);
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
    return;
  }
  getbegyx(win,begy,begx);
@@ -209,9 +199,7 @@ int *y,*x;
    *x = ncurses_mouse_event.x - begx;
    *y = ncurses_mouse_event.y - begy;
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -226,9 +214,7 @@ int *button,*button_action,*button_modifier;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:  get_mouse_info");
-#endif
+ TRACE_FUNCTION("mouse.c:  get_mouse_info");
  getmouse(&ncurses_mouse_event);
  /*
   * Save the current mouse position
@@ -258,9 +244,7 @@ int *button,*button_action,*button_modifier;
        else
        {
           *button = *button_action = *button_modifier = 0;
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return RC_INVALID_OPERAND;
        }
     }
@@ -301,9 +285,7 @@ int *button,*button_action,*button_modifier;
        }
     }
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 #endif
@@ -325,29 +307,21 @@ CHARTYPE *params;
  int curr_button_modifier=0;
  int curr_button=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:  THEMouse");
-#endif
+ TRACE_FUNCTION("mouse.c:  THEMouse");
  which_window_is_mouse_in(&scrn,&w);
  if (w == (-1)) /* shouldn't happen! */
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
  rc = get_mouse_info(&curr_button,&curr_button_action,&curr_button_modifier);
  if (rc != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  rc = execute_mouse_commands(MOUSE_INFO_TO_KEY(w,curr_button,curr_button_action,curr_button_modifier));
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -365,9 +339,7 @@ int *w;
  int j=0;
  int y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:  which_window_is_mouse_in");
-#endif
+ TRACE_FUNCTION("mouse.c:  which_window_is_mouse_in");
  for (i=0;i<display_screens;i++)
    {
     for (j=0;j<VIEW_WINDOWS;j++)
@@ -380,9 +352,7 @@ int *w;
             {
              *scrn = i;
              *w = j;
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              return;
             }
          }
@@ -398,9 +368,7 @@ int *w;
    {
     *w = WINDOW_STATAREA;
     *scrn = current_screen;
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -416,9 +384,7 @@ int *w;
       {
        *w = WINDOW_DIVIDER;
        *scrn = current_screen;
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return;
       }
    }
@@ -426,9 +392,7 @@ int *w;
 /* To get here, the mouse is NOT in ANY window. Return an error.       */
 /*---------------------------------------------------------------------*/
  *w = (-1);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -441,14 +405,10 @@ void reset_saved_mouse_pos()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("mouse.c:  reset_saved_mouse_pos");
-#endif
+   TRACE_FUNCTION("mouse.c:  reset_saved_mouse_pos");
    last_mouse_x_pos = -1;
    last_mouse_y_pos = -1;
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -462,14 +422,10 @@ int *y,*x;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
-   trace_function("mouse.c:  get_saved_mouse_pos");
-#endif
+   TRACE_FUNCTION("mouse.c:  get_saved_mouse_pos");
    *x = last_mouse_x_pos;
    *y = last_mouse_y_pos;
-#ifdef THE_TRACE
-   trace_return();
-#endif
+   TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -482,9 +438,7 @@ void initialise_mouse_commands()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   initialise_mouse_commands");
-#endif
+ TRACE_FUNCTION("mouse.c:   initialise_mouse_commands");
 
 /*
  * Default mouse actions in FILEAREA
@@ -492,86 +446,86 @@ void initialise_mouse_commands()
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
 #endif
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_PRESS|MOUSE_SHIFT,
-            (CHARTYPE *)"CURSOR MOUSE#RESET BLOCK#MARK LINE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#RESET BLOCK#MARK LINE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_PRESS|MOUSE_CONTROL,
-            (CHARTYPE *)"CURSOR MOUSE#RESET BLOCK#MARK BOX",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#RESET BLOCK#MARK BOX",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_DRAG|MOUSE_SHIFT,
-            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_DRAG|MOUSE_CONTROL,
-            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_RIGHT|MOUSE_PRESS|MOUSE_SHIFT,
-            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_RIGHT|MOUSE_PRESS|MOUSE_CONTROL,
-            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE,FALSE,0);
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_RIGHT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_RIGHT|MOUSE_PRESS|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE,FALSE,0);
 #endif
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_DRAG|MOUSE_SHIFT,
-            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK LINE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_DRAG|MOUSE_CONTROL,
-            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#MARK BOX",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_DOUBLE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS EDIT",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS EDIT",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_LEFT|MOUSE_PRESS|MOUSE_ALT,
-            (CHARTYPE *)"BACKWARD",FALSE);
+            (CHARTYPE *)"BACKWARD",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_FILEAREA|MOUSE_RIGHT|MOUSE_PRESS|MOUSE_ALT,
-            (CHARTYPE *)"FORWARD",FALSE);
+            (CHARTYPE *)"FORWARD",FALSE,FALSE,0);
 /*
  * Default mouse actions in PREFIX area
  */
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_PREFIX|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_PREFIX|MOUSE_RIGHT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_PREFIX|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_PREFIX|MOUSE_RIGHT|MOUSE_PRESS|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS MAKECURR",FALSE,FALSE,0);
 #endif
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_PREFIX|MOUSE_LEFT|MOUSE_DOUBLE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE#SOS EDIT",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE#SOS EDIT",FALSE,FALSE,0);
 /*
  * Default mouse actions in COMMAND line
  */
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_COMMAND|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_COMMAND|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"CURSOR MOUSE",FALSE);
+            (CHARTYPE *)"CURSOR MOUSE",FALSE,FALSE,0);
 #endif
 /*
  * Default mouse actions in STATAREA
@@ -579,11 +533,11 @@ void initialise_mouse_commands()
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_STATAREA|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"STATUS",FALSE);
+            (CHARTYPE *)"STATUS",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_STATAREA|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"STATUS",FALSE);
+            (CHARTYPE *)"STATUS",FALSE,FALSE,0);
 #endif
 /*
  * Default mouse actions in IDLINE
@@ -591,17 +545,17 @@ void initialise_mouse_commands()
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_IDLINE|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"XEDIT",FALSE);
+            (CHARTYPE *)"XEDIT",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_IDLINE|MOUSE_RIGHT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"XEDIT -",FALSE);
+            (CHARTYPE *)"XEDIT -",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_IDLINE|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"XEDIT",FALSE);
+            (CHARTYPE *)"XEDIT",FALSE,FALSE,0);
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_IDLINE|MOUSE_RIGHT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"XEDIT -",FALSE);
+            (CHARTYPE *)"XEDIT -",FALSE,FALSE,0);
 #endif
 /*
  * Default mouse actions in DIVIDER
@@ -609,16 +563,14 @@ void initialise_mouse_commands()
 #if defined(NCURSES_MOUSE_VERSION)
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_DIVIDER|MOUSE_LEFT|MOUSE_CLICK|MOUSE_NORMAL,
-            (CHARTYPE *)"SCREEN 1",FALSE);
+            (CHARTYPE *)"SCREEN 1",FALSE,FALSE,0);
 #else
  add_define(&first_mouse_define,&last_mouse_define,
             WINDOW_DIVIDER|MOUSE_LEFT|MOUSE_RELEASE|MOUSE_NORMAL,
-            (CHARTYPE *)"SCREEN 1",FALSE);
+            (CHARTYPE *)"SCREEN 1",FALSE,FALSE,0);
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -632,13 +584,9 @@ int w,button,button_action,button_modifier;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   mouse_info_to_key");
-#endif
+ TRACE_FUNCTION("mouse.c:   mouse_info_to_key");
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(MOUSE_INFO_TO_KEY(w,button,button_action,button_modifier));
 }
 #endif
@@ -657,9 +605,7 @@ CHARTYPE *key_name;
  int w=0,b=0,ba=0,bm=0;
  CHARTYPE *win_name=(CHARTYPE *)"*** unknown ***";
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   mouse_key_number_to_name");
-#endif
+ TRACE_FUNCTION("mouse.c:   mouse_key_number_to_name");
  w = MOUSE_WINDOW_MASK(key_number);
  b = (MOUSE_BUTTON_MASK(key_number)>>MOUSE_BUTTON_OFFSET);
  ba = (MOUSE_ACTION_MASK(key_number)>>MOUSE_ACTION_OFFSET);
@@ -675,9 +621,7 @@ CHARTYPE *key_name;
   }
  sprintf((DEFCHAR *)key_name,"%s%s%s in %s",button_modifier_names[bm],button_action_names[ba],
          button_names[b],win_name);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(key_name);
 }
 /***********************************************************************/
@@ -699,9 +643,7 @@ CHARTYPE *mnemonic,*win_name;
  int b=0,ba=0,bm=0;
  CHARTYPE tmp_buf[6];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   find_mouse_key_value");
-#endif
+ TRACE_FUNCTION("mouse.c:   find_mouse_key_value");
 /*---------------------------------------------------------------------*/
 /* Parse the mnemonic for a valid mouse key definition...              */
 /*---------------------------------------------------------------------*/
@@ -720,9 +662,7 @@ CHARTYPE *mnemonic,*win_name;
     else
       {
        display_error(1,mnemonic,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(-1);
       }
    }
@@ -731,9 +671,7 @@ CHARTYPE *mnemonic,*win_name;
    && tmp_buf[4] != 'b'))
    {
     display_error(1,mnemonic,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(-1);
    }
  /*
@@ -759,9 +697,7 @@ CHARTYPE *mnemonic,*win_name;
          break;
     default:
          display_error(1,mnemonic,FALSE);
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(-1);
          break;
    }
@@ -791,9 +727,7 @@ CHARTYPE *mnemonic,*win_name;
          break;
     default:
          display_error(1,mnemonic,FALSE);
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(-1);
          break;
    }
@@ -816,9 +750,7 @@ CHARTYPE *mnemonic,*win_name;
          break;
     default:
          display_error(1,mnemonic,FALSE);
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(-1);
          break;
    }
@@ -836,15 +768,11 @@ CHARTYPE *mnemonic,*win_name;
  if (w == (-1))
    {
     display_error(1,win_name,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(-1);
    }
  key = w|b|ba|bm;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(key);
 }
 #if defined(HAVE_SB_INIT)
@@ -861,9 +789,7 @@ CHARTYPE *params;
  int cur=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   ScrollbarHorz");
-#endif
+ TRACE_FUNCTION("mouse.c:   ScrollbarHorz");
 /*---------------------------------------------------------------------*/
 /* Parse the mnemonic for a valid mouse key definition...              */
 /*---------------------------------------------------------------------*/
@@ -872,9 +798,7 @@ CHARTYPE *params;
     rc = Left((CHARTYPE*)"FULL");
  else
     rc = Right((CHARTYPE*)"FULL");
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -890,17 +814,13 @@ CHARTYPE *params;
  int cur=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("mouse.c:   ScrollbarVert");
-#endif
+ TRACE_FUNCTION("mouse.c:   ScrollbarVert");
 /*---------------------------------------------------------------------*/
 /* Parse the mnemonic for a valid mouse key definition...              */
 /*---------------------------------------------------------------------*/
  sb_get_vert(NULL,NULL,&cur);
  rc = execute_makecurr((LINETYPE)cur);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 #endif
