@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: print.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: print.c,v 1.2 2000/12/10 04:05:01 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -399,9 +399,7 @@ short target_type;
  LINETYPE start=0L,end=0L,len=0L;
  CHARTYPE *ptr=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   print_line");
-#endif
+ TRACE_FUNCTION("print.c:   print_line");
 
  if (close_spooler)
    {
@@ -415,9 +413,7 @@ short target_type;
 #else
        fclose(pp);
 #endif
-# ifdef THE_TRACE
-       trace_return();
-# endif
+       TRACE_RETURN();
        return;
       }
    }
@@ -434,9 +430,7 @@ short target_type;
     pp = popen((DEFCHAR *)spooler_name,"w");
     if (pp == NULL)
      {
-# ifdef THE_TRACE
-      trace_return();
-# endif
+      TRACE_RETURN();
       return;
      }
     spooler_open = TRUE;
@@ -447,9 +441,7 @@ short target_type;
     pp = fopen((DEFCHAR *)spooler_name,"ab");
     if (pp == NULL)
      {
-# ifdef THE_TRACE
-      trace_return();
-# endif
+      TRACE_RETURN();
       return;
      }
     spooler_open = TRUE;
@@ -464,9 +456,7 @@ short target_type;
 #else
     fprintf(pp,"%s%s",text,line_term);
 #endif
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -625,9 +615,7 @@ short target_type;
     else
        wmove(CURRENT_WINDOW,y,x);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 
@@ -647,9 +635,7 @@ int width;
  int numlen=0,first=0;
  char numbuf[33]; /* 10 + length of LINES_NOT_DISPLAYED */
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   make_shadow_line");
-#endif
+ TRACE_FUNCTION("print.c:   make_shadow_line");
  numlen = sprintf(numbuf," %ld%s",num_excluded,LINES_NOT_DISPLAYED);
  if (numlen > width)
     numlen = width;
@@ -663,9 +649,7 @@ int width;
  memset(buf,'-',width - first - numlen);
  /* terminate string */
  buf[width - first - numlen] = '\0';
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 
@@ -684,9 +668,7 @@ LINETYPE num_excluded;
  register int width=0;
  char buf[512];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   print_shadow_line");
-#endif
+ TRACE_FUNCTION("print.c:   print_shadow_line");
  if (CURRENT_VIEW->shadow)
    {
     width = min(sizeof(buf)-1,CURRENT_SCREEN.cols[WINDOW_FILEAREA]);
@@ -694,9 +676,7 @@ LINETYPE num_excluded;
     WriteString(buf,width);
     WriteString(line_term,strlen(line_term));
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 #else
@@ -715,9 +695,7 @@ LINETYPE num_excluded;
  register int width=0;
  char buf[512];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   print_shadow_line");
-#endif
+ TRACE_FUNCTION("print.c:   print_shadow_line");
  if (CURRENT_VIEW->shadow)
    {
     width = min(sizeof(buf)-1,CURRENT_SCREEN.cols[WINDOW_FILEAREA]);
@@ -725,9 +703,7 @@ LINETYPE num_excluded;
     fwrite(buf,width,1,pp);
     fputs((DEFCHAR *)line_term,pp);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 #endif
@@ -744,9 +720,7 @@ char *pn;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setprintername");
-#endif
+ TRACE_FUNCTION("print.c:   setprintername");
 
 #ifdef WIN32
  if ( hPrinter )
@@ -770,9 +744,7 @@ char *pn;
     EndDocument();
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return (rc);
 }
 
@@ -787,15 +759,11 @@ int cpi;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setfontcpi");
-#endif
+ TRACE_FUNCTION("print.c:   setfontcpi");
 #ifdef WIN32
  SetCPI(MAKELONG(cpi,savelpi));
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return (RC_OK);
 }
 
@@ -810,15 +778,11 @@ int lpi;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setfontlpi");
-#endif
+ TRACE_FUNCTION("print.c:   setfontlpi");
 #ifdef WIN32
  SetCPI(MAKELONG(savecpi,lpi));
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return (RC_OK);
 }
 
@@ -833,12 +797,8 @@ int ps;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setpagesize");
-#endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_FUNCTION("print.c:   setpagesize");
+ TRACE_RETURN();
  return (RC_OK);
 }
 
@@ -853,12 +813,8 @@ char *font;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setfontname");
-#endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_FUNCTION("print.c:   setfontname");
+ TRACE_RETURN();
  return (RC_OK);
 }
 
@@ -873,9 +829,7 @@ char or;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("print.c:   setorient");
-#endif
+ TRACE_FUNCTION("print.c:   setorient");
 
 #ifdef WIN32
  if (or == 'L') 
@@ -884,9 +838,7 @@ char or;
     SetOrient(DMORIENT_PORTRAIT);
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return (RC_OK);
 }
 #endif
