@@ -38,7 +38,7 @@
  */
 
 /*
-$Id: query.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
+$Id: query.h,v 1.2 2000/12/10 04:07:39 mark Exp $
 */
 
 
@@ -82,89 +82,92 @@ $Id: query.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #define ITEM_ECOLOUR                         31
 #define ITEM_EOF                             32
 #define ITEM_EOLOUT                          33
-#define ITEM_ETMODE                          34
-#define ITEM_FEXT                            35
-#define ITEM_FIELD                           36
-#define ITEM_FILENAME                        37
-#define ITEM_FILESTATUS                      38
-#define ITEM_FMODE                           39
-#define ITEM_FNAME                           40
-#define ITEM_FPATH                           41
-#define ITEM_FTYPE                           42
-#define ITEM_FULLFNAME                       43
-#define ITEM_GETENV                          44
-#define ITEM_HEX                             45
-#define ITEM_HEXDISPLAY                      46
-#define ITEM_HEXSHOW                         47
-#define ITEM_HIGHLIGHT                       48
-#define ITEM_IDLINE                          49
-#define ITEM_IMPMACRO                        50
-#define ITEM_IMPOS                           51
-#define ITEM_INPUTMODE                       52
-#define ITEM_INSERTMODE                      53
-#define ITEM_LASTKEY                         54
-#define ITEM_LASTMSG                         55
-#define ITEM_LASTRC                          56
-#define ITEM_LENGTH                          57
-#define ITEM_LINE                            58
-#define ITEM_LINEFLAG                        59
-#define ITEM_LINEND                          60
-#define ITEM_LSCREEN                         61
-#define ITEM_MACRO                           62
-#define ITEM_MACROEXT                        63
-#define ITEM_MACROPATH                       64
-#define ITEM_MARGINS                         65
-#define ITEM_MONITOR                         66
-#define ITEM_MOUSE                           67
-#define ITEM_MSGLINE                         68
-#define ITEM_MSGMODE                         69
-#define ITEM_NBFILE                          70
-#define ITEM_NEWLINES                        71
-#define ITEM_NONDISP                         72
-#define ITEM_NUMBER                          73
-#define ITEM_PARSER                          74
-#define ITEM_PENDING                         75
-#define ITEM_POINT                           76
-#define ITEM_POSITION                        77
-#define ITEM_PREFIX                          78
-#define ITEM_PRINTER                         79
-#define ITEM_READONLY                        80
-#define ITEM_READV                           81
-#define ITEM_REPROFILE                       82
-#define ITEM_RESERVED                        83
-#define ITEM_REXX                            84
-#define ITEM_REXXOUTPUT                      85
-#define ITEM_RING                            86
-#define ITEM_SCALE                           87
-#define ITEM_SCOPE                           88
-#define ITEM_SCREEN                          89
-#define ITEM_SELECT                          90
-#define ITEM_SHADOW                          91
-#define ITEM_SHOWKEY                         92
-#define ITEM_SIZE                            93
-#define ITEM_STATUSLINE                      94
-#define ITEM_STAY                            95
-#define ITEM_TABKEY                          96
-#define ITEM_TABLINE                         97
-#define ITEM_TABS                            98
-#define ITEM_TABSIN                          99
-#define ITEM_TABSOUT                        100
-#define ITEM_TERMINAL                       101
-#define ITEM_TIMECHECK                      102
-#define ITEM_TOF                            103
-#define ITEM_TOFEOF                         104
-#define ITEM_TYPEAHEAD                      105
-#define ITEM_UNDOING                        106
-#define ITEM_UNTAA                          107
-#define ITEM_VERIFY                         108
-#define ITEM_VERSHIFT                       109
-#define ITEM_VERSION                        110
-#define ITEM_WIDTH                          111
-#define ITEM_WORD                           112
-#define ITEM_WORDWRAP                       113
-#define ITEM_WRAP                           114
-#define ITEM_XTERMINAL                      115
-#define ITEM_ZONE                           116
+#define ITEM_EQUIVCHAR                       34
+#define ITEM_ETMODE                          35
+#define ITEM_FEXT                            36
+#define ITEM_FIELD                           37
+#define ITEM_FILENAME                        38
+#define ITEM_FILESTATUS                      39
+#define ITEM_FMODE                           40
+#define ITEM_FNAME                           41
+#define ITEM_FPATH                           42
+#define ITEM_FTYPE                           43
+#define ITEM_FULLFNAME                       44
+#define ITEM_GETENV                          45
+#define ITEM_HEX                             46
+#define ITEM_HEXDISPLAY                      47
+#define ITEM_HEXSHOW                         48
+#define ITEM_HIGHLIGHT                       49
+#define ITEM_IDLINE                          50
+#define ITEM_IMPMACRO                        51
+#define ITEM_IMPOS                           52
+#define ITEM_INPUTMODE                       53
+#define ITEM_INSERTMODE                      54
+#define ITEM_LASTKEY                         55
+#define ITEM_LASTMSG                         56
+#define ITEM_LASTRC                          57
+#define ITEM_LENGTH                          58
+#define ITEM_LINE                            59
+#define ITEM_LINEFLAG                        60
+#define ITEM_LINEND                          61
+#define ITEM_LSCREEN                         62
+#define ITEM_MACRO                           63
+#define ITEM_MACROEXT                        64
+#define ITEM_MACROPATH                       65
+#define ITEM_MARGINS                         66
+#define ITEM_MONITOR                         67
+#define ITEM_MOUSE                           68
+#define ITEM_MSGLINE                         69
+#define ITEM_MSGMODE                         70
+#define ITEM_NBFILE                          71
+#define ITEM_NBSCOPE                         72
+#define ITEM_NEWLINES                        73
+#define ITEM_NONDISP                         74
+#define ITEM_NUMBER                          75
+#define ITEM_PARSER                          76
+#define ITEM_PENDING                         77
+#define ITEM_POINT                           78
+#define ITEM_POSITION                        79
+#define ITEM_PREFIX                          80
+#define ITEM_PRINTER                         81
+#define ITEM_READONLY                        82
+#define ITEM_READV                           83
+#define ITEM_REPROFILE                       84
+#define ITEM_RESERVED                        85
+#define ITEM_REXX                            86
+#define ITEM_REXXOUTPUT                      87
+#define ITEM_RING                            88
+#define ITEM_SCALE                           89
+#define ITEM_SCOPE                           90
+#define ITEM_SCREEN                          91
+#define ITEM_SELECT                          92
+#define ITEM_SHADOW                          93
+#define ITEM_SHOWKEY                         94
+#define ITEM_SIZE                            95
+#define ITEM_STATUSLINE                      96
+#define ITEM_STAY                            97
+#define ITEM_SYNONYM                         98
+#define ITEM_TABKEY                          99
+#define ITEM_TABLINE                        100
+#define ITEM_TABS                           101
+#define ITEM_TABSIN                         102
+#define ITEM_TABSOUT                        103
+#define ITEM_TERMINAL                       104
+#define ITEM_TIMECHECK                      105
+#define ITEM_TOF                            106
+#define ITEM_TOFEOF                         107
+#define ITEM_TYPEAHEAD                      108
+#define ITEM_UNDOING                        109
+#define ITEM_UNTAA                          110
+#define ITEM_VERIFY                         111
+#define ITEM_VERSHIFT                       112
+#define ITEM_VERSION                        113
+#define ITEM_WIDTH                          114
+#define ITEM_WORD                           115
+#define ITEM_WORDWRAP                       116
+#define ITEM_WRAP                           117
+#define ITEM_XTERMINAL                      118
+#define ITEM_ZONE                           119
 
 /*---------------------------------------------------------------------*/
 /* The following are item number defines for the boolean functions.    */
