@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: rexx.c,v 1.3 1999/07/25 11:11:19 mark Exp mark $";
+static char RCSid[] = "$Id: rexx.c,v 1.2 2000/12/10 04:10:18 mark Exp $";
 
 #if defined(__EMX__) && defined(USE_REGINA)
 # define INCL_VIO
@@ -78,6 +78,7 @@ LINETYPE rexxout_number_lines=0L;
 #if defined(USE_REXX6000)
 LONG THE_Commands( RSH_ARG0_TYPE, RSH_ARG1_TYPE, RSH_ARG2_TYPE );
 LONG THE_Exit_Handler( REH_ARG0_TYPE, REH_ARG1_TYPE, REH_ARG2_TYPE );
+LONG ver_handler( REH_ARG0_TYPE, REH_ARG1_TYPE, REH_ARG2_TYPE );
 LONG rexx_interpreter_version_exit( REH_ARG0_TYPE, REH_ARG1_TYPE, REH_ARG2_TYPE );
 USHORT THE_Function_Handler( RFH_ARG0_TYPE, RFH_ARG1_TYPE, RFH_ARG2_TYPE, RFH_ARG3_TYPE, RFH_ARG4_TYPE );
 #else
@@ -117,10 +118,10 @@ static CHARTYPE version_buffer[MAX_FILE_NAME+1];
 unsigned long MyRexxDeregisterFunction
 #if defined(HAVE_PROTO)
    (
-   CHARTYPE *Name)       /* Name of function to be deregistered        */
+   CHARTYPE *Name)       /* Name of function to be deregistered  */
 #else
    (Name)
-   CHARTYPE *Name;       /* Name of function to be deregistered        */
+   CHARTYPE *Name;       /* Name of function to be deregistered  */
 #endif
 /***********************************************************************/
 {
@@ -143,10 +144,10 @@ unsigned long MyRexxDeregisterFunction
 unsigned long MyRexxRegisterFunctionExe
 #if defined(HAVE_PROTO)
    (
-   CHARTYPE *Name)         /* Name of function to be registered        */
+   CHARTYPE *Name)         /* Name of function to be registered  */
 #else
    (Name)
-   CHARTYPE *Name;         /* Name of function to be registered        */
+   CHARTYPE *Name;         /* Name of function to be registered  */
 #endif
 /***********************************************************************/
 {
@@ -248,6 +249,29 @@ RSH_RETURN_TYPE THE_Commands
  Retstr->strlength = strlen((DEFCHAR *)Retstr->strptr);
  return 0L;                              /* processing completed       */
 }
+#ifdef USE_REXX6000
+/***********************************************************************/
+/* This is a nop function for REXX6000 for getting the version */
+/***********************************************************************/
+REH_RETURN_TYPE ver_exit
+#if defined(HAVE_PROTO)
+   (
+   REH_ARG0_TYPE ExitNumber,    /* code defining the exit function    */
+   REH_ARG1_TYPE Subfunction,   /* code defining the exit subfunction */
+   REH_ARG2_TYPE ParmBlock      /* function dependent control block   */
+   )
+#else
+   ( ExitNumber, Subfunction, ParmBlock )
+   REH_ARG0_TYPE ExitNumber;    /* code defining the exit function    */
+   REH_ARG1_TYPE Subfunction;   /* code defining the exit subfunction */
+   REH_ARG2_TYPE ParmBlock;     /* function dependent control block   */
+#endif
+/***********************************************************************/
+{
+ return(0L);
+}
+#endif
+
 /***********************************************************************/
 REH_RETURN_TYPE THE_Exit_Handler
 #if defined(HAVE_PROTO)
@@ -274,10 +298,15 @@ REH_RETURN_TYPE THE_Exit_Handler
  char rexxout_temp[60];
  VIEW_DETAILS *found_view=NULL;
  static bool first=TRUE;
+
+  USHORT         usExists = 0;         /* Existence flag                   */
+  PSZ            pszTraceName[2];      /* Ptr to trace output file name    */
+
 /*--------------------------- processing ------------------------------*/
  if (Subfunction != RXSIOSAY   /* ignore all but RXSIOSAY and RXSIOTRC */
  &&  Subfunction != RXSIOTRC)
     return(RXEXIT_NOT_HANDLED);
+ rc = RexxQueryExit("THE_EXIT",NULL, &usExists, (PUCHAR)pszTraceName);
 /*---------------------------------------------------------------------*/
 /* If this is the first time this exit handler is called, set up the   */
 /* handling of the result; either open the capture file, or set the    */
@@ -370,7 +399,7 @@ REH_RETURN_TYPE THE_Exit_Handler
        rc = RXEXIT_HANDLED;
    }
  else
-    rc = RXEXIT_NOT_HANDLED;
+   rc = RXEXIT_NOT_HANDLED;
 /*---------------------------------------------------------------------*/
 /* If the number of lines processed exceeds the line limit, display our*/
 /* own message telling what has happened and exit with                 */
@@ -428,6 +457,7 @@ RFH_RETURN_TYPE THE_Function_Handler
 /*---------------------------------------------------------------------*/
 /* Find the external function name in the array. Error if not found.   */
 /*---------------------------------------------------------------------*/
+ set_compare_exact( TRUE );
  if (itemno == (-1))
  {
     rc = search_query_item_array(function_item,
@@ -532,16 +562,12 @@ short initialise_rexx
  int num_values=0;
  char buf[50];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    initialise_rexx");
-#endif
+ TRACE_FUNCTION("rexx.c:    initialise_rexx");
 
 #if defined(MSWIN)
  if (RexxThread(GetCurrentTask(),THREAD_ATTACH) != THREAD_ATTACH_AOK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_ENVIRON);
    }
 #endif
@@ -557,9 +583,7 @@ short initialise_rexx
 #endif
  if (rc != RXSUBCOM_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return((short)rc);
    }
 
@@ -569,9 +593,7 @@ short initialise_rexx
                           (RREE_ARG2_TYPE)NULL);
  if (rc != RXEXIT_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return((short)rc);
    }
 #endif
@@ -584,9 +606,7 @@ short initialise_rexx
  }
  if (rc != RXFUNC_OK)
  {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return((short)rc);
  }
 
@@ -603,9 +623,7 @@ short initialise_rexx
     if (rc != RXFUNC_OK)
        break;
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((short)rc);
 }
 /***********************************************************************/
@@ -623,9 +641,7 @@ short finalise_rexx
  int num_values=0;
  char buf[50];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    finalise_rexx");
-#endif
+ TRACE_FUNCTION("rexx.c:    finalise_rexx");
 
 #if defined(USE_REXX6000)
  rc = RexxDeregisterSubcom((RDS_ARG0_TYPE)"THE");
@@ -638,7 +654,7 @@ short finalise_rexx
 
  for (i=0; i<number_function_item(); i++)
  {
-    rc = RexxDeregisterFunction((RDF_ARG0_TYPE)function_item[i].name);
+    rc = MyRexxDeregisterFunction(function_item[i].name);
  }
 
  for (i=0; i<number_query_item(); i++)
@@ -647,7 +663,7 @@ short finalise_rexx
     for (j=0;j<num_values;j++)
     {
        sprintf(buf,"%s.%d",query_item[i].name,j);
-       rc = RexxDeregisterFunction((RDF_ARG0_TYPE)buf);
+       rc = MyRexxDeregisterFunction(buf);
     }
  }
 
@@ -655,9 +671,7 @@ short finalise_rexx
  (void)RexxThread(GetCurrentTask(),THREAD_DETACH);
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((short)rc);
 }
 /***********************************************************************/
@@ -693,9 +707,7 @@ short execute_macro_file
  CHARTYPE *rexx_args=NULL;
  RXSYSEXIT exit_list[2];                /* system exit list           */
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    execute_macro_file");
-#endif
+ TRACE_FUNCTION("rexx.c:    execute_macro_file");
 /*---------------------------------------------------------------------*/
 /* Determine how many parameters are to be passed to the interpreter.  */
 /* Only 0 or 1 are valid values.                                       */
@@ -713,9 +725,7 @@ short execute_macro_file
     if ((rexx_args = (CHARTYPE *)(*the_malloc)(strlen((DEFCHAR *)params)+1)) == (CHARTYPE *)NULL)
       {
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY);
       }
     strcpy((DEFCHAR *)rexx_macro_parameters,(DEFCHAR *)params);
@@ -823,10 +833,8 @@ short execute_macro_file
 
  if (rexx_args != NULL)
     (*the_free)(rexx_args);
-#ifdef THE_TRACE
- trace_return();
-#endif
  *macrorc = (short)rexxrc;
+ TRACE_RETURN();
  return((short)rc);
 }
 /***********************************************************************/
@@ -861,9 +869,7 @@ short execute_macro_instore
  RXSYSEXIT exit_list[2];                /* system exit list           */
  bool save_in_macro=in_macro;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    execute_macro_instore");
-#endif
+ TRACE_FUNCTION("rexx.c:    execute_macro_instore");
  in_macro = TRUE;
  sprintf((DEFCHAR *)macro_name,"INSTORE%d",macro_ident);
 /*---------------------------------------------------------------------*/
@@ -982,10 +988,8 @@ short execute_macro_instore
     reset_prog_mode();
 #endif
  in_macro = save_in_macro;
-#ifdef THE_TRACE
- trace_return();
-#endif
  *macrorc = (short)rexxrc;
+ TRACE_RETURN();
  return((short)rc);
 }
 
@@ -1041,11 +1045,15 @@ CHARTYPE *get_rexx_interpreter_version
  if (rexx_support)
  {
     strcpy((DEFCHAR *)version_buffer,"Unable to obtain Rexx version from interpreter");
+#if defined(USE_REXX6000)
+    Exits[0].sysexit_func = ver_exit;
+#else
     RexxRegisterExitExe((RREE_ARG0_TYPE)"ver_exit",
                         (RREE_ARG1_TYPE)rexx_interpreter_version_exit,
                         (RREE_ARG2_TYPE)NULL);
 
     Exits[0].sysexit_name = "ver_exit" ;
+#endif
     Exits[0].sysexit_code = RXTER ;
     Exits[1].sysexit_code = RXENDLST ;
 
@@ -1064,7 +1072,9 @@ CHARTYPE *get_rexx_interpreter_version
                 (RS_ARG7_TYPE)&rexxrc,
                 (RS_ARG8_TYPE)NULL);
 
+#if defined(USE_REXX6000)
     RexxDeregisterExit( "ver_exit", NULL ) ;
+#endif
     if (rc == 0)
        strcpy((DEFCHAR *)buf,(DEFCHAR *)version_buffer);
  }
@@ -1091,18 +1101,14 @@ short get_rexx_variable
  RXSTRING retstr;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    get_rexx_variable");
-#endif
+ TRACE_FUNCTION("rexx.c:    get_rexx_variable");
  MAKERXSTRING(retstr,"",0);
  (void)get_compound_rexx_variable(name,&retstr,(-1));
  if (retstr.strptr == NULL)
     rc = RC_INVALID_ENVIRON;
  *value = (CHARTYPE*)retstr.strptr;
  *value_length = retstr.strlength;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 
@@ -1124,9 +1130,7 @@ short set_rexx_variable
  CHAR variable_name[250];
  short rc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    set_rexx_variable");
-#endif
+ TRACE_FUNCTION("rexx.c:    set_rexx_variable");
 
  shv.shvnext=NULL;                                   /* only one block */
 #if defined(USE_REGINA)
@@ -1169,9 +1173,7 @@ short set_rexx_variable
    }
  else
     rc = RC_OK;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1191,9 +1193,7 @@ static RXSTRING *get_compound_rexx_variable
  CHAR variable_name[250];
  short rc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    get_compound_rexx_variable");
-#endif
+ TRACE_FUNCTION("rexx.c:    get_compound_rexx_variable");
  shv.shvnext=NULL;                                   /* only one block */
 #if defined(USE_REGINA)
  shv.shvcode=RXSHV_SYFET; /* for Regina (no direct set) use symbolic set */
@@ -1270,9 +1270,7 @@ static RXSTRING *get_compound_rexx_variable
          value->strlength = 0;
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(value);
 }
 /***********************************************************************/
@@ -1292,9 +1290,7 @@ static short valid_target_function
  LINETYPE true_line=0L;
  short rc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    valid_target_function");
-#endif
+ TRACE_FUNCTION("rexx.c:    valid_target_function");
  switch(1)
    {
     case 1:
@@ -1363,9 +1359,7 @@ static short valid_target_function
    }
  item_values[0].value = (CHARTYPE *)"1";
  item_values[0].len = 1;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1384,9 +1378,7 @@ static short run_os_function
  static CHARTYPE num0[5];                  /* large enough for 1000+rc */
  CHARTYPE *cmd=NULL,*instem=NULL,*outstem=NULL,*errstem=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    run_os_function");
-#endif
+ TRACE_FUNCTION("rexx.c:    run_os_function");
  switch(Argc)
    {
     case 0:
@@ -1431,9 +1423,7 @@ static short run_os_function
  if (instem) (*the_free)(instem);
  if (outstem) (*the_free)(outstem);
  if (errstem) (*the_free)(errstem);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -1462,9 +1452,7 @@ static int run_os_command
  int save_stdin=0,save_stdout=0,save_stderr=0;
  int infd=0,outfd=0,errfd=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    run_os_command");
-#endif
+ TRACE_FUNCTION("rexx.c:    run_os_command");
 /*---------------------------------------------------------------------*/
 /* Determine if we are redirecting stdin, stdout or both and if the    */
 /* values passed as stem variables end in '.'.                         */
@@ -1479,9 +1467,7 @@ static int run_os_command
        *(instem+inlen-1) = '\0';
     else
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
    }
@@ -1495,9 +1481,7 @@ static int run_os_command
        *(outstem+outlen-1) = '\0';
     else
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
    }
@@ -1511,9 +1495,7 @@ static int run_os_command
        *(errstem+errlen-1) = '\0';
     else
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
    }
@@ -1525,17 +1507,13 @@ static int run_os_command
     if (out
     &&  strcmp((DEFCHAR *)instem,(DEFCHAR *)outstem) == 0)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
     if (err
     &&  strcmp((DEFCHAR *)instem,(DEFCHAR *)errstem) == 0)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
    }
@@ -1558,16 +1536,12 @@ static int run_os_command
     (void)get_compound_rexx_variable(instem,&tmpstr,0);
     if (tmpstr.strptr == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_SYSTEM_ERROR+1000);
       }
     if (!valid_positive_integer((CHARTYPE *)tmpstr.strptr))
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND+1000);
       }
     innum = atol((DEFCHAR *)tmpstr.strptr);
@@ -1578,16 +1552,12 @@ static int run_os_command
     infile = (char *)(*the_malloc)(L_tmpnam);
     if (infile == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY+1000);
       }
     if ((infile = tmpnam(infile)) == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
 #if defined(GO32) || defined(__EMX__)
@@ -1599,9 +1569,7 @@ static int run_os_command
 #endif
     if ((infp = fopen(infile,"w")) == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
     for (i=0;i<innum;i++)
@@ -1610,9 +1578,7 @@ static int run_os_command
        (void)get_compound_rexx_variable(instem,&tmpstr,i+1);
        if (tmpstr.strptr == NULL)
          {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_SYSTEM_ERROR+1000);
          }
        fputs((DEFCHAR *)tmpstr.strptr,infp);
@@ -1621,9 +1587,7 @@ static int run_os_command
       }
     if (fclose(infp))
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
    }
@@ -1636,16 +1600,12 @@ static int run_os_command
     outfile = (char *)(*the_malloc)(L_tmpnam);
     if (outfile == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY+1000);
       }
     if ((outfile = tmpnam(outfile)) == NULL)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
    }
@@ -1664,16 +1624,12 @@ static int run_os_command
        errfile = (char *)(*the_malloc)(L_tmpnam);
        if (errfile == NULL)
          {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY+1000);
          }
        if ((errfile = tmpnam(errfile)) == NULL)
          {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_ACCESS_DENIED+1000);
          }
       }
@@ -1689,9 +1645,7 @@ static int run_os_command
    {
     if ((infd = open(infile,O_RDONLY)) == (-1))
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
    }
@@ -1703,9 +1657,7 @@ static int run_os_command
     if ((outfd = open(outfile,O_RDWR|O_CREAT|O_TRUNC,S_IWRITE|S_IREAD)) == (-1))
 #endif
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_ACCESS_DENIED+1000);
       }
    }
@@ -1721,9 +1673,7 @@ static int run_os_command
        if ((errfd = open(errfile,O_RDWR|O_CREAT|O_TRUNC,S_IWRITE|S_IREAD)) == (-1))
 #endif
          {
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_ACCESS_DENIED+1000);
          }
       }
@@ -1793,9 +1743,7 @@ static int run_os_command
 /*---------------------------------------------------------------------*/
 /* Return with, hopefully, return code from system() command.          */
 /*---------------------------------------------------------------------*/
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  if (rc)
     return(rc+1000);
  else
@@ -1814,9 +1762,7 @@ static CHARTYPE *MakeAscii
 /*--------------------------- local data ------------------------------*/
  CHARTYPE *string=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    MakeAscii");
-#endif
+ TRACE_FUNCTION("rexx.c:    MakeAscii");
 
  string = (CHARTYPE *)(*the_malloc)((sizeof(CHARTYPE)*rxstring->strlength)+1);
  if (string != NULL)
@@ -1824,9 +1770,7 @@ static CHARTYPE *MakeAscii
     memcpy(string,rxstring->strptr,rxstring->strlength);
     *(string+(rxstring->strlength)) = '\0';
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(string);
 }
 /***********************************************************************/
@@ -1919,14 +1863,10 @@ static short set_rexx_variables_from_file
  int length=0,rcode=0,rc=0;
  char tmpnum[10];
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("rexx.c:    set_rexx_variables_from_file");
-#endif
+ TRACE_FUNCTION("rexx.c:    set_rexx_variables_from_file");
  if ((fp = fopen(filename,"r")) == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_ACCESS_DENIED);
    }
  for (i=0;;i++)
@@ -1934,9 +1874,7 @@ static short set_rexx_variables_from_file
     string = get_a_line(fp,string,&length,&rcode);
     if (rcode == RC_OUT_OF_MEMORY)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(rcode);
       }
     if (rcode == RC_TOF_EOF_REACHED
@@ -1954,9 +1892,7 @@ static short set_rexx_variables_from_file
  rc = set_rexx_variable(stem,(CHARTYPE *)tmpnum,strlen(tmpnum),0);
  if (fclose(fp))
     rc = RC_ACCESS_DENIED;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 #else
