@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: target.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: target.c,v 1.2 2000/12/10 04:13:01 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -85,9 +85,7 @@ LINETYPE *num,*occ;
  short target_type = TARGET_NORMAL|TARGET_BLOCK_CURRENT|TARGET_ALL|TARGET_SPARE;
  unsigned short num_params=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  split_change_params");
-#endif
+ TRACE_FUNCTION("target.c:  split_change_params");
 /*---------------------------------------------------------------------*/
 /* First, determine the delimiter; the first character in the argument */
 /* string.                                                             */
@@ -133,9 +131,7 @@ LINETYPE *num,*occ;
 /*---------------------------------------------------------------------*/
  if (blank_field(target_start))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -143,9 +139,7 @@ LINETYPE *num,*occ;
 /*---------------------------------------------------------------------*/
  if ((rc = validate_target(target_start,target,target_type,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
 /*---------------------------------------------------------------------*/
@@ -153,9 +147,7 @@ LINETYPE *num,*occ;
 /*---------------------------------------------------------------------*/
  if (target->spare == (-1))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -174,9 +166,7 @@ LINETYPE *num,*occ;
        if (!valid_positive_integer(word[0]))
          {
           display_error(4,word[0],FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_INVALID_OPERAND);
          }
        else
@@ -187,18 +177,14 @@ LINETYPE *num,*occ;
     if (!valid_positive_integer(word[1]))
       {
        display_error(4,word[1],FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     else
        *occ = atol((DEFCHAR *)word[1]);
    }
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -232,9 +218,7 @@ bool display_parse_error,allow_error_display,column_target;
  CHARTYPE *ptr=NULL;
  LINETYPE lineno=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  parse_target");
-#endif
+ TRACE_FUNCTION("target.c:  parse_target");
 /*---------------------------------------------------------------------*/
 /* Copy the incoming target specification...                           */
 /*---------------------------------------------------------------------*/
@@ -242,9 +226,7 @@ bool display_parse_error,allow_error_display,column_target;
    {
     if (allow_error_display)
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OUT_OF_MEMORY);
    }
  ptr = target->string;
@@ -270,9 +252,7 @@ bool display_parse_error,allow_error_display,column_target;
            {
             if (allow_error_display)
                display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-            trace_return();
-#endif
+            TRACE_RETURN();
             return(RC_OUT_OF_MEMORY);
            }
          target->num_targets = 1;
@@ -287,15 +267,11 @@ bool display_parse_error,allow_error_display,column_target;
            {
             if (allow_error_display)
                display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-            trace_return();
-#endif
+            TRACE_RETURN();
             return(RC_OUT_OF_MEMORY);
            }
          strcpy((DEFCHAR *)target->rt[0].string,(DEFCHAR *)ptr);
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(RC_OK);
          break;
     default:
@@ -315,9 +291,7 @@ bool display_parse_error,allow_error_display,column_target;
               {
                if (allow_error_display)
                   display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-               trace_return();
-#endif
+               TRACE_RETURN();
                return(RC_OUT_OF_MEMORY);
               }
             target->rt[num_targets].not = FALSE;
@@ -386,9 +360,7 @@ bool display_parse_error,allow_error_display,column_target;
                       {
                        if (allow_error_display)
                           display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                       trace_return();
-#endif
+                       TRACE_RETURN();
                        return(RC_OUT_OF_MEMORY);
                       }
                     if (target->rt[num_targets].negative)
@@ -529,9 +501,7 @@ bool display_parse_error,allow_error_display,column_target;
                          {
                           if (allow_error_display)
                              display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                          trace_return();
-#endif
+                          TRACE_RETURN();
                           return(RC_OUT_OF_MEMORY);
                          }
                        memcpy(target->rt[num_targets].string,ptr+str_start,len);
@@ -584,9 +554,7 @@ bool display_parse_error,allow_error_display,column_target;
                       {
                        if (allow_error_display)
                           display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                       trace_return();
-#endif
+                       TRACE_RETURN();
                        return(RC_OUT_OF_MEMORY);
                       }
                     memcpy(target->rt[num_targets].string,ptr+str_start,len);
@@ -621,9 +589,7 @@ bool display_parse_error,allow_error_display,column_target;
                       {
                        if (allow_error_display)
                           display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                       trace_return();
-#endif
+                       TRACE_RETURN();
                        return(RC_OUT_OF_MEMORY);
                       }
                     if (delim != '\0')
@@ -740,9 +706,7 @@ bool display_parse_error,allow_error_display,column_target;
                       {
                        if (allow_error_display)
                           display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-                       trace_return();
-#endif
+                       TRACE_RETURN();
                        return(RC_OUT_OF_MEMORY);
                       }
                     memcpy(target->rt[num_targets].string,ptr+str_start,len);
@@ -752,9 +716,7 @@ bool display_parse_error,allow_error_display,column_target;
                       {
                        if (allow_error_display)
                           display_error(17,(CHARTYPE *)target->rt[num_targets].string,FALSE);
-#ifdef THE_TRACE
-                       trace_return();
-#endif
+                       TRACE_RETURN();
                        return(RC_TARGET_NOT_FOUND);
                       }
                     target->rt[num_targets].numeric_target = lineno;
@@ -792,9 +754,7 @@ bool display_parse_error,allow_error_display,column_target;
     if (display_parse_error
     && allow_error_display)
        display_error(1,ptr,FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_INVALID_OPERAND);
    }
 /*---------------------------------------------------------------------*/
@@ -887,9 +847,7 @@ bool display_parse_error,allow_error_display,column_target;
  && display_parse_error
  && allow_error_display)
     display_error(1,ptr,FALSE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -903,18 +861,14 @@ TARGET *target;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  initialise_target");
-#endif
+ TRACE_FUNCTION("target.c:  initialise_target");
  target->rt=NULL;
  target->string=NULL;
  target->num_lines = target->true_line = target->last_line = 0L;
  target->num_targets = 0;
  target->spare = (-1);
  target->ignore_scope = FALSE;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -929,16 +883,12 @@ TARGET *target;
 /*--------------------------- local data ------------------------------*/
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  free_target");
-#endif
+ TRACE_FUNCTION("target.c:  free_target");
  if (target->string == NULL
  &&  target->num_targets == 0
  &&  target->rt == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
  for (i=0;i<target->num_targets;i++)
@@ -950,9 +900,7 @@ TARGET *target;
     (*the_free)(target->string);
  if (target->rt != NULL)
     (*the_free)(target->rt);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -973,9 +921,7 @@ bool display_parse_error,allow_error_display;
  LINETYPE line_number=0L;
  short status=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_target");
-#endif
+ TRACE_FUNCTION("target.c:  find_target");
 /*---------------------------------------------------------------------*/
 /* Check single targets first (ALL and BLOCK)                          */
 /*---------------------------------------------------------------------*/
@@ -988,9 +934,7 @@ bool display_parse_error,allow_error_display;
          target->true_line = 1L;
          target->last_line = CURRENT_FILE->number_lines;
          target->num_lines = CURRENT_FILE->number_lines;
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(RC_OK);
          break;
     case TARGET_BLOCK_ANY:
@@ -1006,9 +950,7 @@ bool display_parse_error,allow_error_display;
             target->true_line = MARK_VIEW->mark_start_line;
             target->last_line = MARK_VIEW->mark_end_line;
            }
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(rc);
          break;
     case TARGET_BLOCK_CURRENT:
@@ -1033,9 +975,7 @@ bool display_parse_error,allow_error_display;
                target->last_line = MARK_VIEW->mark_end_line;
               }
            }
-#ifdef THE_TRACE
-         trace_return();
-#endif
+         TRACE_RETURN();
          return(rc);
          break;
     default:
@@ -1096,9 +1036,7 @@ bool display_parse_error,allow_error_display;
    }
  else
     rc = status;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1120,9 +1058,7 @@ bool display_parse_error,allow_error_display;
  LINETYPE num_columns=0L;
  bool status=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_column_target");
-#endif
+ TRACE_FUNCTION("target.c:  find_column_target");
 /*---------------------------------------------------------------------*/
 /* All column targets are potentially repeating targets...             */
 /*---------------------------------------------------------------------*/
@@ -1171,9 +1107,7 @@ bool display_parse_error,allow_error_display;
        display_error(17,target->string,FALSE);
     rc = RC_TARGET_NOT_FOUND;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1189,14 +1123,10 @@ LINE *curr;
  register short i=0;
  bool rc=TRUE;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  is_blank");
-#endif
+ TRACE_FUNCTION("target.c:  is_blank");
  if (CURRENT_VIEW->zone_start > curr->length)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(TRUE);
    }
  for (i=CURRENT_VIEW->zone_start-1;i<min(CURRENT_VIEW->zone_end,curr->length);i++)
@@ -1207,9 +1137,7 @@ LINE *curr;
        break;
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1227,9 +1155,7 @@ bool respect_scope;
  LINETYPE lineno=0;
  LINE *curr=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_named_line");
-#endif
+ TRACE_FUNCTION("target.c:  find_named_line");
 /*---------------------------------------------------------------------*/
 /* Find the line number in the current file of the named line specified*/
 /*---------------------------------------------------------------------*/
@@ -1246,19 +1172,16 @@ bool respect_scope;
        if (curr->name != (CHARTYPE *)NULL)
           if (strcmp((DEFCHAR *)curr->name,(DEFCHAR *)name) == 0)
             {
-#ifdef THE_TRACE
-             trace_return();
-#endif
+             TRACE_RETURN();
              *retline = lineno;
+             TRACE_RETURN();
              return(curr);
             }
       }
     lineno++;
     curr = curr->next;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((LINE *)NULL);
 }
 /***********************************************************************/
@@ -1280,9 +1203,7 @@ RTARGET *rt;
  short rc=RC_OK;
  short loc=(-1);
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_string_target");
-#endif
+ TRACE_FUNCTION("target.c:  find_string_target");
 /*---------------------------------------------------------------------*/
 /* Copy the supplied string target rather than point to it, as we don't*/
 /* want to change the value of the target if it is a HEX string.       */
@@ -1297,9 +1218,7 @@ RTARGET *rt;
     if (rc == (-1))
       {
        display_error(32,needle,FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_INVALID_OPERAND);
       }
     else
@@ -1362,9 +1281,7 @@ RTARGET *rt;
     pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1385,9 +1302,7 @@ LINETYPE *num_lines;
  LINETYPE multiplier=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_rtarget_target");
-#endif
+ TRACE_FUNCTION("target.c:  find_rtarget_target");
 /*---------------------------------------------------------------------*/
 /* If the line is not in scope and scope is respected, return FALSE.   */
 /*---------------------------------------------------------------------*/
@@ -1398,9 +1313,7 @@ LINETYPE *num_lines;
     && !TOF(line_number)
     && !BOF(line_number))
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_TARGET_NOT_FOUND);
       }
    }
@@ -1468,9 +1381,7 @@ LINETYPE *num_lines;
                case RC_TARGET_NOT_FOUND:
                     break;
                default:
-#ifdef THE_TRACE
-                    trace_return();
-#endif
+                    TRACE_RETURN();
                     return(rc);
                     break;
               }
@@ -1517,9 +1428,7 @@ LINETYPE *num_lines;
             break;
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((status)?RC_OK:RC_TARGET_NOT_FOUND);
 }
 /***********************************************************************/
@@ -1540,9 +1449,7 @@ LINETYPE *num_columns;
  bool target_found=FALSE,status=FALSE;
  LINETYPE multiplier=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_rtarget_column_target");
-#endif
+ TRACE_FUNCTION("target.c:  find_rtarget_column_target");
  if (column_number != true_column)
     *num_columns = *num_columns + 1L;
  for (i=0;i<target->num_targets-((target->spare == (-1)) ? 0 : 1);i++)
@@ -1621,9 +1528,7 @@ LINETYPE *num_columns;
             break;
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(status);
 }
 /***********************************************************************/
@@ -1641,9 +1546,7 @@ short direction;
 /*--------------------------- local data ------------------------------*/
  LINE *curr=in_curr;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_next_in_scope");
-#endif
+ TRACE_FUNCTION("target.c:  find_next_in_scope");
  if (in_curr == NULL)
      curr = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,line_number,CURRENT_FILE->number_lines);
  for (;;line_number+=(LINETYPE)direction)
@@ -1657,9 +1560,7 @@ short direction;
     if (curr == NULL)
        break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(line_number);
 }
 /***********************************************************************/
@@ -1678,9 +1579,7 @@ short direction;
  LINE *curr=in_curr;
  LINETYPE offset=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_last_not_in_scope");
-#endif
+ TRACE_FUNCTION("target.c:  find_last_not_in_scope");
  if (in_curr == NULL)
      curr = lll_find(CURRENT_FILE->first_line,CURRENT_FILE->last_line,line_number,CURRENT_FILE->number_lines);
  for (;;line_number+=(LINETYPE)direction)
@@ -1700,9 +1599,7 @@ short direction;
     if (curr == NULL)
        break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(line_number+offset);
 }
 /***********************************************************************/
@@ -1721,28 +1618,20 @@ bool display_parse_error,allow_error_display;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  validate_target");
-#endif
+ TRACE_FUNCTION("target.c:  validate_target");
  rc = parse_target(string,true_line,target,target_type,display_parse_error,allow_error_display,FALSE);
  if (rc != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(rc);
    }
  rc = find_target(target,true_line,display_parse_error,allow_error_display);
  if (rc != RC_OK)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_TARGET_NOT_FOUND);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 #ifdef NOT_USED_ANYMORE
@@ -1759,17 +1648,13 @@ LINE *curr;
 /*--------------------------- local data ------------------------------*/
  bool rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  in_scope");
-#endif
+ TRACE_FUNCTION("target.c:  in_scope");
  if (curr->select < view->display_low
  ||  curr->select > view->display_high)
     rc = FALSE;
  else
     rc = TRUE;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 #endif
@@ -1793,9 +1678,7 @@ short direction;
  register short i=0;
  unsigned short y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  calculate_scroll_values");
-#endif
+ TRACE_FUNCTION("target.c:  calculate_scroll_values");
  *limit_of_screen = *limit_of_file = FALSE;
  *number_focus_rows = 0;
  *new_focus_line = (-1L);
@@ -1975,9 +1858,7 @@ short direction;
             *limit_of_file = TRUE;
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1994,9 +1875,7 @@ unsigned short *newrow;
  short row=(-1);
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_last_focus_line");
-#endif
+ TRACE_FUNCTION("target.c:  find_last_focus_line");
  for (i=CURRENT_SCREEN.rows[WINDOW_FILEAREA]-1;i>-1;i--)
    {
     if (CURRENT_SCREEN.sl[i].line_number != (-1L))
@@ -2007,9 +1886,7 @@ unsigned short *newrow;
    }
  if (row == (-1))
     rc = RC_INVALID_OPERAND;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -2026,9 +1903,7 @@ unsigned short *newrow;
  short row=(-1);
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_first_focus_line");
-#endif
+ TRACE_FUNCTION("target.c:  find_first_focus_line");
  for (i=0;i<CURRENT_SCREEN.rows[WINDOW_FILEAREA];i++)
    {
     if (CURRENT_SCREEN.sl[i].line_number != (-1L))
@@ -2039,9 +1914,7 @@ unsigned short *newrow;
    }
  if (row == (-1))
     rc = RC_INVALID_OPERAND;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -2056,21 +1929,15 @@ CHARTYPE *str;
 /*--------------------------- local data ------------------------------*/
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("target.c:  find_unique_char");
-#endif
+ TRACE_FUNCTION("target.c:  find_unique_char");
  for (i=254;i>0;i--)
    {
     if (strzeq(str,(CHARTYPE)i) == (-1))
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return((CHARTYPE)i);
       }
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(0);
 }
