@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: the.c,v 1.3 1999/07/31 07:38:26 mark Exp mark $";
+static char RCSid[] = "$Id: the.c,v 1.3 2000/12/10 04:35:47 mark Exp $";
 
 #define MAIN 1
 #include <the.h>
@@ -71,7 +71,7 @@ static void init_signals();
    VIEW_DETAILS *vd_last=(VIEW_DETAILS *)NULL;
    VIEW_DETAILS *vd_mark=(VIEW_DETAILS *)NULL;
    CHARTYPE number_of_views = 0;                      /* number of views */
-   CHARTYPE number_of_files = 0;                      /* number of files */
+   LINETYPE number_of_files = 0;                      /* number of files */
    CHARTYPE display_screens = 1;                    /* number of screens */
    CHARTYPE current_screen = 0;
    SCREEN_DETAILS screen[MAX_SCREENS];            /* 2 screen structures */
@@ -120,8 +120,8 @@ static void init_signals();
    bool readonly=FALSE;     /* indicates if running THE in readonly mode */
    bool be_quiet=FALSE;   /* do not display error message header if TRUE */
   
-   CHARTYPE *the_version = (CHARTYPE *)"3.0";
-   CHARTYPE *the_release = (CHARTYPE *)"16-January-2000";
+   CHARTYPE *the_version = (CHARTYPE *)"3.1b";
+   CHARTYPE *the_release = (CHARTYPE *)"10-December-2000";
    CHARTYPE *the_copyright = (CHARTYPE *)"Copyright 1991-2000 Mark Hessling";
    CHARTYPE term_name[20];  /* $TERM value */
    CHARTYPE *tempfilename = (CHARTYPE *)NULL;
@@ -276,6 +276,7 @@ char *argv[];
    short rc=RC_OK;
    char *envptr=NULL;
    int slk_format=0;
+   int blink_tenths=0;
 #if defined(XCURSES) & PDC_BUILD >= 2401
    int initscr_argc=0;
    char **initscr_argv=NULL;
@@ -284,11 +285,8 @@ char *argv[];
 #ifdef __EMX__
    _wildcard(&argc,&argv);
 #endif
-
-#ifdef THE_TRACE
-   trace_initialise();
-   trace_function("the.c:     main");
-#endif
+   TRACE_INITIALISE();
+   TRACE_FUNCTION("the.c:     main");
   /*---------------------------------------------------------------------*/
   /* Ensure that CURRENT_VIEW is NULL before starting. This is to ensure */
   /* that any errors generated before CURRENT_VIEW is assigned are       */
@@ -372,6 +370,11 @@ char *argv[];
    strcpy((DEFCHAR *)term_name,"X11");
 #elif defined(WIN32)
    strcpy((DEFCHAR *)term_name,"WIN32");
+#elif defined(AMIGA)
+   if ((envptr = getenv("TERM")) != NULL)
+      strcpy((DEFCHAR *)term_name,envptr);
+   else
+      strcpy((DEFCHAR *)term_name,"default");
 #endif
    strcpy((DEFCHAR *)xterm_program,XTERM_PROGRAM);
   /*---------------------------------------------------------------------*/
@@ -420,7 +423,7 @@ char *argv[];
   /* Process the command line arguments.                                 */
   /*---------------------------------------------------------------------*/
 #if defined(XCURSES) & PDC_BUILD >= 2401
-   while ((c = my_getopt(argc,argv,"qk::sSbmnrl:c:p:w:a:u:X:h?")) != EOF)
+   while ((c = my_getopt(argc,argv,"qk::B::sSbmnrl:c:p:w:a:u:X:h?")) != EOF)
 #else
    while ((c = my_getopt(argc,argv,"qk::sSbmnrl:c:p:w:a:u:h?")) != EOF)
 #endif
@@ -474,6 +477,12 @@ char *argv[];
                   break;
             }
             break;
+         case 'B':        /* cursor blink rate */
+            if ( optarg == NULL )
+               blink_tenths = 5;
+            else
+               blink_tenths = atoi( optarg );
+            break;
          case 'S':        /* allow scrollbar */
             SBx = TRUE;
             break;
@@ -707,7 +716,7 @@ char *argv[];
 #ifdef UNIX
    strcpy((DEFCHAR *)dir_pathname,(DEFCHAR *)user_home_dir);
 #endif
-#if defined(DOS) || defined(OS2) || defined(WIN32)
+#if defined(DOS) || defined(OS2) || defined(WIN32) || defined(AMIGA)
    strcpy((DEFCHAR *)dir_pathname,(DEFCHAR *)ISTR_SLASH);
 #endif
 #ifdef VMS
@@ -821,7 +830,7 @@ char *argv[];
       /*---------------------------------------------------------------------*/
       if (number_of_files != 0)
       {
-         sprintf((DEFCHAR *)rec,"%d",number_of_files);
+         sprintf((DEFCHAR *)rec,"%ld",number_of_files);
          display_error(77,rec,FALSE);
       }
       cleanup();
@@ -916,6 +925,14 @@ char *argv[];
    keypad(stdscr,TRUE);
    notimeout(stdscr,TRUE);
    (void)THETypeahead((CHARTYPE *)"OFF");
+#if defined(XCURSES) && PDC_BUILD >= 2501
+   /*
+    * Force getch() to fail every .5 second to let us send a display_cursor
+    * message to the XCurses process to blink the cursor.
+    */
+   if ( blink_tenths != 0 )
+      halfdelay(blink_tenths);
+#endif
    /*---------------------------------------------------------------------*/
    /* Set up mouse support if enabled in curses library.                  */
    /*---------------------------------------------------------------------*/
@@ -959,7 +976,7 @@ char *argv[];
    (void)Etmode((CHARTYPE *)"ON");
 #elif defined(XCURSES)
    (void)Etmode((CHARTYPE *)"ON 32-255");
-#elif defined(UNIX)
+#elif defined(UNIX) || defined(AMIGA)
    (void)Etmode((CHARTYPE *)"OFF");
 #endif
    /*---------------------------------------------------------------------*/
@@ -1011,10 +1028,12 @@ char *argv[];
    /*---------------------------------------------------------------------*/
    if (first_define != NULL)
       first_define = dll_free(first_define);
+   if (first_synonym != NULL)
+      first_synonym = dll_free(first_synonym);
    if (first_prefix_synonym != NULL)
       first_prefix_synonym = lll_free(first_prefix_synonym);
    if (first_mouse_define != NULL)
-      first_define = dll_free(first_mouse_define);
+      first_mouse_define = dll_free(first_mouse_define);
    (*the_free)(rec);
    (*the_free)(trec);
    (*the_free)(brec);
@@ -1109,9 +1128,7 @@ static void init_signals()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("the.c:     init_signals");
-#endif
+ TRACE_FUNCTION("the.c:     init_signals");
 #ifdef UNIX
  signal(SIGQUIT,handle_signal);
  signal(SIGHUP,handle_signal);
@@ -1127,9 +1144,7 @@ static void init_signals()
  signal(SIGWINCH,handle_signal);
 # endif
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1143,9 +1158,7 @@ void init_colour_pairs()
 /*--------------------------- local data ------------------------------*/
  register int fg=0,bg=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("the.c:     init_colour_pairs");
-#endif
+ TRACE_FUNCTION("the.c:     init_colour_pairs");
 
 #ifdef A_COLOR
  for (fg=0;fg<COLORS;fg++)
@@ -1158,9 +1171,7 @@ void init_colour_pairs()
    }
 #endif
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1274,6 +1285,9 @@ CHARTYPE *argv0;
  fprintf(stdout,"-u display_length      display length in non-line mode\n");
 #ifdef XCURSES
  fprintf(stdout,"-X X11_switches        X11 switches (enclosed in \"\"\n");
+# if PDC_BUILD >= 2501
+ fprintf(stdout,"-B[blink_rate]         blink rate of cursor rate in tenths of seconds (default 5)\n");
+# endif
 #endif
  fprintf(stdout,"[dir [file [...]]]     file(s) and/or directory to be edited\n\n");
  fflush(stdout);
@@ -1289,9 +1303,7 @@ int allocate_working_memory()
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("the.c:     allocate_working_memory");
-#endif
+ TRACE_FUNCTION("the.c:     allocate_working_memory");
 /*---------------------------------------------------------------------*/
 /* Allocate some memory to rec.                                        */
 /*---------------------------------------------------------------------*/
@@ -1366,9 +1378,7 @@ void cleanup()
 #endif
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("the.c:     cleanup");
-#endif
+ TRACE_FUNCTION("the.c:     cleanup");
 
  if (curses_started)
    {
@@ -1427,9 +1437,7 @@ void cleanup()
 #ifndef MSWIN
  the_free_flists();
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 
@@ -1450,9 +1458,7 @@ int err;
  FILE_DETAILS *first_view_file=NULL;
  register int j=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("the.c:     handle_signal");
-#endif
+ TRACE_FUNCTION("the.c:     handle_signal");
 /*
  * If a SIGWINCH is caught, set a global flag to indicate that the screen has resized
  * Only do this for NCURSES.
