@@ -1,6 +1,6 @@
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1999 Mark Hessling
+ * Copyright (C) 1991-2000 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,14 +27,13 @@
  * necessary by the community.
  *
  * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
- * PO Box 203, Bellara, QLD 4507, AUSTRALIA
  * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
  * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
 /*
-$Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
+$Id: the.h,v 1.2 2000/12/10 04:15:33 mark Exp $
 */
 
 #include <defines.h>
@@ -90,6 +89,12 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #  include <curses.h>
 #endif
 
+#ifdef HAVE_PROTO
+# define Args(a) a
+#else
+# define Args(a) ()
+#endif
+
 /*
  * The following required because IBM AIX 4.3 defines curses colors
  * incorrectly :-(
@@ -242,6 +247,25 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #  endif
 #endif
 
+#if defined(AMIGA) && defined(GCC)
+#  include <stdlib.h>
+#  include <memory.h>
+#  include <string.h>
+#  include <errno.h>
+#  include <ctype.h>
+#  include <fcntl.h>
+#  include <sys/types.h>
+#  include <sys/stat.h>
+#  define ESLASH '/'
+#  define ESTR_SLASH (CHARTYPE *)"/"
+#  define OSLASH '/'
+#  define OSTR_SLASH (CHARTYPE *)"/"
+#  define ISLASH '/'
+#  define ISTR_SLASH (CHARTYPE *)"/"
+#  define CURRENT_DIR (CHARTYPE *)"."
+/* #  define CAN_RESIZE 1 */
+#endif
+
 #ifdef HAVE_CONFIG_H
 # ifndef HAVE_WATTRSET
 #  define wattrset(win,attr) ((attr == A_NORMAL) ? wstandend(win) : wstandout(win))
@@ -700,7 +724,8 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #define ATTR_GAP        22
 #define ATTR_ALERT      23
 #define ATTR_DIALOG     24
-#define ATTR_MAX        25
+#define ATTR_BOUNDMARK  25
+#define ATTR_MAX        26
 /*--------------------- -- ecolour defines -----------------------------*/
 #define ECOLOUR_COMMENTS               0
 #define ECOLOUR_STRINGS                1
@@ -742,13 +767,14 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #define LINE_LINE                  0
 #define LINE_TABLINE               1
 #define LINE_SCALE                 2
-#define LINE_SHADOW                4
-#define LINE_TOF                   8
-#define LINE_EOF                  16
-#define LINE_RESERVED             32
-#define LINE_OUT_OF_BOUNDS_ABOVE  64
-#define LINE_OUT_OF_BOUNDS_BELOW 128
-#define LINE_HEXSHOW             256
+#define LINE_BOUNDS                4
+#define LINE_SHADOW                8
+#define LINE_TOF                  16
+#define LINE_EOF                  32
+#define LINE_RESERVED             64
+#define LINE_OUT_OF_BOUNDS_ABOVE 128
+#define LINE_OUT_OF_BOUNDS_BELOW 256
+#define LINE_HEXSHOW             512
 /*--------------------------- target types ---------------------------*/
 #define TARGET_ERR          (-1)
 #define TARGET_UNFOUND        0x0000
@@ -770,28 +796,22 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 /*--------------------------- compatiblility modes -------------------*/
 #define COMPAT_THE            1
 #define COMPAT_XEDIT          2
-#define COMPAT_KEDIT          3
-#define COMPAT_KEDITW         4
+#define COMPAT_KEDIT          4
+#define COMPAT_KEDITW         8
+#define COMPAT_ISPF          16
 /*--------------------------- cursor commands ------------------------*/
 #define CURSOR_START          (-1)
 #define CURSOR_ERROR          (-2)
 #define CURSOR_HOME           0
 #define CURSOR_HOME_LAST      1
 #define CURSOR_SCREEN         2
-#define CURSOR_SCREEN_UP      3
-#define CURSOR_SCREEN_DOWN    4
-#define CURSOR_SCREEN_LEFT    5
-#define CURSOR_SCREEN_RIGHT   6
-#define CURSOR_ESCREEN        7
-#define CURSOR_ESCREEN_UP     8
-#define CURSOR_ESCREEN_DOWN   9
-#define CURSOR_ESCREEN_LEFT   10
-#define CURSOR_ESCREEN_RIGHT  11
-#define CURSOR_COLUMN         12
-#define CURSOR_FILE           13
-#define CURSOR_CMDLINE        14
-#define CURSOR_KEDIT          15
-#define CURSOR_MOUSE          16
+#define CURSOR_ESCREEN        3
+#define CURSOR_CUA            4
+#define CURSOR_COLUMN         5
+#define CURSOR_FILE           6
+#define CURSOR_CMDLINE        7
+#define CURSOR_KEDIT          8
+#define CURSOR_MOUSE          9
 /*--------------------------- defines for tabbing to fields ----------*/
 #define WHERE_WINDOW_MASK             0x0000FF00L
 #define WHERE_WINDOW_FILEAREA         0x00000100L
@@ -804,6 +824,19 @@ $Id: the.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 #define WHERE_SCREEN_FIRST            0x00010000L
 #define WHERE_SCREEN_LAST             0x00020000L
 #define WHERE_SCREEN_ONLY             0x00040000L
+/*--------------------------- defines for headers fo apply -----------*/
+#define HEADER_NUMBER                 0x001
+#define HEADER_COMMENT                0x002
+#define HEADER_STRING                 0x004
+#define HEADER_KEYWORD                0x008
+#define HEADER_FUNCTION               0x010
+#define HEADER_HEADER                 0x020
+#define HEADER_LABEL                  0x040
+#define HEADER_MATCH                  0x080
+#define HEADER_COLUMN                 0x100
+#define HEADER_POSTCOMPARE            0x200
+#define HEADER_MARKUP                 0x300
+#define HEADER_ALL                    (HEADER_NUMBER|HEADER_COMMENT|HEADER_STRING|HEADER_KEYWORD|HEADER_FUNCTION|HEADER_HEADER|HEADER_LABEL|HEADER_MATCH|HEADER_COLUMN|HEADER_POSTCOMPARE|HEADER_MARKUP)
 
 struct pending_prefix_command
  {
@@ -883,23 +916,34 @@ struct prefix_commands
   bool valid_on_tof;         /* is command allowed on Top of File line */
   bool valid_on_bof;      /* is command allowed on Bottom of File line */
   bool valid_in_readonly;    /* TRUE if command valid in readonly mode */
-#ifdef HAVE_PROTO
- short (*function)(THE_PPC *,short,LINETYPE);
-#else
- short (*function)();
-#endif
+  short (*function) Args((THE_PPC *,short,LINETYPE));
   LINETYPE default_target;/* number of lines to process if not specified */
   bool ignore_scope;/* TRUE if scope to be ignored when finding target */
   bool use_last_not_in_scope;/* TRUE if starting at end of shadow lines*/
   int  priority;                         /* priority of prefix command */
-#ifdef HAVE_PROTO
- short (*post_function)(THE_PPC *,short,LINETYPE);
-#else
- short (*post_function)();
-#endif
-
+  short (*post_function) Args((THE_PPC *,short,LINETYPE));
  };
 typedef struct prefix_commands PREFIX_COMMAND;
+#define PC_IS_ACTION      TRUE
+#define PC_NOT_ACTION     FALSE
+#define PC_MULTIPLES      TRUE
+#define PC_NO_MULTIPLES     FALSE
+#define PC_FULL_TARGET      TRUE
+#define PC_NO_FULL_TARGET     FALSE
+#define PC_IS_BLOCK      TRUE
+#define PC_NOT_BLOCK     FALSE
+#define PC_TARGET_REQD     TRUE
+#define PC_TARGET_NOT_REQD     FALSE
+#define PC_VALID_TOF      TRUE
+#define PC_INVALID_TOF         FALSE
+#define PC_VALID_BOF       TRUE
+#define PC_INVALID_BOF     FALSE
+#define PC_VALID_RO     TRUE
+#define PC_INVALID_RO     FALSE
+#define PC_IGNORE_SCOPE     TRUE
+#define PC_RESPECT_SCOPE     FALSE
+#define PC_USE_LAST_IN_SCOPE     TRUE
+#define PC_NO_USE_LAST_IN_SCOPE     FALSE
 
 struct parse_comments
 {
@@ -947,6 +991,18 @@ struct parse_headers
 };
 typedef struct parse_headers PARSE_HEADERS;
 
+struct parse_postcompare
+{
+   struct parse_postcompare *prev;
+   struct parse_postcompare *next;
+   bool is_class_type;
+   struct re_pattern_buffer *pattern_buffer;
+   CHARTYPE *string;
+   short string_length;
+   CHARTYPE alternate;
+};
+typedef struct parse_postcompare PARSE_POSTCOMPARE;
+
 struct parser_details
 {
    struct parser_details *prev;
@@ -956,6 +1012,7 @@ struct parser_details
    /* 
     * string features 
     */
+   bool have_string;
    bool check_single_quote;
    bool backslash_single_quote;
    bool check_double_quote;
@@ -1024,6 +1081,26 @@ struct parser_details
    short len_markup_reference_start_delim;
    CHARTYPE markup_reference_end_delim[MAX_DELIMITER_LENGTH+1];
    short len_markup_reference_end_delim;
+   /*
+    * postcompare features
+    */
+   bool have_postcompare;
+   PARSE_POSTCOMPARE *first_postcompare;
+   PARSE_POSTCOMPARE *current_postcompare;
+   /*
+    * column features
+    */
+#define MAX_PARSER_COLUMNS 20
+   bool have_columns;
+   LENGTHTYPE first_column[MAX_PARSER_COLUMNS];
+   LENGTHTYPE last_column[MAX_PARSER_COLUMNS];
+   short number_columns;
+   CHARTYPE column_alternate[MAX_PARSER_COLUMNS];
+   /* 
+    * number features
+    */
+   struct re_pattern_buffer number_pattern_buffer;
+   bool have_number_pattern_buffer;
 };
 typedef struct parser_details PARSER_DETAILS;
 
@@ -1169,6 +1246,8 @@ typedef struct
   LENGTHTYPE zone_start;                       /* col of start of zone */
   LENGTHTYPE zone_end;                           /* col of end of zone */
   LINETYPE autoscroll;     /* 0 - no autoscroll, -1 half, other number */
+  CHARTYPE boundmark;                             /* type of boundmark */
+  LINETYPE syntax_headers;       /* which syntax headers to be applied */
  } PRESERVED_VIEW_DETAILS;
 
 struct view_details
@@ -1240,6 +1319,8 @@ struct view_details
   LENGTHTYPE zone_start;                       /* col of start of zone */
   LENGTHTYPE zone_end;                           /* col of end of zone */
   LINETYPE autoscroll;     /* 0 - no autoscroll, -1 half, other number */
+  CHARTYPE boundmark;                             /* type of boundmark */
+  LINETYPE syntax_headers;       /* which syntax headers to be applied */
   /*
    * All settings above this line are saveable.
    * Ensure that PRESERVED_VIEW_DETAILS structure reflects this.
@@ -1458,9 +1539,24 @@ typedef struct
 #define CHAR_ALPHANUM  1
 #define CHAR_SPACE     2
 
-#define SHIFT_ALT      1
-#define SHIFT_CTRL     2
-#define SHIFT_SHIFT    4
+#define SHIFT_ALT            1
+#define SHIFT_CTRL           2
+#define SHIFT_SHIFT          4
+#define SHIFT_MODIFIER_ONLY  8
+
+#define INTERFACE_CLASSIC    1
+#define INTERFACE_CUA        2
+
+/*
+ * #defines for BOUNDMARK
+ */
+#define BOUNDMARK_OFF       0
+#define BOUNDMARK_ZONE      1
+#define BOUNDMARK_TRUNC     2
+#define BOUNDMARK_MARGINS   3
+#define BOUNDMARK_TABS      4
+#define BOUNDMARK_VERIFY    5
+
 /*
  * following #defines for MyStrip() function
  */
@@ -1518,7 +1614,7 @@ typedef struct
 #define     CURRENT_BOF         ((CURRENT_VIEW->current_line == CURRENT_FILE->number_lines+1L) ? TRUE : FALSE)
 #define     FOCUS_TOF           ((CURRENT_VIEW->focus_line == 0L) ? TRUE : FALSE)
 #define     FOCUS_BOF           ((CURRENT_VIEW->focus_line == CURRENT_FILE->number_lines+1L) ? TRUE : FALSE)
-#define     IN_VIEW(view,line)   ((line >= (view->current_line - (LINETYPE)view->current_row)) && (line <= (view->current_line + ((LINETYPE)CURRENT_SCREEN.rows - (LINETYPE)view->current_row))))
+#define     IN_VIEW(view,line)   ((line >= (view->current_line - (LINETYPE)view->current_row)) && (line <= (view->current_line + ((LINETYPE)CURRENT_SCREEN.rows[WINDOW_FILEAREA] - (LINETYPE)view->current_row))))
 #define     IN_SCOPE(view,line) ((line)->select >= (view)->display_low && (line)->select <= (view)->display_high)
 /*---------------------- system specific redefines --------------------*/
 #ifdef VAX
@@ -1558,8 +1654,10 @@ struct defines
  int def_funkey;
  short def_command;
  CHARTYPE *def_params;
+ CHARTYPE *synonym;
  CHARTYPE *pcode;
  int pcode_len;
+ CHARTYPE linend;
 };
 typedef struct defines DEFINE;
 
@@ -1600,11 +1698,7 @@ struct window_areas
  };
 typedef struct window_areas AREAS;
 
-#ifdef HAVE_PROTO
-typedef short ExtractFunction( short, short, CHARTYPE *, CHARTYPE ,LINETYPE ,CHARTYPE *, LINETYPE );
-#else
-typedef short ExtractFunction( );
-#endif
+typedef short (ExtractFunction) Args(( short, short, CHARTYPE *, CHARTYPE ,LINETYPE ,CHARTYPE *, LINETYPE ));
 
 /* structure for query and implied extract */
 struct query_item
@@ -1665,18 +1759,19 @@ extern void* (*the_realloc)();
 #endif
 
 #if defined(THE_TRACE)
-#  if defined(HAVE_PROTO)
-void trace_initialise(void);
-void trace_function(char *);
-void trace_return(void);
-void trace_string(char *,...);
-void trace_constant(char *);
-#  else
-void trace_initialise(/* void */);
-void trace_function(/* char* */);
-void trace_return(/* void */);
-void trace_string(/* char*,... */);
-void trace_constant(/* char * */);
-# endif
+void trace_initialise Args((void));
+void trace_function Args((char *));
+void trace_return Args((void));
+void trace_string Args((char *,...));
+void trace_constant Args((char *));
+# define TRACE_RETURN()     trace_return()
+# define TRACE_FUNCTION(x)  trace_function(x)
+# define TRACE_INITIALISE() trace_initialise()
+# define TRACE_CONSTANT(x) trace_constant(x)
+#else
+# define TRACE_RETURN()
+# define TRACE_FUNCTION(x) 
+# define TRACE_INITIALISE()
+# define TRACE_CONSTANT(x)
 #endif
 #include "vars.h"
