@@ -34,7 +34,7 @@
  */
 
 /*
-$Id: therexx.h,v 1.1 1999/07/31 07:28:45 mark Exp mark $
+$Id: therexx.h,v 1.2 2000/12/10 04:16:31 mark Exp $
 */
 
 #if defined(OS2)
@@ -119,6 +119,13 @@ typedef CHAR *PCH;
 #  endif
 # endif
 #endif
+
+#if defined(AMIGA)
+# if defined(USE_REGINA)
+#  include <rexxsaa.h>
+# endif
+#endif
+
 /*
  * The following abbreviations are used as prefixes for the following
  * #defines:
@@ -251,39 +258,44 @@ typedef CHAR *PCH;
 # endif
 
 #elif defined(USE_REGINA)
+# if defined(CONST)
+#  define C_PSZ  PCSZ
+# else
+#  define C_PSZ  PSZ
+# endif
 # define RXSTRING_STRPTR_TYPE char *
 # define RFH_RETURN_TYPE      APIRET APIENTRY
-# define RFH_ARG0_TYPE        PUCHAR
+# define RFH_ARG0_TYPE        C_PSZ
 # define RFH_ARG1_TYPE        ULONG
 # define RFH_ARG2_TYPE        PRXSTRING
-# define RFH_ARG3_TYPE        PSZ
+# define RFH_ARG3_TYPE        C_PSZ
 # define RFH_ARG4_TYPE        PRXSTRING
-# define RRFE_ARG0_TYPE       PSZ
+# define RRFE_ARG0_TYPE       C_PSZ
 # define RRFE_ARG1_TYPE       PFN
-# define RDF_ARG0_TYPE        PSZ
+# define RDF_ARG0_TYPE        C_PSZ
 # define REH_RETURN_TYPE      LONG APIENTRY
 # define REH_ARG0_TYPE        LONG
 # define REH_ARG1_TYPE        LONG
 # define REH_ARG2_TYPE        PEXIT
-# define RREE_ARG0_TYPE       PSZ
+# define RREE_ARG0_TYPE       C_PSZ
 # define RREE_ARG1_TYPE       PFN
 # define RREE_ARG2_TYPE       PUCHAR
 # define RSH_RETURN_TYPE      APIRET APIENTRY
 # define RSH_ARG0_TYPE        PRXSTRING
 # define RSH_ARG1_TYPE        PUSHORT
 # define RSH_ARG2_TYPE        PRXSTRING
-# define RRSE_ARG0_TYPE       PSZ
+# define RRSE_ARG0_TYPE       C_PSZ
 # define RRSE_ARG1_TYPE       PFN
 # define RRSE_ARG2_TYPE       PUCHAR
-# define RDE_ARG0_TYPE        PSZ
-# define RDE_ARG1_TYPE        PSZ
-# define RDS_ARG0_TYPE        PSZ
-# define RDS_ARG1_TYPE        PSZ
+# define RDE_ARG0_TYPE        C_PSZ
+# define RDE_ARG1_TYPE        C_PSZ
+# define RDS_ARG0_TYPE        C_PSZ
+# define RDS_ARG1_TYPE        C_PSZ
 # define RS_ARG0_TYPE         LONG
 # define RS_ARG1_TYPE         PRXSTRING
-# define RS_ARG2_TYPE         PSZ
+# define RS_ARG2_TYPE         C_PSZ
 # define RS_ARG3_TYPE         PRXSTRING
-# define RS_ARG4_TYPE         PSZ
+# define RS_ARG4_TYPE         C_PSZ
 # define RS_ARG5_TYPE         LONG
 # define RS_ARG6_TYPE         PRXSYSEXIT
 # define RS_ARG7_TYPE         PSHORT
