@@ -1,5 +1,5 @@
 /***********************************************************************/
-/* THE_TRACE.C - Debugging and tracing functions.                          */
+/* trace.c - Debugging and tracing functions.                          */
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: trace.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: trace.c,v 1.2 2000/12/10 04:17:33 mark Exp $";
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -96,53 +96,24 @@ char *trace_str;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
- register int i;
- time_t timer;
- struct tm *tblock=NULL;
+   register int i;
+   time_t timer;
+   struct tm *tblock=NULL;
 /*--------------------------- processing ------------------------------*/
-#if 0
- if (trace_level == (-1))
-    return;
- if (strcmp(trace_str,trace_save_str) == 0)
-   {
-    trace_number++;
-    trace_level++;
-    return;
-   }
- if (trace_number == 0)
-   {
-    trace_number = 1;
-    trace_level++;
-    return;
-   }
- trace_fp = fopen(trace_env,"a");
- for (i=0;i<trace_level;i++)
-     fprintf(trace_fp,"  ");
- fprintf(trace_fp,"(%d)%-s",trace_level,trace_save_str);
- for (i=0;i<60-(trace_level*2)-strlen(trace_save_str);i++)
-     fprintf(trace_fp," ");
- fprintf(trace_fp,"%5d\n",trace_number);
- fclose(trace_fp);
-
- trace_number = 1;
- trace_level++;
- strcpy(trace_save_str,trace_str);
- return;
-#endif
- if (trace_level == (-1))
-    return;
- trace_level++;
- trace_fp = fopen(trace_env,"a");
- for (i=0;i<trace_level;i++)
-     fprintf(trace_fp,"  ");
- fprintf(trace_fp,"(%d)%-s",trace_level,trace_str);
- for (i=0;i<60-(trace_level*2)-strlen(trace_str);i++)
-     fprintf(trace_fp," ");
- timer = time(NULL);
- tblock = localtime(&timer);
- fprintf(trace_fp,"%2d:%2d:%2d\n",tblock->tm_hour,tblock->tm_min,tblock->tm_sec);
- fclose(trace_fp);
- return;
+   if (trace_level == (-1))
+      return;
+   trace_level++;
+   trace_fp = fopen(trace_env,"a");
+   for (i=0;i<trace_level;i++)
+      fprintf(trace_fp,"  ");
+   fprintf(trace_fp,"(%d)%-s",trace_level,trace_str);
+   for (i=0;i<100-(trace_level*2)-strlen(trace_str);i++)
+      fprintf(trace_fp," ");
+   timer = time(NULL);
+   tblock = localtime(&timer);
+   fprintf(trace_fp,"%2d:%2d:%2d\n",tblock->tm_hour,tblock->tm_min,tblock->tm_sec);
+   fclose(trace_fp);
+   return;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
