@@ -36,7 +36,7 @@
  * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-static char RCSid[] = "$Id: util.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+static char RCSid[] = "$Id: util.c,v 1.2 2000/12/10 04:20:58 mark Exp $";
 
 #include <the.h>
 #include <proto.h>
@@ -52,6 +52,7 @@ static char RCSid[] = "$Id: util.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
  static short num_rcvry=0;
 
  static int CompareLen=0;
+ static bool CompareExact;
 
 #ifdef USE_EXTCURSES
  chtype color_pair[COLOR_PAIRS];
@@ -1101,18 +1102,12 @@ short min_len;
 #endif
 {
 /*--------------------------- local data ------------------------------*/
- register int i=0,lenstr=0;
- CHARTYPE c1,c2;
+   register int i=0,lenstr=0;
+   CHARTYPE c1,c2;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    equal");
-#endif
- if (min_len == 0)
+   if (min_len == 0)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(FALSE);
+      return(FALSE);
    }
 #if 0
  if (memfind(con,str,(short)min(strlen((DEFCHAR *)str),strlen((DEFCHAR *)con)),
@@ -1120,49 +1115,36 @@ short min_len;
  &&  strlen((DEFCHAR *)str) >= min_len
  &&  strlen((DEFCHAR *)con) >= strlen((DEFCHAR *)str))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(TRUE);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(FALSE);
 #else
- if (strlen((DEFCHAR *)str) < min_len
- ||  strlen((DEFCHAR *)con) < strlen((DEFCHAR *)str))
+   if (strlen((DEFCHAR *)str) < min_len
+   ||  strlen((DEFCHAR *)con) < strlen((DEFCHAR *)str))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
-    return(FALSE);
+      return(FALSE);
    }
- lenstr = strlen((DEFCHAR*)str);
- for (i=0;i<lenstr;i++)
+   lenstr = strlen((DEFCHAR*)str);
+   for (i=0;i<lenstr;i++)
    {
-    if (isupper(*con))
-       c1 = tolower(*con);
-    else
-       c1 = *con;
-    if (isupper(*str))
-       c2 = tolower(*str);
-    else
-       c2 = *str;
-    if (c1 != c2)
+      if (isupper(*con))
+         c1 = tolower(*con);
+      else
+         c1 = *con;
+      if (isupper(*str))
+         c2 = tolower(*str);
+      else
+         c2 = *str;
+      if (c1 != c2)
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
-       return(FALSE);
+         return(FALSE);
       }
-    ++con;
-    ++str;
+      ++con;
+      ++str;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
- return(TRUE);
+   return(TRUE);
 #endif
 
 }
@@ -1183,9 +1165,7 @@ CHARTYPE *str;
  register short i=0;
  short num_signs=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    valid_integer");
-#endif
+ TRACE_FUNCTION("util.c:    valid_integer");
  for (i=0; i<strlen((DEFCHAR *)str); i++)
     {
      if (*(str+i) == '-' || *(str+i) == '+')
@@ -1193,22 +1173,16 @@ CHARTYPE *str;
      else
         if (!isdigit(*(str+i)))
           {
-#ifdef THE_TRACE
-           trace_return();
-#endif
+           TRACE_RETURN();
            return(FALSE);
           }
     }
  if (num_signs > 1)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(FALSE);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(TRUE);
 }
 /***********************************************************************/
@@ -1228,9 +1202,7 @@ CHARTYPE *str;
  register short i=0;
  short num_signs=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    valid_positive_integer");
-#endif
+ TRACE_FUNCTION("util.c:    valid_positive_integer");
  for (i=0; i<strlen((DEFCHAR *)str); i++)
     {
      if (*(str+i) == '+')
@@ -1238,22 +1210,16 @@ CHARTYPE *str;
      else
         if (!isdigit(*(str+i)))
           {
-#ifdef THE_TRACE
-           trace_return();
-#endif
+           TRACE_RETURN();
            return(FALSE);
           }
     }
  if (num_signs > 1)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(FALSE);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(TRUE);
 }
 /***********************************************************************/
@@ -1335,15 +1301,11 @@ bool new_flag;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    add_LINE");
-#endif
+ TRACE_FUNCTION("util.c:    add_LINE");
  next_line = lll_add(first,curr,sizeof(LINE));
  if (next_line == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(NULL);
    }
  curr_line = next_line;
@@ -1351,9 +1313,7 @@ bool new_flag;
  curr_line->line = (CHARTYPE *)(*the_malloc)((len+1)*sizeof(CHARTYPE));
  if (curr_line->line == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(NULL);
    }
  memcpy(curr_line->line,line,len);
@@ -1369,7 +1329,7 @@ bool new_flag;
  curr_line->flags.save_tag_flag = FALSE;
 /*
  * If this is the first line of the file, and the current parser for the
- * file is NULL, see if we can't use one of the magic string parsers...
+ * file is NULL, see if we can use one of the magic string parsers...
  */
  if (curr_line->prev
  &&  curr_line->prev->prev == NULL
@@ -1379,9 +1339,7 @@ bool new_flag;
  {
     find_auto_parser(CURRENT_FILE);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(curr_line);
 }
 /***********************************************************************/
@@ -1397,23 +1355,17 @@ LENGTHTYPE len;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    append_LINE");
-#endif
+ TRACE_FUNCTION("util.c:    append_LINE");
  curr->line = (CHARTYPE *)(*the_realloc)(curr->line,(curr->length+len+1)*sizeof(CHARTYPE));
  if (curr->line == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(NULL);
    }
  memcpy(curr->line+curr->length,line,len);
  curr->length += len;
  *(curr->line+curr->length) = '\0'; /* for functions that expect ASCIIZ string */
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(curr);
 }
 /***********************************************************************/
@@ -1436,16 +1388,12 @@ short direction;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    delete_LINE");
-#endif
+ TRACE_FUNCTION("util.c:    delete_LINE");
  if (curr->name != (CHARTYPE *)NULL)
     (*the_free)(curr->name);
  (*the_free)(curr->line);
  curr = lll_del(&first,&last,curr,direction);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(curr);
 }
 
@@ -1464,17 +1412,13 @@ short len;
 /*--------------------------- local data ------------------------------*/
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    put_string");
-#endif
+ TRACE_FUNCTION("util.c:    put_string");
  wmove(win,row,col);
  for (i=0;i<len;i++)
    {
     waddch(win,etmode_table[*(string+i)]);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1491,9 +1435,7 @@ CHARTYPE add_ins;
 /*--------------------------- local data ------------------------------*/
  chtype chr=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    put_char");
-#endif
+ TRACE_FUNCTION("util.c:    put_char");
  chr = ch & A_CHARTEXT;
  if (etmode_flag[chr])  /* etmode character has attributes, use them */
     ch = etmode_table[chr];
@@ -1504,9 +1446,7 @@ CHARTYPE add_ins;
     waddch(win,ch);
  else
     winsch(win,ch);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1524,17 +1464,13 @@ short scrn;
  FILE_DETAILS fp;
  short my_prefix_width=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    set_up_windows");
-#endif
+ TRACE_FUNCTION("util.c:    set_up_windows");
 /*---------------------------------------------------------------------*/
 /* If curses has not started exit gracefully...                        */
 /*---------------------------------------------------------------------*/
  if (!curses_started)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -1543,9 +1479,7 @@ short scrn;
  if ((fp.attr = (COLOUR_ATTR *)(*the_malloc)(ATTR_MAX*sizeof(COLOUR_ATTR))) == NULL)
    {
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OUT_OF_MEMORY);
    }
  if (screen[scrn].screen_view)
@@ -1581,9 +1515,7 @@ short scrn;
        if (screen[scrn].win[i] == (WINDOW *)NULL)
          {
           display_error(30,(CHARTYPE *)"creating window",FALSE);
-#ifdef THE_TRACE
-          trace_return();
-#endif
+          TRACE_RETURN();
           return(RC_OUT_OF_MEMORY);
          }
 #if !defined(PDCURSES)
@@ -1639,9 +1571,7 @@ short scrn;
     if (divider == (WINDOW *)NULL)
       {
        display_error(30,(CHARTYPE *)"creating window",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY);
       }
 
@@ -1668,9 +1598,7 @@ if (SLKx)
 /* Free up  space for a file descriptor colour attributes...           */
 /*---------------------------------------------------------------------*/
  (*the_free)(fp.attr);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -1686,9 +1614,7 @@ short draw_divider()
  register int i=0;
 #endif
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    draw_divider");
-#endif
+ TRACE_FUNCTION("util.c:    draw_divider");
 
 #ifdef HAVE_WVLINE
  wmove(divider,0,0);
@@ -1703,9 +1629,7 @@ short draw_divider()
     waddch(divider,'|');
    }
 #endif
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -1719,14 +1643,10 @@ short create_statusline_window()
 /*--------------------------- local data ------------------------------*/
  COLOUR_ATTR attr;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    create_statusline_window");
-#endif
+ TRACE_FUNCTION("util.c:    create_statusline_window");
  if (!curses_started)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
  if (CURRENT_VIEW == NULL
@@ -1754,9 +1674,7 @@ short create_statusline_window()
     default:
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(RC_OK);
 }
 /***********************************************************************/
@@ -1773,9 +1691,7 @@ LINE *known_curr;
 /*--------------------------- local data ------------------------------*/
  LINE *curr=known_curr;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    pre_process_line");
-#endif
+ TRACE_FUNCTION("util.c:    pre_process_line");
 /*---------------------------------------------------------------------*/
 /* If we haven't been passed a valid LINE*, go and get one for the     */
 /* supplied line_number.                                               */
@@ -1802,9 +1718,7 @@ LINE *known_curr;
     pre_rec[pre_rec_len] = ' ';
     pre_rec[MAX_PREFIX_WIDTH] = '\0';
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -1823,17 +1737,13 @@ bool set_alt;
  LINE *curr=known_curr;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    post_process_line");
-#endif
+ TRACE_FUNCTION("util.c:    post_process_line");
 /*---------------------------------------------------------------------*/
 /* If there are no lines in the file associated with the view, exit... */
 /*---------------------------------------------------------------------*/
  if (the_view->file_for_view->first_line == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_OK);
    }
 /*---------------------------------------------------------------------*/
@@ -1855,9 +1765,7 @@ bool set_alt;
 /*---------------------------------------------------------------------*/
  if (rec_len == curr->length && (memcmp(rec,curr->line,curr->length) == 0))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(RC_NO_LINES_CHANGED);
    }
 /*---------------------------------------------------------------------*/
@@ -1883,9 +1791,7 @@ bool set_alt;
     if (curr->line == NULL)
       {
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(RC_OUT_OF_MEMORY);
       }
    }
@@ -1896,17 +1802,15 @@ bool set_alt;
  curr->length = rec_len;
  *(curr->line+rec_len) = '\0';
 /*
- * If this is the first line of the file, ad the current parser for the
- * file is NULL, see if we can't use one of the magic string parsers...
+ * If this is the first line of the file, and the current parser for the
+ * file is NULL, see if we can use one of the magic string parsers...
  */
  if (line_number == 1
  &&  CURRENT_FILE->parser == NULL)
  {
     find_auto_parser(CURRENT_FILE);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 /***********************************************************************/
@@ -1920,19 +1824,13 @@ CHARTYPE *field;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    blank_field");
-#endif
+ TRACE_FUNCTION("util.c:    blank_field");
  if (strzne(field,' ') == (-1))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(TRUE);                /* field is NULL or just contains spaces */
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(FALSE);
 }
 /***********************************************************************/
@@ -1952,17 +1850,13 @@ LINETYPE num_lines;
 /*---------------------------------------------------------------------*/
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    adjust_marked_lines");
-#endif
+ TRACE_FUNCTION("util.c:    adjust_marked_lines");
 /*---------------------------------------------------------------------*/
 /* If there are no marked lines in the current view, return.           */
 /*---------------------------------------------------------------------*/
  if (MARK_VIEW != CURRENT_VIEW)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
  switch(binsert_line)
@@ -2015,9 +1909,7 @@ LINETYPE num_lines;
          CURRENT_VIEW->mark_end_line -= num_lines;
          break;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -2039,17 +1931,13 @@ LINETYPE num_lines;
 /*--------------------------- local data ------------------------------*/
  THE_PPC *curr_ppc=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    adjust_pending_prefix");
-#endif
+ TRACE_FUNCTION("util.c:    adjust_pending_prefix");
 /*---------------------------------------------------------------------*/
 /* If there are no pending prefix commands in the view, return.        */
 /*---------------------------------------------------------------------*/
  if (view->file_for_view->first_ppc == NULL)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
  curr_ppc = view->file_for_view->first_ppc;
@@ -2081,9 +1969,7 @@ LINETYPE num_lines;
       }
     curr_ppc = curr_ppc->next;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -2097,28 +1983,20 @@ CHARTYPE key;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    case_translate");
-#endif
+ TRACE_FUNCTION("util.c:    case_translate");
  if (CURRENT_VIEW->case_enter == CASE_UPPER
  && islower(key))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(toupper(key));
    }
  if (CURRENT_VIEW->case_enter == CASE_LOWER
  && isupper(key))
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(tolower(key));
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(key);
 }
 /***********************************************************************/
@@ -2134,17 +2012,13 @@ LENGTHTYPE len;
 /*--------------------------- local data ------------------------------*/
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    add_to_recovery_list");
-#endif
+ TRACE_FUNCTION("util.c:    add_to_recovery_list");
 /*---------------------------------------------------------------------*/
 /* Ignore if running in batch.                                         */
 /*---------------------------------------------------------------------*/
  if (batch_only)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -2165,9 +2039,7 @@ LENGTHTYPE len;
     if ((rcvry[add_rcvry] = (CHARTYPE *)(*the_malloc)((len+1)*sizeof(CHARTYPE))) == NULL)
       {
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return;
       }
    }
@@ -2176,9 +2048,7 @@ LENGTHTYPE len;
     if ((rcvry[add_rcvry] = (CHARTYPE *)(*the_realloc)(rcvry[add_rcvry],(len+1)*sizeof(CHARTYPE))) == NULL)
       {
        display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return;
       }
    }
@@ -2188,9 +2058,7 @@ LENGTHTYPE len;
  add_rcvry = (++add_rcvry >= MAX_RECV) ? 0 : add_rcvry;
  num_rcvry = (++num_rcvry > MAX_RECV) ? MAX_RECV : num_rcvry;
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -2206,18 +2074,14 @@ short num;
  register short i=0;
  short num_retr = min(num,num_rcvry);
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    get_from_recovery_list");
-#endif
+ TRACE_FUNCTION("util.c:    get_from_recovery_list");
 /*---------------------------------------------------------------------*/
 /* Return error if nothing to recover.                                 */
 /*---------------------------------------------------------------------*/
  if (retr_rcvry == (-1))
    {
     display_error(0,(CHARTYPE *)"0 line(s) recovered",TRUE);
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return;
    }
 /*---------------------------------------------------------------------*/
@@ -2240,9 +2104,7 @@ short num;
 
  sprintf((DEFCHAR *)temp_cmd,"%d line(s) recovered",num_retr);
  display_error(0,temp_cmd,TRUE);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 /***********************************************************************/
@@ -2256,9 +2118,7 @@ void free_recovery_list()
 /*--------------------------- local data ------------------------------*/
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    free_recovery_list");
-#endif
+ TRACE_FUNCTION("util.c:    free_recovery_list");
  for (i=0;i<MAX_RECV;i++)
    {
     if (rcvry[i] != NULL)
@@ -2270,9 +2130,7 @@ void free_recovery_list()
  add_rcvry  = (-1);
  retr_rcvry = (-1);
  num_rcvry  = 0;
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return;
 }
 
@@ -2295,9 +2153,7 @@ short cols;
  short begy=0,begx=0,maxy=0,maxx=0,y=0,x=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    adjust_window");
-#endif
+ TRACE_FUNCTION("util.c:    adjust_window");
 /*---------------------------------------------------------------------*/
 /* Get existing details about the current window.                      */
 /*---------------------------------------------------------------------*/
@@ -2307,17 +2163,13 @@ short cols;
    {
     if (begy == tr && begx == tc)   /* same position */
       {
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(win); /* nothing to do, return same window */
       }
     else /* need to move window */
       {
        rc = mvwin(win,tr,tc);
-#ifdef THE_TRACE
-       trace_return();
-#endif
+       TRACE_RETURN();
        return(win);
       }
    }
@@ -2329,9 +2181,7 @@ short cols;
  neww = newwin(lines,cols,tr,tc);
  if (neww != (WINDOW *)NULL)
     wmove(neww,y,x);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(neww);
 }
 #endif
@@ -2347,51 +2197,23 @@ bool visible;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    draw_cursor");
-#endif
-
-#if 0
-
+   TRACE_FUNCTION("util.c:    draw_cursor");
 #ifdef HAVE_CURS_SET
- if (visible)
+   if (visible)
    {
-    if (INSERTMODEx)
-#if defined(USE_NCURSES) || defined(CURSOR_DISAPPEARS)
-       curs_set(1);   /* underline cursor - until ncurses bug fixed */
-#else
-       curs_set(2);   /* block cursor */
-#endif
-    else
-       curs_set(1);   /* underline cursor */
-   }
- else
-    curs_set(0);      /* cursor off */
-#endif
-
-#else
-
-#ifdef HAVE_CURS_SET
- if (visible)
-   {
-    if (INSERTMODEx)
+      if (INSERTMODEx)
       {
-       curs_set(1);   /* First set to displayed... */
-       curs_set(2);   /* ...then try to make it more visible */
+         curs_set(1);   /* First set to displayed... */
+         curs_set(2);   /* ...then try to make it more visible */
       }
-    else
-       curs_set(1);   /* underline cursor */
+      else
+         curs_set(1);   /* underline cursor */
    }
- else
-    curs_set(0);      /* cursor off */
+   else
+      curs_set(0);      /* cursor off */
 #endif
-
-#endif
-
-#ifdef THE_TRACE
- trace_return();
-#endif
- return;
+   TRACE_RETURN();
+   return;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -2406,9 +2228,7 @@ WINDOW *win;
  register short i=0;
  short x=0,y=0,maxx=0,maxy=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    my_wclrtoeol");
-#endif
+ TRACE_FUNCTION("util.c:    my_wclrtoeol");
 #if defined(USE_NCURSES_IGNORED)
  /*
   * This extra code here to get around an ncurses bug that
@@ -2433,9 +2253,7 @@ WINDOW *win;
        waddch(win,' ');
     wmove(win,y,x);
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(0);
 }
 /***********************************************************************/
@@ -2450,9 +2268,7 @@ WINDOW *win;
 /*--------------------------- local data ------------------------------*/
  short x=0,y=0,maxx=0,maxy=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    my_wdelch");
-#endif
+ TRACE_FUNCTION("util.c:    my_wdelch");
 
  getyx(win,y,x);
  getmaxyx(win,maxy,maxx);
@@ -2460,9 +2276,7 @@ WINDOW *win;
  mvwaddch(win,y,maxx-1,' ');
  wmove(win,y,x);
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(0);
 }
 /***********************************************************************/
@@ -2487,18 +2301,14 @@ LENGTHTYPE *first_col,*last_col;
  short state=0;
  register short i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    get_word");
-#endif
+ TRACE_FUNCTION("util.c:    get_word");
 /*---------------------------------------------------------------------*/
 /* If we are after the last column of the line, then just ignore the   */
 /* command and leave the cursor where it is.                           */
 /*---------------------------------------------------------------------*/
  if (curr_pos >= length)
    {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(0);
    }
 /*---------------------------------------------------------------------*/
@@ -2532,9 +2342,7 @@ LENGTHTYPE *first_col,*last_col;
       }
     if (i < 0)
        *first_col = 0;
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(1);
    }
 /*---------------------------------------------------------------------*/
@@ -2623,9 +2431,7 @@ LENGTHTYPE *first_col,*last_col;
        *last_col = length - 1;
    }
 
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(1);
 }
 
@@ -2641,9 +2447,7 @@ CHARTYPE chr;
 /*--------------------------- local data ------------------------------*/
  short char_type=CHAR_OTHER;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    my_isalphanum");
-#endif
+ TRACE_FUNCTION("util.c:    my_isalphanum");
 
  if (chr == ' ')
     char_type = CHAR_SPACE;
@@ -2655,9 +2459,7 @@ CHARTYPE chr;
     ||  chr > 128)
        char_type = CHAR_ALPHANUM;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(char_type);
 }
 
@@ -2674,9 +2476,7 @@ short scridx,winidx,y,x;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    my_wmove");
-#endif
+ TRACE_FUNCTION("util.c:    my_wmove");
 /*---------------------------------------------------------------------*/
 /* If the scridx or winidx are -1, do not try to save the x/y position.*/
 /*---------------------------------------------------------------------*/
@@ -2688,9 +2488,7 @@ short scridx,winidx,y,x;
    }
  if (curses_started)
     wmove(win,y,x);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(rc);
 }
 
@@ -2706,9 +2504,7 @@ CHARTYPE scridx;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    get_row_for_tof_eof");
-#endif
+ TRACE_FUNCTION("util.c:    get_row_for_tof_eof");
  if (screen[scridx].sl[row].line_type == LINE_OUT_OF_BOUNDS_ABOVE)
    {
     for(;screen[scridx].sl[row].line_type != LINE_TOF;row++)
@@ -2721,12 +2517,22 @@ CHARTYPE scridx;
     for(;screen[scridx].sl[row].line_type != LINE_EOF;row--)
        ;
    }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(row);
 }
 
+/***********************************************************************/
+#ifdef HAVE_PROTO
+void set_compare_exact( bool exact )
+#else
+void set_compare_exact( exact )
+bool exact;
+#endif
+/***********************************************************************/
+{
+   CompareExact = exact;
+}
+
 /***********************************************************************/
 #ifdef HAVE_PROTO
 static int query_item_compare(const void *inkey, const void *intpl)
@@ -2747,10 +2553,22 @@ const void *intpl;
  rc = memcmp(key, (DEFCHAR*)tpl->name, m);
  if (rc != 0)
     return(rc);
- if (CompareLen > tpl->name_length)
-    return(1);
- if (CompareLen < tpl->name_length)
-    return(-1);
+   if ( CompareExact )
+   {
+      if (CompareLen > tpl->name_length)
+         return(1);
+      if (CompareLen < tpl->name_length)
+         return(-1);
+   }
+   else
+   {
+      if (equal(tpl->name,key,tpl->min_len))
+         return 0;
+      if (CompareLen > tpl->name_length)
+         return(1);
+      if (CompareLen < tpl->name_length)
+         return(-1);
+   }
  return(0);
 }
 
@@ -2775,21 +2593,17 @@ int len;
  size_t alloclen = width;
 #endif
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    search_query_item_array");
-#endif
+ TRACE_FUNCTION("util.c:    search_query_item_array");
 
 #ifdef __CHECKER__
  if (len > alloclen)
     alloclen = len;
- if ((buf = (char*)(*the_malloc)(alloclen)) == NULL)
+ if ((buf = (char*)(*the_malloc)(alloclen+1)) == NULL)
 #else
- if ((buf = (char*)(*the_malloc)(len)) == NULL)
+ if ((buf = (char*)(*the_malloc)(len+1)) == NULL)
 #endif
  {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(-1);
  }
 
@@ -2797,20 +2611,17 @@ int len;
  {
     buf[i] = (char)tolower(needle[i]);
  }
+ buf[i] = '\0';
  CompareLen = len;
  result = bsearch(buf, base, num, width, query_item_compare);
  (*the_free)(buf);
 
  if (result == NULL)
  {
-#ifdef THE_TRACE
-    trace_return();
-#endif
+    TRACE_RETURN();
     return(-1);
  }
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return((int) (((long) result - (long) base) / width ));
 }
 
@@ -2936,16 +2747,12 @@ int doupdate()
 /*--------------------------- local data ------------------------------*/
  unsigned short y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef THE_TRACE
- trace_function("util.c:    doupdate");
-#endif
+ TRACE_FUNCTION("util.c:    doupdate");
  getyx(CURRENT_WINDOW,y,x);
  refresh();
  wmove(CURRENT_WINDOW,y,x);
  wrefresh(CURRENT_WINDOW);
-#ifdef THE_TRACE
- trace_return();
-#endif
+ TRACE_RETURN();
  return(0);
 }
 #endif
